pub enum AppSpecDomainsItemMinimumTlsVersion {
X12,
X13,
}Expand description
The minimum version of TLS a client application can use to access resources for the domain. Must be one of the following values wrapped within quotations: "1.2" or "1.3".
JSON schema
{
"description": "The minimum version of TLS a client application can use to access resources for the domain. Must be one of the following values wrapped within quotations: `\"1.2\"` or `\"1.3\"`.",
"examples": [
"1.3"
],
"type": "string",
"enum": [
"1.2",
"1.3"
],
"maxLength": 3,
"minLength": 3
}Variants