pub enum AssignDropletsByIdNetworkStack {
Ipv4,
Dualstack,
}Expand description
A string indicating whether the load balancer will support IPv4 or both IPv4 and IPv6 networking. This property cannot be updated after creating the load balancer.
JSON schema
{
"description": "A string indicating whether the load balancer will support IPv4 or both IPv4 and IPv6 networking. This property cannot be updated after creating the load balancer.",
"default": "IPV4",
"examples": [
"IPV4"
],
"type": "string",
"enum": [
"IPV4",
"DUALSTACK"
]
}Variants