pub enum AssignDropletsByIdType {
Regional,
RegionalNetwork,
Global,
}Expand description
A string indicating whether the load balancer should be a standard regional HTTP load balancer, a regional network load balancer that routes traffic at the TCP/UDP transport layer, or a global load balancer.
JSON schema
{
"description": "A string indicating whether the load balancer should be a standard regional HTTP load balancer, a regional network load balancer that routes traffic at the TCP/UDP transport layer, or a global load balancer.",
"default": "REGIONAL",
"examples": [
"REGIONAL"
],
"type": "string",
"enum": [
"REGIONAL",
"REGIONAL_NETWORK",
"GLOBAL"
]
}Variants