DatabasesAddUserBodySettingsOpensearchAclItemPermission

Enum DatabasesAddUserBodySettingsOpensearchAclItemPermission 

pub enum DatabasesAddUserBodySettingsOpensearchAclItemPermission {
    Deny,
    Admin,
    Read,
    Readwrite,
    Write,
}
Permission set applied to the ACL. ‘read’ allows user to read from the index. ‘write’ allows for user to write to the index. ‘readwrite’ allows for both ‘read’ and ‘write’ permission. ‘deny’(default) restricts user from performing any operation over an index. ‘admin’ allows for ‘readwrite’ as well as any operations to administer the index.

JSON schema
{
 "description": "Permission set applied to the ACL. 'read' allows user to read from the index. 'write' allows for user to write to the index. 'readwrite' allows for both 'read' and 'write' permission. 'deny'(default) restricts user from performing any operation over an index. 'admin' allows for 'readwrite' as well as any operations to administer the index.",
 "examples": [
   "read"
 ],
 "type": "string",
 "enum": [
   "deny",
   "admin",
   "read",
   "readwrite",
   "write"
 ]
}

Variants



Deny



Admin



Read



Readwrite



Write