pub enum DatabasesGetConfigResponseConfigSubtype2RedisMaxmemoryPolicy {
Noeviction,
AllkeysLru,
AllkeysRandom,
VolatileLru,
VolatileRandom,
VolatileTtl,
}Expand description
A string specifying the desired eviction policy for the Caching cluster.
noeviction: Don’t evict any data, returns error when memory limit is reached.allkeys-lru:Evict any key, least recently used (LRU) first.allkeys-random: Evict keys in a random order.volatile-lru: Evict keys with expiration only, least recently used (LRU) first.volatile-random: Evict keys with expiration only in a random order.volatile-ttl: Evict keys with expiration only, shortest time-to-live (TTL) first.
JSON schema
{
"description": "A string specifying the desired eviction policy for the Caching cluster.\n\n- `noeviction`: Don't evict any data, returns error when memory limit is reached.\n- `allkeys-lru:` Evict any key, least recently used (LRU) first.\n- `allkeys-random`: Evict keys in a random order.\n- `volatile-lru`: Evict keys with expiration only, least recently used (LRU) first.\n- `volatile-random`: Evict keys with expiration only in a random order.\n- `volatile-ttl`: Evict keys with expiration only, shortest time-to-live (TTL) first.",
"examples": [
"allkeys-lru"
],
"type": "string",
"enum": [
"noeviction",
"allkeys-lru",
"allkeys-random",
"volatile-lru",
"volatile-random",
"volatile-ttl"
]
}Variants