pub enum DatabasesListLogsinkResponseSinksItemConfigSubtype0Format {
Rfc5424,
Rfc3164,
Custom,
}Expand description
Message format used by the server, this can be either rfc3164 (the old BSD style message format), rfc5424 (current syslog message format) or custom
JSON schema
{
"description": "Message format used by the server, this can be either rfc3164 (the old BSD style message format), `rfc5424` (current syslog message format) or custom",
"examples": [
"rfc5424"
],
"type": "string",
"enum": [
"rfc5424",
"rfc3164",
"custom"
]
}Variants