pub enum DatabasesListReplicasResponseReplicasItemStatus {
Creating,
Online,
Resizing,
Migrating,
Forking,
}Expand description
A string representing the current status of the database cluster.
JSON schema
{
"description": "A string representing the current status of the database cluster.",
"readOnly": true,
"examples": [
"creating"
],
"type": "string",
"enum": [
"creating",
"online",
"resizing",
"migrating",
"forking"
]
}Variants