pub enum FloatingIPsGetResponseFloatingIpDropletSubtype1ImageDistribution {
Show 13 variants
ArchLinux,
CentOs,
CoreOs,
Debian,
Fedora,
FedoraAtomic,
FreeBsd,
Gentoo,
OpenSuse,
RancherOs,
RockyLinux,
Ubuntu,
Unknown,
}Expand description
The name of a custom image’s distribution. Currently, the valid values are Arch Linux, CentOS, CoreOS, Debian, Fedora, Fedora Atomic, FreeBSD, Gentoo, openSUSE, RancherOS, Rocky Linux, Ubuntu, and Unknown. Any other value will be accepted but ignored, and Unknown will be used in its place.
JSON schema
{
"description": "The name of a custom image's distribution. Currently, the valid values are `Arch Linux`, `CentOS`, `CoreOS`, `Debian`, `Fedora`, `Fedora Atomic`, `FreeBSD`, `Gentoo`, `openSUSE`, `RancherOS`, `Rocky Linux`, `Ubuntu`, and `Unknown`. Any other value will be accepted but ignored, and `Unknown` will be used in its place.",
"examples": [
"Ubuntu"
],
"type": "string",
"enum": [
"Arch Linux",
"CentOS",
"CoreOS",
"Debian",
"Fedora",
"Fedora Atomic",
"FreeBSD",
"Gentoo",
"openSUSE",
"RancherOS",
"Rocky Linux",
"Ubuntu",
"Unknown"
]
}Variants
ArchLinux
CentOs
CoreOs
Debian
Fedora
FedoraAtomic
FreeBsd
Gentoo
OpenSuse
RancherOs
RockyLinux
Ubuntu
Unknown