pub enum ImageActionsPostBodyVariant1Region {
Show 15 variants
Ams1,
Ams2,
Ams3,
Blr1,
Fra1,
Lon1,
Nyc1,
Nyc2,
Nyc3,
Sfo1,
Sfo2,
Sfo3,
Sgp1,
Tor1,
Syd1,
}Expand description
The slug identifier for the region where the resource will initially be available.
JSON schema
{
"description": "The slug identifier for the region where the resource will initially be available.",
"examples": [
"nyc3"
],
"type": "string",
"enum": [
"ams1",
"ams2",
"ams3",
"blr1",
"fra1",
"lon1",
"nyc1",
"nyc2",
"nyc3",
"sfo1",
"sfo2",
"sfo3",
"sgp1",
"tor1",
"syd1"
]
}Variants