pub enum KubernetesCreateClusterBodyStatusState {
Running,
Provisioning,
Degraded,
Error,
Deleted,
Upgrading,
Deleting,
}Expand description
A string indicating the current status of the cluster.
JSON schema
{
"description": "A string indicating the current status of the cluster.",
"examples": [
"provisioning"
],
"type": "string",
"enum": [
"running",
"provisioning",
"degraded",
"error",
"deleted",
"upgrading",
"deleting"
]
}Variants