pub enum LoadBalancersCreateResponseLoadBalancerNetwork {
External,
Internal,
}Expand description
A string indicating whether the load balancer should be external or internal. Internal load balancers have no public IPs and are only accessible to resources on the same VPC network. This property cannot be updated after creating the load balancer.
JSON schema
{
"description": "A string indicating whether the load balancer should be external or internal. Internal load balancers have no public IPs and are only accessible to resources on the same VPC network. This property cannot be updated after creating the load balancer.",
"default": "EXTERNAL",
"examples": [
"EXTERNAL"
],
"type": "string",
"enum": [
"EXTERNAL",
"INTERNAL"
]
}Variants