pub enum LoadBalancersRemoveForwardingRulesBodyForwardingRulesItemEntryProtocol {
Http,
Https,
Http2,
Http3,
Tcp,
Udp,
}Expand description
The protocol used for traffic to the load balancer. The possible values are: http, https, http2, http3, tcp, or udp. If you set the entry_protocol to udp, the target_protocol must be set to udp. When using UDP, the load balancer requires that you set up a health check with a port that uses TCP, HTTP, or HTTPS to work properly.
JSON schema
{
"description": "The protocol used for traffic to the load balancer. The possible values are: `http`, `https`, `http2`, `http3`, `tcp`, or `udp`. If you set the `entry_protocol` to `udp`, the `target_protocol` must be set to `udp`. When using UDP, the load balancer requires that you set up a health check with a port that uses TCP, HTTP, or HTTPS to work properly.\n",
"examples": [
"https"
],
"type": "string",
"enum": [
"http",
"https",
"http2",
"http3",
"tcp",
"udp"
]
}Variants