pub enum NfsCreateAccessPointBodyAccessPolicySquashConfig {
NoSquash,
RootSquash,
AllSquash,
}Expand description
The squash mode applied to the access point export.
JSON schema
{
"description": "The squash mode applied to the access point export.",
"examples": [
"ROOT_SQUASH"
],
"type": "string",
"enum": [
"NO_SQUASH",
"ROOT_SQUASH",
"ALL_SQUASH"
]
}Variants