pub enum ReservedIPsActionsPostBodyVariant1Type {
Assign,
Unassign,
}Expand description
The type of action to initiate for the reserved IP.
JSON schema
{
"description": "The type of action to initiate for the reserved IP.",
"type": "string",
"enum": [
"assign",
"unassign"
]
}Variants