pub enum SingleDropletResponseDropletImageStatus {
New,
Available,
Pending,
Deleted,
Retired,
}Expand description
A status string indicating the state of a custom image. This may be NEW,
available, pending, deleted, or retired.
JSON schema
{
"description": "A status string indicating the state of a custom image. This may be `NEW`,\n `available`, `pending`, `deleted`, or `retired`.",
"examples": [
"NEW"
],
"type": "string",
"enum": [
"NEW",
"available",
"pending",
"deleted",
"retired"
]
}Variants