pub enum UptimeUpdateAlertResponseAlertPeriod {
X2m,
X3m,
X5m,
X10m,
X15m,
X30m,
X1h,
}Expand description
Period of time the threshold must be exceeded to trigger the alert.
JSON schema
{
"description": "Period of time the threshold must be exceeded to trigger the alert.",
"examples": [
"2m"
],
"type": "string",
"enum": [
"2m",
"3m",
"5m",
"10m",
"15m",
"30m",
"1h"
]
}Variants