pub struct ActionsGetResponseActionRegion {
pub available: bool,
pub features: Vec<String>,
pub name: String,
pub sizes: Vec<String>,
pub slug: String,
}Expand description
ActionsGetResponseActionRegion
JSON schema
{
"type": "object",
"required": [
"available",
"features",
"name",
"sizes",
"slug"
],
"properties": {
"available": {
"description": "This is a boolean value that represents whether new Droplets can be created in this region.",
"examples": [
true
],
"type": "boolean"
},
"features": {
"description": "This attribute is set to an array which contains features available in this region",
"examples": [
[
"private_networking",
"backups",
"ipv6",
"metadata",
"install_agent",
"storage",
"image_transfer"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"name": {
"description": "The display name of the region. This will be a full name that is used in the control panel and other interfaces.",
"examples": [
"New York 3"
],
"type": "string"
},
"sizes": {
"description": "This attribute is set to an array which contains the identifying slugs for the sizes available in this region. sizes:read is required to view.",
"examples": [
[
"s-1vcpu-1gb",
"s-1vcpu-2gb",
"s-1vcpu-3gb",
"s-2vcpu-2gb",
"s-3vcpu-1gb",
"s-2vcpu-4gb",
"s-4vcpu-8gb",
"s-6vcpu-16gb",
"s-8vcpu-32gb",
"s-12vcpu-48gb",
"s-16vcpu-64gb",
"s-20vcpu-96gb",
"s-24vcpu-128gb",
"s-32vcpu-192g"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"slug": {
"description": "A human-readable string that is used as a unique identifier for each region.",
"examples": [
"nyc3"
],
"type": "string"
}
}
}Fields
available: boolThis is a boolean value that represents whether new Droplets can be created in this region.
features: Vec<String>This attribute is set to an array which contains features available in this region
name: StringThe display name of the region. This will be a full name that is used in the control panel and other interfaces.
sizes: Vec<String>This attribute is set to an array which contains the identifying slugs for the sizes available in this region. sizes:read is required to view.
slug: StringA human-readable string that is used as a unique identifier for each region.