pub struct AppSpecIngressRulesItemMatch {
pub authority: Option<AppSpecIngressRulesItemMatchAuthority>,
pub path: Option<AppSpecIngressRulesItemMatchPath>,
}Expand description
The match configuration for the rule.
JSON schema
{
"description": "The match configuration for the rule.",
"type": "object",
"properties": {
"authority": {
"description": "The authority to match on.",
"type": "object",
"required": [
"exact"
],
"properties": {
"exact": {
"description": "Exact string match. An empty string is a valid value and will be serialized explicitly rather than being omitted from the payload.",
"examples": [
"example.com"
],
"type": [
"string",
"null"
],
"maxLength": 256
}
}
},
"path": {
"description": "The path to match on.",
"type": "object",
"required": [
"prefix"
],
"properties": {
"prefix": {
"description": "Prefix-based match. For example, `/api` will match `/api`, `/api/`, and any nested paths such as `/api/v1/endpoint`.",
"examples": [
"/api"
],
"type": [
"string",
"null"
],
"maxLength": 256
}
}
}
}
}Fields
path: Option<AppSpecIngressRulesItemMatchPath>Trait Implementations
Sourceimpl Clone for AppSpecIngressRulesItemMatch
impl Clone for AppSpecIngressRulesItemMatch
Sourcefn clone(&self) -> AppSpecIngressRulesItemMatch
fn clone(&self) -> AppSpecIngressRulesItemMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AppSpecIngressRulesItemMatch
impl Debug for AppSpecIngressRulesItemMatch
Sourceimpl<'de> Deserialize<'de> for AppSpecIngressRulesItemMatch
impl<'de> Deserialize<'de> for AppSpecIngressRulesItemMatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&AppSpecIngressRulesItemMatch> for AppSpecIngressRulesItemMatch
impl From<&AppSpecIngressRulesItemMatch> for AppSpecIngressRulesItemMatch
Sourcefn from(value: &AppSpecIngressRulesItemMatch) -> Self
fn from(value: &AppSpecIngressRulesItemMatch) -> Self
Converts to this type from the input type.