pub struct AppSpecIngressRulesItemMatchAuthority {
pub exact: Option<AppSpecIngressRulesItemMatchAuthorityExact>,
}Expand description
The authority to match on.
JSON schema
{
"description": "The authority to match on.",
"type": "object",
"required": [
"exact"
],
"properties": {
"exact": {
"description": "Exact string match. An empty string is a valid value and will be serialized explicitly rather than being omitted from the payload.",
"examples": [
"example.com"
],
"type": [
"string",
"null"
],
"maxLength": 256
}
}
}Fields
exact: Option<AppSpecIngressRulesItemMatchAuthorityExact>Exact string match. An empty string is a valid value and will be serialized explicitly rather than being omitted from the payload.