pub struct AppSpecMaintenance {
pub archive: Option<bool>,
pub enabled: Option<bool>,
pub offline_page_url: Option<String>,
}Expand description
Specification to configure maintenance settings for the app, such as maintenance mode and archiving the app.
JSON schema
{
"description": "Specification to configure maintenance settings for the app, such as maintenance mode and archiving the app.",
"type": "object",
"properties": {
"archive": {
"description": "Indicates whether the app should be archived. Setting this to true implies that enabled is set to true.",
"examples": [
true
],
"type": "boolean"
},
"enabled": {
"description": "Indicates whether maintenance mode should be enabled for the app.",
"examples": [
true
],
"type": "boolean"
},
"offline_page_url": {
"description": "A custom offline page to display when maintenance mode is enabled or the app is archived.",
"examples": [
"https://example.com/offline.html"
],
"type": "string"
}
}
}Fields
archive: Option<bool>Indicates whether the app should be archived. Setting this to true implies that enabled is set to true.
enabled: Option<bool>Indicates whether maintenance mode should be enabled for the app.
offline_page_url: Option<String>A custom offline page to display when maintenance mode is enabled or the app is archived.