AppSpecStaticSitesItemEnvsItem

Struct AppSpecStaticSitesItemEnvsItem 

pub struct AppSpecStaticSitesItemEnvsItem {
    pub key: AppSpecStaticSitesItemEnvsItemKey,
    pub scope: AppSpecStaticSitesItemEnvsItemScope,
    pub type_: AppSpecStaticSitesItemEnvsItemType,
    pub value: Option<String>,
}
AppSpecStaticSitesItemEnvsItem

JSON schema
{
 "type": "object",
 "required": [
   "key"
 ],
 "properties": {
   "key": {
     "description": "The variable name",
     "examples": [
       "BASE_URL"
     ],
     "type": "string",
     "pattern": "^[_A-Za-z][_A-Za-z0-9]*$"
   },
   "scope": {
     "description": "- RUN_TIME: Made available only at run-time\n- BUILD_TIME: Made available only at build-time\n- RUN_AND_BUILD_TIME: Made available at both build and run-time",
     "default": "RUN_AND_BUILD_TIME",
     "examples": [
       "BUILD_TIME"
     ],
     "type": "string",
     "enum": [
       "UNSET",
       "RUN_TIME",
       "BUILD_TIME",
       "RUN_AND_BUILD_TIME"
     ]
   },
   "type": {
     "description": "- GENERAL: A plain-text environment variable\n- SECRET: A secret encrypted environment variable",
     "default": "GENERAL",
     "examples": [
       "GENERAL"
     ],
     "type": "string",
     "enum": [
       "GENERAL",
       "SECRET"
     ]
   },
   "value": {
     "description": "The value. If the type is `SECRET`, the value will be encrypted on first submission. On following submissions, the encrypted value should be used.",
     "examples": [
       "http://example.com"
     ],
     "type": "string"
   }
 }
}

Fields

key: AppSpecStaticSitesItemEnvsItemKey

The variable name

scope: AppSpecStaticSitesItemEnvsItemScope
  • RUN_TIME: Made available only at run-time
  • BUILD_TIME: Made available only at build-time
  • RUN_AND_BUILD_TIME: Made available at both build and run-time
type_: AppSpecStaticSitesItemEnvsItemType
  • GENERAL: A plain-text environment variable
  • SECRET: A secret encrypted environment variable
value: Option<String>

The value. If the type is SECRET, the value will be encrypted on first submission. On following submissions, the encrypted value should be used.