pub struct AppSpecStaticSitesItemGitlab {
pub branch: Option<String>,
pub deploy_on_push: Option<bool>,
pub repo: Option<String>,
}Expand description
AppSpecStaticSitesItemGitlab
JSON schema
{
"type": "object",
"properties": {
"branch": {
"description": "The name of the branch to use",
"examples": [
"main"
],
"type": "string"
},
"deploy_on_push": {
"description": "Whether to automatically deploy new commits made to the repo",
"examples": [
true
],
"type": "boolean"
},
"repo": {
"description": "The name of the repo in the format owner/repo. Example: `digitalocean/sample-golang`",
"examples": [
"digitalocean/sample-golang"
],
"type": "string"
}
}
}Fields
branch: Option<String>The name of the branch to use
deploy_on_push: Option<bool>Whether to automatically deploy new commits made to the repo
repo: Option<String>The name of the repo in the format owner/repo. Example: digitalocean/sample-golang