pub struct AppSpecWorkersItemAutoscaling {
pub max_instance_count: Option<NonZeroU32>,
pub metrics: Option<AppSpecWorkersItemAutoscalingMetrics>,
pub min_instance_count: Option<NonZeroU32>,
}Expand description
Configuration for automatically scaling this component based on metrics.
JSON schema
{
"description": "Configuration for automatically scaling this component based on metrics.",
"type": "object",
"properties": {
"max_instance_count": {
"description": "The maximum amount of instances for this component. Maximum 250. Consider using a larger instance size if your application requires more than 250 instances.",
"examples": [
3
],
"type": "integer",
"format": "uint32",
"maximum": 250.0,
"minimum": 1.0
},
"metrics": {
"description": "The metrics that the component is scaled on.",
"type": "object",
"properties": {
"cpu": {
"description": "Settings for scaling the component based on CPU utilization.",
"type": "object",
"properties": {
"percent": {
"description": "The average target CPU utilization for the component.",
"default": 80,
"examples": [
75
],
"type": "integer",
"format": "uint32",
"maximum": 100.0,
"minimum": 1.0
}
}
}
}
},
"min_instance_count": {
"description": "The minimum amount of instances for this component.",
"examples": [
2
],
"type": "integer",
"format": "uint32",
"minimum": 1.0
}
}
}Fields
max_instance_count: Option<NonZeroU32>The maximum amount of instances for this component. Maximum 250. Consider using a larger instance size if your application requires more than 250 instances.
metrics: Option<AppSpecWorkersItemAutoscalingMetrics>min_instance_count: Option<NonZeroU32>The minimum amount of instances for this component.