pub struct AppSpecWorkersItemImageDeployOnPush {
pub enabled: Option<bool>,
}Expand description
AppSpecWorkersItemImageDeployOnPush
JSON schema
{
"type": "object",
"properties": {
"enabled": {
"description": "Whether to automatically deploy new images. Can only be used for images hosted in DOCR and can only be used with an image tag, not a specific digest.",
"examples": [
true
],
"type": "boolean"
}
}
}Fields
enabled: Option<bool>Whether to automatically deploy new images. Can only be used for images hosted in DOCR and can only be used with an image tag, not a specific digest.