pub struct AppsGetInstancesResponse {
pub instances: Vec<AppsGetInstancesResponseInstancesItem>,
}Expand description
AppsGetInstancesResponse
JSON schema
{
"type": "object",
"properties": {
"instances": {
"type": "array",
"items": {
"type": "object",
"properties": {
"component_name": {
"description": "Name of the component, from the app spec.",
"examples": [
"sample-golang"
],
"type": "string"
},
"component_type": {
"description": "Supported compute component by DigitalOcean App Platform.",
"examples": [
"SERVICE"
],
"type": "string",
"enum": [
"SERVICE",
"WORKER",
"JOB"
]
},
"instance_alias": {
"description": "Readable identifier, an alias of the instance name, reference for mapping insights to instance names.",
"examples": [
"sample-golang-0"
],
"type": "string"
},
"instance_name": {
"description": "Name of the instance, which is a unique identifier for the instance.",
"examples": [
"sample-golang-76b84c7fb8-6p8kq"
],
"type": "string"
}
}
}
}
}
}Fields
instances: Vec<AppsGetInstancesResponseInstancesItem>Trait Implementations
Sourceimpl Clone for AppsGetInstancesResponse
impl Clone for AppsGetInstancesResponse
Sourcefn clone(&self) -> AppsGetInstancesResponse
fn clone(&self) -> AppsGetInstancesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AppsGetInstancesResponse
impl Debug for AppsGetInstancesResponse
Sourceimpl Default for AppsGetInstancesResponse
impl Default for AppsGetInstancesResponse
Sourceimpl<'de> Deserialize<'de> for AppsGetInstancesResponse
impl<'de> Deserialize<'de> for AppsGetInstancesResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&AppsGetInstancesResponse> for AppsGetInstancesResponse
impl From<&AppsGetInstancesResponse> for AppsGetInstancesResponse
Sourcefn from(value: &AppsGetInstancesResponse) -> Self
fn from(value: &AppsGetInstancesResponse) -> Self
Converts to this type from the input type.