pub struct AppsValidateRollbackResponseError {
pub code: Option<AppsValidateRollbackResponseErrorCode>,
pub components: Vec<String>,
pub message: Option<String>,
}Expand description
AppsValidateRollbackResponseError
JSON schema
{
"allOf": [
{
"description": "Contains the failing condition that is causing the rollback to be invalid."
},
{
"type": "object",
"properties": {
"code": {
"description": "A code identifier that represents the failing condition.\n\nFailing conditions:\n - `incompatible_phase` - indicates that the deployment's phase is not suitable for rollback.\n - `incompatible_result` - indicates that the deployment's result is not suitable for rollback.\n - `exceeded_revision_limit` - indicates that the app has exceeded the rollback revision limits for its tier.\n - `app_pinned` - indicates that there is already a rollback in progress and the app is pinned.\n - `database_config_conflict` - indicates that the deployment's database config is different than the current config.\n - `region_conflict` - indicates that the deployment's region differs from the current app region.\n \nWarning conditions:\n - `static_site_requires_rebuild` - indicates that the deployment contains at least one static site that will require a rebuild.\n - `image_source_missing_digest` - indicates that the deployment contains at least one component with an image source that is missing a digest.\n",
"examples": [
"exceeded_revision_limit"
],
"type": "string",
"enum": [
"incompatible_phase",
"incompatible_result",
"exceeded_revision_limit",
"app_pinned",
"database_config_conflict",
"region_conflict",
"static_site_requires_rebuild",
"image_source_missing_digest"
]
},
"components": {
"examples": [
[
"www"
]
],
"type": "array",
"items": {
"description": "If applicable, a list of components that are failing the condition.",
"type": "string"
}
},
"message": {
"description": "A human-readable message describing the failing condition.",
"examples": [
"the deployment is past the maximum historical revision limit of 0 for the \"starter\" app tier"
],
"type": "string"
}
}
}
]
}Fields
code: Option<AppsValidateRollbackResponseErrorCode>A code identifier that represents the failing condition.
Failing conditions:
incompatible_phase- indicates that the deployment’s phase is not suitable for rollback.incompatible_result- indicates that the deployment’s result is not suitable for rollback.exceeded_revision_limit- indicates that the app has exceeded the rollback revision limits for its tier.app_pinned- indicates that there is already a rollback in progress and the app is pinned.database_config_conflict- indicates that the deployment’s database config is different than the current config.region_conflict- indicates that the deployment’s region differs from the current app region.
Warning conditions:
static_site_requires_rebuild- indicates that the deployment contains at least one static site that will require a rebuild.image_source_missing_digest- indicates that the deployment contains at least one component with an image source that is missing a digest.
components: Vec<String>message: Option<String>A human-readable message describing the failing condition.