pub struct AssignDropletsByIdDomainsItem {
pub certificate_id: Option<String>,
pub is_managed: Option<bool>,
pub name: Option<String>,
}Expand description
An object specifying domain configurations for a Global load balancer.
JSON schema
{
"description": "An object specifying domain configurations for a Global load balancer.",
"type": "object",
"properties": {
"certificate_id": {
"description": "The ID of the TLS certificate used for SSL termination.",
"examples": [
"892071a0-bb95-49bc-8021-3afd67a210bf"
],
"type": "string"
},
"is_managed": {
"description": "A boolean value indicating if the domain is already managed by DigitalOcean. If true, all A and AAAA records required to enable Global load balancers will be automatically added.",
"examples": [
true
],
"type": "boolean"
},
"name": {
"description": "FQDN to associate with a Global load balancer.",
"examples": [
"example.com"
],
"type": "string"
}
}
}Fields
certificate_id: Option<String>The ID of the TLS certificate used for SSL termination.
is_managed: Option<bool>A boolean value indicating if the domain is already managed by DigitalOcean. If true, all A and AAAA records required to enable Global load balancers will be automatically added.
name: Option<String>FQDN to associate with a Global load balancer.