AutoscalepoolsUpdateResponseAutoscalePoolDropletTemplate

Struct AutoscalepoolsUpdateResponseAutoscalePoolDropletTemplate 

pub struct AutoscalepoolsUpdateResponseAutoscalePoolDropletTemplate {
    pub image: String,
    pub ipv6: Option<bool>,
    pub name: Option<String>,
    pub project_id: Option<String>,
    pub public_networking: bool,
    pub region: AutoscalepoolsUpdateResponseAutoscalePoolDropletTemplateRegion,
    pub size: String,
    pub ssh_keys: Vec<String>,
    pub tags: Vec<String>,
    pub user_data: Option<String>,
    pub vpc_uuid: Option<String>,
    pub with_droplet_agent: Option<bool>,
}
AutoscalepoolsUpdateResponseAutoscalePoolDropletTemplate

JSON schema
{
 "type": "object",
 "required": [
   "image",
   "region",
   "size",
   "ssh_keys"
 ],
 "properties": {
   "image": {
     "description": "The Droplet image to be used for all Droplets in the autoscale pool. You may specify the slug or the image ID.",
     "examples": [
       "ubuntu-20-04-x64"
     ],
     "type": "string"
   },
   "ipv6": {
     "description": "Assigns a unique IPv6 address to each of the Droplets in the autoscale pool.",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "name": {
     "description": "The name(s) to be applied to all Droplets in the autoscale pool.",
     "examples": [
       "my-droplet-name"
     ],
     "type": "string"
   },
   "project_id": {
     "description": "The project that the Droplets in the autoscale pool will belong to.\nRequires `project:read` scope.\n",
     "examples": [
       "746c6152-2fa2-11ed-92d3-27aaa54e4988"
     ],
     "type": "string"
   },
   "public_networking": {
     "description": "An optional boolean indicating whether the Droplets should be created with public networking or not. By default, all Droplets are created with public networking available. If explicitly set to `false`, only private networking will be enabled, and public networking will be disabled; currently this means that it will not have any public static or Reserved IPv4 or IPv6 address, nor can one be assigned later. If explicitly set to `false`, `ipv6` must also be `false`.",
     "default": true,
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "region": {
     "description": "The datacenter in which all of the Droplets will be created.",
     "examples": [
       "tor1"
     ],
     "type": "string",
     "enum": [
       "nyc1",
       "nyc2",
       "nyc3",
       "ams2",
       "ams3",
       "sfo1",
       "sfo2",
       "sfo3",
       "sgp1",
       "lon1",
       "fra1",
       "tor1",
       "blr1",
       "syd1"
     ]
   },
   "size": {
     "description": "The Droplet size to be used for all Droplets in the autoscale pool.",
     "examples": [
       "c-2"
     ],
     "type": "string"
   },
   "ssh_keys": {
     "description": "The SSH keys to be installed on the Droplets in the autoscale pool. You can either specify the key ID or the fingerprint.\nRequires `ssh_key:read` scope.\n",
     "examples": [
       [
         "88:66:90:d2:68:d5:b5:85:e3:26:26:11:31:57:e6:f8"
       ]
     ],
     "type": "array",
     "items": {
       "type": "string"
     }
   },
   "tags": {
     "description": "The tags to apply to each of the Droplets in the autoscale pool.\nRequires `tag:read` scope.\n",
     "examples": [
       [
         "my-tag"
       ]
     ],
     "type": "array",
     "items": {
       "type": "string"
     }
   },
   "user_data": {
     "description": "A string containing user data that cloud-init consumes to configure a Droplet on first boot. User data is often a cloud-config file or Bash script. It must be plain text and may not exceed 64 KiB in size.",
     "examples": [
       "#cloud-config\nruncmd:\n  - touch /test.txt\n"
     ],
     "type": "string"
   },
   "vpc_uuid": {
     "description": "The VPC where the Droplets in the autoscale pool will be created. The VPC must be in the region where you want to create the Droplets.\nRequires `vpc:read` scope.\n",
     "examples": [
       "760e09ef-dc84-11e8-981e-3cfdfeaae000"
     ],
     "type": "string"
   },
   "with_droplet_agent": {
     "description": "Installs the Droplet agent. This must be set to true to monitor Droplets for resource utilization scaling.",
     "examples": [
       true
     ],
     "type": "boolean"
   }
 }
}

Fields

image: String

The Droplet image to be used for all Droplets in the autoscale pool. You may specify the slug or the image ID.

ipv6: Option<bool>

Assigns a unique IPv6 address to each of the Droplets in the autoscale pool.

name: Option<String>

The name(s) to be applied to all Droplets in the autoscale pool.

project_id: Option<String>

The project that the Droplets in the autoscale pool will belong to. Requires project:read scope.

public_networking: bool

An optional boolean indicating whether the Droplets should be created with public networking or not. By default, all Droplets are created with public networking available. If explicitly set to false, only private networking will be enabled, and public networking will be disabled; currently this means that it will not have any public static or Reserved IPv4 or IPv6 address, nor can one be assigned later. If explicitly set to false, ipv6 must also be false.

region: AutoscalepoolsUpdateResponseAutoscalePoolDropletTemplateRegion

The datacenter in which all of the Droplets will be created.

size: String

The Droplet size to be used for all Droplets in the autoscale pool.

ssh_keys: Vec<String>

The SSH keys to be installed on the Droplets in the autoscale pool. You can either specify the key ID or the fingerprint. Requires ssh_key:read scope.

tags: Vec<String>

The tags to apply to each of the Droplets in the autoscale pool. Requires tag:read scope.

user_data: Option<String>

A string containing user data that cloud-init consumes to configure a Droplet on first boot. User data is often a cloud-config file or Bash script. It must be plain text and may not exceed 64 KiB in size.

vpc_uuid: Option<String>

The VPC where the Droplets in the autoscale pool will be created. The VPC must be in the region where you want to create the Droplets. Requires vpc:read scope.

with_droplet_agent: Option<bool>

Installs the Droplet agent. This must be set to true to monitor Droplets for resource utilization scaling.