pub struct CertificatesListResponse {
pub certificates: Vec<CertificatesListResponseCertificatesItem>,
pub links: Option<CertificatesListResponseLinks>,
pub meta: CertificatesListResponseMeta,
}Expand description
CertificatesListResponse
JSON schema
{
"allOf": [
{
"type": "object",
"properties": {
"certificates": {
"type": "array",
"items": {
"type": "object",
"properties": {
"created_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the certificate was created.",
"readOnly": true,
"examples": [
"2017-02-08T16:02:37Z"
],
"type": "string",
"format": "date-time"
},
"dns_names": {
"description": "An array of fully qualified domain names (FQDNs) for which the certificate was issued.",
"examples": [
[
"www.example.com",
"example.com"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"id": {
"description": "A unique ID that can be used to identify and reference a certificate.",
"readOnly": true,
"examples": [
"892071a0-bb95-49bc-8021-3afd67a210bf"
],
"type": "string",
"format": "uuid"
},
"name": {
"description": "A unique human-readable name referring to a certificate.",
"examples": [
"web-cert-01"
],
"type": "string"
},
"not_after": {
"description": "A time value given in ISO8601 combined date and time format that represents the certificate's expiration date.",
"readOnly": true,
"examples": [
"2017-02-22T00:23:00Z"
],
"type": "string",
"format": "date-time"
},
"sha1_fingerprint": {
"description": "A unique identifier generated from the SHA-1 fingerprint of the certificate.",
"readOnly": true,
"examples": [
"dfcc9f57d86bf58e321c2c6c31c7a971be244ac7"
],
"type": "string"
},
"state": {
"description": "A string representing the current state of the certificate. It may be `pending`, `verified`, or `error`.",
"readOnly": true,
"examples": [
"verified"
],
"type": "string",
"enum": [
"pending",
"verified",
"error"
]
},
"type": {
"description": "A string representing the type of the certificate. The value will be `custom` for a user-uploaded certificate or `lets_encrypt` for one automatically generated with Let's Encrypt.",
"examples": [
"lets_encrypt"
],
"type": "string",
"enum": [
"custom",
"lets_encrypt"
]
}
}
}
}
}
},
{
"type": "object",
"properties": {
"links": {
"type": "object",
"properties": {
"pages": {
"examples": [
{
"pages": {
"first": "https://api.digitalocean.com/v2/account/keys?page=1",
"prev": "https://api.digitalocean.com/v2/account/keys?page=2"
}
}
],
"anyOf": [
{
"type": "object",
"properties": {
"first": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
},
"last": {
"examples": [
"https://api.digitalocean.com/v2/images?page=3"
],
"type": "string",
"format": "uri"
},
"next": {
"examples": [
"https://api.digitalocean.com/v2/images?page=2"
],
"type": "string",
"format": "uri"
}
}
},
{
"type": "object",
"properties": {
"first": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
},
"last": {
"examples": [
"https://api.digitalocean.com/v2/images?page=3"
],
"type": "string",
"format": "uri"
},
"prev": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
}
}
},
{}
]
}
}
}
}
},
{
"type": "object",
"required": [
"meta"
],
"properties": {
"meta": {
"allOf": [
{
"description": "Information about the response itself.",
"type": "object",
"properties": {
"total": {
"description": "Number of objects returned by the request.",
"examples": [
1
],
"type": "integer"
}
}
},
{
"required": [
"total"
]
}
]
}
}
}
]
}Fields
certificates: Vec<CertificatesListResponseCertificatesItem>links: Option<CertificatesListResponseLinks>meta: CertificatesListResponseMetaTrait Implementations
Sourceimpl Clone for CertificatesListResponse
impl Clone for CertificatesListResponse
Sourcefn clone(&self) -> CertificatesListResponse
fn clone(&self) -> CertificatesListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CertificatesListResponse
impl Debug for CertificatesListResponse
Sourceimpl<'de> Deserialize<'de> for CertificatesListResponse
impl<'de> Deserialize<'de> for CertificatesListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&CertificatesListResponse> for CertificatesListResponse
impl From<&CertificatesListResponse> for CertificatesListResponse
Sourcefn from(value: &CertificatesListResponse) -> Self
fn from(value: &CertificatesListResponse) -> Self
Converts to this type from the input type.