pub struct DatabasesCreateClusterBodyAutoscaleStorage {
pub enabled: bool,
pub increment_gib: Option<i64>,
pub threshold_percent: Option<i64>,
}Expand description
DatabasesCreateClusterBodyAutoscaleStorage
JSON schema
{
"allOf": [
{
"description": "Configuration for database cluster storage autoscaling",
"type": "object",
"required": [
"enabled"
],
"properties": {
"enabled": {
"description": "Whether storage autoscaling is enabled for the cluster",
"examples": [
true
],
"type": "boolean"
},
"increment_gib": {
"description": "The amount of additional storage to add (in GiB) when autoscaling is triggered",
"examples": [
10
],
"type": "integer",
"maximum": 500.0,
"minimum": 10.0
},
"threshold_percent": {
"description": "The storage usage threshold percentage that triggers autoscaling. When storage usage exceeds this percentage, additional storage will be added automatically.",
"examples": [
80
],
"type": "integer",
"maximum": 95.0,
"minimum": 15.0
}
}
},
{
"description": "Storage autoscaling configuration"
}
]
}Fields
enabled: boolWhether storage autoscaling is enabled for the cluster
increment_gib: Option<i64>The amount of additional storage to add (in GiB) when autoscaling is triggered
threshold_percent: Option<i64>The storage usage threshold percentage that triggers autoscaling. When storage usage exceeds this percentage, additional storage will be added automatically.