pub struct DatabasesCreateClusterBodyMaintenanceWindow {
pub day: String,
pub description: Vec<String>,
pub hour: String,
pub pending: Option<bool>,
}Expand description
DatabasesCreateClusterBodyMaintenanceWindow
JSON schema
{
"type": "object",
"required": [
"day",
"hour"
],
"properties": {
"day": {
"description": "The day of the week on which to apply maintenance updates.",
"examples": [
"tuesday"
],
"type": "string"
},
"description": {
"description": "A list of strings, each containing information about a pending maintenance update.",
"readOnly": true,
"examples": [
[
"Update TimescaleDB to version 1.2.1",
"Upgrade to PostgreSQL 11.2 and 10.7 bugfix releases"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"hour": {
"description": "The hour in UTC at which maintenance updates will be applied in 24 hour format.",
"examples": [
"14:00"
],
"type": "string"
},
"pending": {
"description": "A boolean value indicating whether any maintenance is scheduled to be performed in the next window.",
"readOnly": true,
"examples": [
true
],
"type": "boolean"
}
}
}Fields
day: StringThe day of the week on which to apply maintenance updates.
description: Vec<String>A list of strings, each containing information about a pending maintenance update.
hour: StringThe hour in UTC at which maintenance updates will be applied in 24 hour format.
pending: Option<bool>A boolean value indicating whether any maintenance is scheduled to be performed in the next window.