pub struct DatabasesCreateClusterBodyRulesItem {
pub cluster_uuid: Option<DatabasesCreateClusterBodyRulesItemClusterUuid>,
pub created_at: Option<DateTime<Utc>>,
pub description: Option<String>,
pub type_: DatabasesCreateClusterBodyRulesItemType,
pub uuid: Option<DatabasesCreateClusterBodyRulesItemUuid>,
pub value: String,
}Expand description
DatabasesCreateClusterBodyRulesItem
JSON schema
{
"type": "object",
"required": [
"type",
"value"
],
"properties": {
"cluster_uuid": {
"description": "A unique ID for the database cluster to which the rule is applied.",
"readOnly": true,
"examples": [
"9cc10173-e9ea-4176-9dbc-a4cee4c4ff30"
],
"type": "string",
"pattern": "^$|[0-9a-f]{8}\\b-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-\\b[0-9a-f]{12}"
},
"created_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the firewall rule was created.",
"readOnly": true,
"examples": [
"2019-01-11T18:37:36Z"
],
"type": "string",
"format": "date-time"
},
"description": {
"description": "A human-readable description of the rule.",
"examples": [
"an IP address for local development"
],
"type": "string"
},
"type": {
"description": "The type of resource that the firewall rule allows to access the database cluster.",
"examples": [
"droplet"
],
"type": "string",
"enum": [
"droplet",
"k8s",
"ip_addr",
"tag",
"app"
]
},
"uuid": {
"description": "A unique ID for the firewall rule itself.",
"examples": [
"79f26d28-ea8a-41f2-8ad8-8cfcdd020095"
],
"type": "string",
"pattern": "^$|[0-9a-f]{8}\\b-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-\\b[0-9a-f]{12}"
},
"value": {
"description": "The ID of the specific resource, the name of a tag applied to a group of resources, or the IP address that the firewall rule allows to access the database cluster.",
"examples": [
"ff2a6c52-5a44-4b63-b99c-0e98e7a63d61"
],
"type": "string"
}
}
}Fields
cluster_uuid: Option<DatabasesCreateClusterBodyRulesItemClusterUuid>A unique ID for the database cluster to which the rule is applied.
created_at: Option<DateTime<Utc>>A time value given in ISO8601 combined date and time format that represents when the firewall rule was created.
description: Option<String>A human-readable description of the rule.
type_: DatabasesCreateClusterBodyRulesItemTypeThe type of resource that the firewall rule allows to access the database cluster.
uuid: Option<DatabasesCreateClusterBodyRulesItemUuid>A unique ID for the firewall rule itself.
value: StringThe ID of the specific resource, the name of a tag applied to a group of resources, or the IP address that the firewall rule allows to access the database cluster.