pub struct DatabasesGetClusterResponseDatabaseStandbyConnection {
pub database: Option<String>,
pub host: Option<String>,
pub password: Option<String>,
pub port: Option<i64>,
pub ssl: Option<bool>,
pub uri: Option<String>,
pub user: Option<String>,
}Expand description
DatabasesGetClusterResponseDatabaseStandbyConnection
JSON schema
{
"allOf": [
{
"type": "object",
"properties": {
"database": {
"description": "The name of the default database.",
"readOnly": true,
"examples": [
"defaultdb"
],
"type": "string"
},
"host": {
"description": "The FQDN pointing to the database cluster's current primary node.",
"readOnly": true,
"examples": [
"backend-do-user-19081923-0.db.ondigitalocean.com"
],
"type": "string"
},
"password": {
"description": "The randomly generated password for the default user.<br><br>Requires `database:view_credentials` scope.",
"readOnly": true,
"examples": [
"wv78n3zpz42xezdk"
],
"type": "string"
},
"port": {
"description": "The port on which the database cluster is listening.",
"readOnly": true,
"examples": [
25060
],
"type": "integer"
},
"ssl": {
"description": "A boolean value indicating if the connection should be made over SSL.",
"readOnly": true,
"examples": [
true
],
"type": "boolean"
},
"uri": {
"description": "A connection string in the format accepted by the `psql` command. This is provided as a convenience and should be able to be constructed by the other attributes.",
"readOnly": true,
"examples": [
"postgres://doadmin:wv78n3zpz42xezdk@backend-do-user-19081923-0.db.ondigitalocean.com:25060/defaultdb?sslmode=require"
],
"type": "string"
},
"user": {
"description": "The default user for the database.<br><br>Requires `database:view_credentials` scope.",
"readOnly": true,
"examples": [
"doadmin"
],
"type": "string"
}
}
},
{
"readOnly": true
}
]
}Fields
database: Option<String>The name of the default database.
host: Option<String>The FQDN pointing to the database cluster’s current primary node.
password: Option<String>The randomly generated password for the default user.
Requires database:view_credentials scope.
port: Option<i64>The port on which the database cluster is listening.
ssl: Option<bool>A boolean value indicating if the connection should be made over SSL.
uri: Option<String>A connection string in the format accepted by the psql command. This is provided as a convenience and should be able to be constructed by the other attributes.
user: Option<String>The default user for the database.
Requires database:view_credentials scope.