DatabasesGetConfigResponseConfigSubtype6

Struct DatabasesGetConfigResponseConfigSubtype6 

pub struct DatabasesGetConfigResponseConfigSubtype6 {
    pub default_read_concern: DatabasesGetConfigResponseConfigSubtype6DefaultReadConcern,
    pub default_write_concern: String,
    pub slow_op_threshold_ms: u64,
    pub transaction_lifetime_limit_seconds: NonZeroU64,
    pub verbosity: i64,
}
DatabasesGetConfigResponseConfigSubtype6

JSON schema
{
 "type": "object",
 "properties": {
   "default_read_concern": {
     "description": "Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value.  Learn more [here](https://www.mongodb.com/docs/manual/reference/read-concern/).",
     "default": "local",
     "examples": [
       "local"
     ],
     "type": "string",
     "enum": [
       "local",
       "available",
       "majority"
     ]
   },
   "default_write_concern": {
     "description": "Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either `majority` or a number `0...n` which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to `0` will request no acknowledgement of the write operation.  Learn more [here](https://www.mongodb.com/docs/manual/reference/write-concern/).",
     "default": "majority",
     "examples": [
       "majority"
     ],
     "type": "string"
   },
   "slow_op_threshold_ms": {
     "description": "Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs.  Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node.  *Changing this parameter will lead to a restart of the MongoDB service.* Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-operationProfiling.slowOpThresholdMs).",
     "default": 100,
     "examples": [
       200
     ],
     "type": "integer",
     "minimum": 0.0
   },
   "transaction_lifetime_limit_seconds": {
     "description": "Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be  aborted by a periodic cleanup process. The cleanup process runs every `transactionLifetimeLimitSeconds/2 seconds` or at least  once every 60 seconds. *Changing this parameter will lead to a restart of the MongoDB service.* Learn more [here](https://www.mongodb.com/docs/manual/reference/parameters/#mongodb-parameter-param.transactionLifetimeLimitSeconds).",
     "default": 60,
     "examples": [
       100
     ],
     "type": "integer",
     "minimum": 1.0
   },
   "verbosity": {
     "description": "The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1...5 increases the level to include debug messages. *Changing this parameter will lead to a restart of the MongoDB service.* Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-systemLog.verbosity).",
     "default": 0,
     "examples": [
       3
     ],
     "type": "integer",
     "maximum": 5.0,
     "minimum": 0.0
   }
 }
}

Fields

default_read_concern: DatabasesGetConfigResponseConfigSubtype6DefaultReadConcern

Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value. Learn more here.

default_write_concern: String

Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either majority or a number 0...n which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to 0 will request no acknowledgement of the write operation. Learn more here.

slow_op_threshold_ms: u64

Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs. Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node. Changing this parameter will lead to a restart of the MongoDB service. Learn more here.

transaction_lifetime_limit_seconds: NonZeroU64

Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be aborted by a periodic cleanup process. The cleanup process runs every transactionLifetimeLimitSeconds/2 seconds or at least once every 60 seconds. Changing this parameter will lead to a restart of the MongoDB service. Learn more here.

verbosity: i64

The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1…5 increases the level to include debug messages. Changing this parameter will lead to a restart of the MongoDB service. Learn more here.