pub struct DatabasesListClustersResponseDatabasesItemUsersItem {
pub access_cert: Option<String>,
pub access_key: Option<String>,
pub mysql_settings: Option<DatabasesListClustersResponseDatabasesItemUsersItemMysqlSettings>,
pub name: String,
pub password: Option<String>,
pub role: Option<DatabasesListClustersResponseDatabasesItemUsersItemRole>,
pub settings: Option<DatabasesListClustersResponseDatabasesItemUsersItemSettings>,
}Expand description
DatabasesListClustersResponseDatabasesItemUsersItem
JSON schema
{
"type": "object",
"required": [
"name"
],
"properties": {
"access_cert": {
"description": "Access certificate for TLS client authentication. (Kafka only)",
"readOnly": true,
"examples": [
"-----BEGIN CERTIFICATE-----\nMIIFFjCCA/6gAwIBAgISA0AznUJmXhu08/89ZuSPC/kRMA0GCSqGSIb3DQEBCwUA\nMEoxCzAJBgNVBAYTAlVTMRYwFAYDVQQKEw1MZXQncyBFbmNyeXB0MSMwIQYDVQQD\nExpMZXQncyBFbmNyeXB0IEF1dGhvcml0eSBYMzAeFw0xNjExMjQwMDIzMDBaFw0x\nNzAyMjIwMDIzMDBaMCQxIjAgBgNVBAMTGWNsb3VkLmFuZHJld3NvbWV0aGluZy5j\nb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDBIZMz8pnK6V52SVf+\nCYssOfCQHAx5f0Ou5rYbq3xNh8VWHIYJCQ1QxQIxKSP6+uODSYrb2KWyurP1DwGb\n8OYm0J3syEDtCUQik1cpCzpeNlAZ2f8FzXyYQAqPopxdRpsFz8DtZnVvu86XwrE4\noFPl9MReICmZfBNWylpV5qgFPoXyJ70ZAsTm3cEe3n+LBXEnY4YrVDRWxA3wZ2mz\nZ03HZ1hHrxK9CMnS829U+8sK+UneZpCO7yLRPuxwhmps0wpK/YuZZfRAKF1FZRna\nk/SIQ28rnWufmdg16YqqHgl5JOgnb3aslKRvL4dI2Gwnkd2IHtpZnTR0gxFXfqqb\nQwuRAgMBAAGjggIaMIICFjAOBgNVHQ8BAf8EBAMCBaAwHQYDVR0lBBYwFAYIKwYB\nBQUHAwEGCCsGAQUFBwMCMAwGA1UdEwEB/wQCMAAwHQYDVR0OBBYEFLsAFcxAhFX1\nMbCnzr9hEO5rL4jqMB8GA1UdIwQYMBaAFKhKamMEfd265tE5t6ZFZe/zqOyhMHAG\nCCsGAQUFBwEBBGQwYjAvBggrBgEFBQcwAYYjaHR0cDovL29jc3AuaW50LXgzLmxl\ndHNlbmNyeXB0Lm9yZy8wLwYIKwYBBQUHMAKGI2h0dHA6Ly9jZXJ0LmludC14My5s\nZXRzZW5jcnlwdC5vcmcvMCQGA1UdEQQdMBuCGWNsb3VkLmFuZHJld3NvbWV0aGlu\nZy5jb20wgf4GA1UdIASB9jCB8zAIBgZngQwBAgWrgeYGCysGAQQBgt8TAQEBMIHW\nMCYGCCsGAQUFBwIBFhpodHRwOi8vY3BzLmxldHNlbmNyeXB0Lm9yZzCBqwYIKwYB\nBQUHAgIwgZ4MgZtUaGlzIENlcnRpZmljYXRlIG1heSBvbmx5IGJlIHJlbGllZCB1\ncG9uIGJ5IFJlbHlpbmcgUGFydGllcyBhbmQgb25seSQ2ziBhY2NvcmRhbmNlIHdp\ndGggdGhlIENlcnRpZmljYXRlIFBvbGljeSBmb3VuZCBhdCBodHRwczovL2xldHNl\nbmNyeXB0Lm9yZy9yZXBvc2l0b3J5LzANBgkqhkiG9w0BAQsFAAOCAQEAOZVQvrjM\nPKXLARTjB5XsgfyDN3/qwLl7SmwGkPe+B+9FJpfScYG1JzVuCj/SoaPaK34G4x/e\niXwlwOXtMOtqjQYzNu2Pr2C+I+rVmaxIrCUXFmC205IMuUBEeWXG9Y/HvXQLPabD\nD3Gdl5+Feink9SDRP7G0HaAwq13hI7ARxkL9p+UIY39X0dV3WOboW2Re8nrkFXJ7\nq9Z6shK5QgpBfsLjtjNsQzaGV3ve1gOg25aTJGearBWOvEjJNA1wGMoKVXOtYwm/\nWyWoVdCQ8HmconcbJB6xc0UZ1EjvzRr5ZIvSa5uHZD0L3m7/kpPWlAlFJ7hHASPu\nUlF1zblDmg2Iaw==\n-----END CERTIFICATE-----"
],
"type": "string"
},
"access_key": {
"description": "Access key for TLS client authentication. (Kafka only)",
"readOnly": true,
"examples": [
"-----BEGIN PRIVATE KEY-----\nREDACTED-EXAMPLE-KEY\n-----END PRIVATE KEY-----"
],
"type": "string"
},
"mysql_settings": {
"type": "object",
"required": [
"auth_plugin"
],
"properties": {
"auth_plugin": {
"description": "A string specifying the authentication method to be used for connections\nto the MySQL user account. The valid values are `mysql_native_password`\nor `caching_sha2_password`. If excluded when creating a new user, the\ndefault for the version of MySQL in use will be used. As of MySQL 8.0, the\ndefault is `caching_sha2_password`.\n",
"examples": [
"mysql_native_password"
],
"type": "string",
"enum": [
"mysql_native_password",
"caching_sha2_password"
]
}
}
},
"name": {
"description": "The name of a database user.",
"examples": [
"app-01"
],
"type": "string"
},
"password": {
"description": "A randomly generated password for the database user.<br>Requires `database:view_credentials` scope.",
"readOnly": true,
"examples": [
"jge5lfxtzhx42iff"
],
"type": "string"
},
"role": {
"description": "A string representing the database user's role. The value will be either\n\"primary\" or \"normal\".\n",
"readOnly": true,
"examples": [
"normal"
],
"type": "string",
"enum": [
"primary",
"normal"
]
},
"settings": {
"type": "object",
"properties": {
"acl": {
"description": "ACLs (Access Control Lists) specifying permissions on topics within a Kafka cluster.",
"type": "array",
"items": {
"type": "object",
"required": [
"permission",
"topic"
],
"properties": {
"id": {
"description": "An identifier for the ACL. Will be computed after the ACL is created/updated.",
"examples": [
"aaa"
],
"type": "string"
},
"permission": {
"description": "Permission set applied to the ACL. 'consume' allows for messages to be consumed from the topic. 'produce' allows for messages to be published to the topic. 'produceconsume' allows for both 'consume' and 'produce' permission. 'admin' allows for 'produceconsume' as well as any operations to administer the topic (delete, update).",
"examples": [
"consume"
],
"type": "string",
"enum": [
"admin",
"consume",
"produce",
"produceconsume"
]
},
"topic": {
"description": "A regex for matching the topic(s) that this ACL should apply to.",
"examples": [
"topic-abc.*"
],
"type": "string"
}
}
}
},
"mongo_user_settings": {
"description": "MongoDB-specific settings for the user. This option is not currently supported for other database engines.",
"type": "object",
"properties": {
"databases": {
"description": "A list of databases to which the user should have access. When the database is set to `admin`, the user will have access to all databases based on the user's role i.e. a user with the role `readOnly` assigned to the `admin` database will have read access to all databases.",
"examples": [
[
"my-db",
"my-db-2"
]
],
"type": "array",
"items": {
"examples": [
"my-db"
],
"type": "string"
}
},
"role": {
"description": "The role to assign to the user with each role mapping to a MongoDB built-in role. `readOnly` maps to a [read](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-read) role. `readWrite` maps to a [readWrite](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-readWrite) role. `dbAdmin` maps to a [dbAdmin](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-dbAdmin) role.",
"examples": [
"readOnly"
],
"type": "string",
"enum": [
"readOnly",
"readWrite",
"dbAdmin"
]
}
}
},
"opensearch_acl": {
"description": "ACLs (Access Control Lists) specifying permissions on index within a OpenSearch cluster.",
"type": "array",
"items": {
"type": "object",
"properties": {
"index": {
"description": "A regex for matching the indexes that this ACL should apply to.",
"examples": [
"index-abc.*"
],
"type": "string"
},
"permission": {
"description": "Permission set applied to the ACL. 'read' allows user to read from the index. 'write' allows for user to write to the index. 'readwrite' allows for both 'read' and 'write' permission. 'deny'(default) restricts user from performing any operation over an index. 'admin' allows for 'readwrite' as well as any operations to administer the index.",
"examples": [
"read"
],
"type": "string",
"enum": [
"deny",
"admin",
"read",
"readwrite",
"write"
]
}
}
}
},
"pg_allow_replication": {
"description": "For PostgreSQL clusters, set to `true` to grant the user replication\nprivileges. When omitted on create or update, the value defaults to\n`false` and replication privileges are not granted. This option is not\ncurrently supported for other database engines.\n",
"examples": [
true
],
"type": "boolean"
}
}
}
}
}Fields
access_cert: Option<String>Access certificate for TLS client authentication. (Kafka only)
access_key: Option<String>Access key for TLS client authentication. (Kafka only)
mysql_settings: Option<DatabasesListClustersResponseDatabasesItemUsersItemMysqlSettings>name: StringThe name of a database user.
password: Option<String>A randomly generated password for the database user.
Requires database:view_credentials scope.
role: Option<DatabasesListClustersResponseDatabasesItemUsersItemRole>A string representing the database user’s role. The value will be either “primary” or “normal”.
settings: Option<DatabasesListClustersResponseDatabasesItemUsersItemSettings>Trait Implementations
Sourceimpl Clone for DatabasesListClustersResponseDatabasesItemUsersItem
impl Clone for DatabasesListClustersResponseDatabasesItemUsersItem
Sourcefn clone(&self) -> DatabasesListClustersResponseDatabasesItemUsersItem
fn clone(&self) -> DatabasesListClustersResponseDatabasesItemUsersItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DatabasesListClustersResponseDatabasesItemUsersItem
impl<'de> Deserialize<'de> for DatabasesListClustersResponseDatabasesItemUsersItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&DatabasesListClustersResponseDatabasesItemUsersItem> for DatabasesListClustersResponseDatabasesItemUsersItem
impl From<&DatabasesListClustersResponseDatabasesItemUsersItem> for DatabasesListClustersResponseDatabasesItemUsersItem
Sourcefn from(value: &DatabasesListClustersResponseDatabasesItemUsersItem) -> Self
fn from(value: &DatabasesListClustersResponseDatabasesItemUsersItem) -> Self
Converts to this type from the input type.