pub struct DatabasesListOptionsResponseOptions {
pub advanced_mysql: Option<DatabasesListOptionsResponseOptionsAdvancedMysql>,
pub advanced_pg: Option<DatabasesListOptionsResponseOptionsAdvancedPg>,
pub kafka: Option<DatabasesListOptionsResponseOptionsKafka>,
pub mongodb: Option<DatabasesListOptionsResponseOptionsMongodb>,
pub mysql: Option<DatabasesListOptionsResponseOptionsMysql>,
pub opensearch: Option<DatabasesListOptionsResponseOptionsOpensearch>,
pub pg: Option<DatabasesListOptionsResponseOptionsPg>,
pub redis: Option<DatabasesListOptionsResponseOptionsRedis>,
pub valkey: Option<DatabasesListOptionsResponseOptionsValkey>,
}Expand description
DatabasesListOptionsResponseOptions
JSON schema
{
"type": "object",
"properties": {
"advanced_mysql": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
},
"advanced_pg": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
},
"kafka": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
},
"mongodb": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
},
"mysql": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
},
"opensearch": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
},
"pg": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
},
"redis": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
},
"valkey": {
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
}
}
}Fields
advanced_mysql: Option<DatabasesListOptionsResponseOptionsAdvancedMysql>advanced_pg: Option<DatabasesListOptionsResponseOptionsAdvancedPg>kafka: Option<DatabasesListOptionsResponseOptionsKafka>mongodb: Option<DatabasesListOptionsResponseOptionsMongodb>mysql: Option<DatabasesListOptionsResponseOptionsMysql>opensearch: Option<DatabasesListOptionsResponseOptionsOpensearch>pg: Option<DatabasesListOptionsResponseOptionsPg>redis: Option<DatabasesListOptionsResponseOptionsRedis>valkey: Option<DatabasesListOptionsResponseOptionsValkey>Trait Implementations
Sourceimpl Clone for DatabasesListOptionsResponseOptions
impl Clone for DatabasesListOptionsResponseOptions
Sourcefn clone(&self) -> DatabasesListOptionsResponseOptions
fn clone(&self) -> DatabasesListOptionsResponseOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DatabasesListOptionsResponseOptions
impl<'de> Deserialize<'de> for DatabasesListOptionsResponseOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&DatabasesListOptionsResponseOptions> for DatabasesListOptionsResponseOptions
impl From<&DatabasesListOptionsResponseOptions> for DatabasesListOptionsResponseOptions
Sourcefn from(value: &DatabasesListOptionsResponseOptions) -> Self
fn from(value: &DatabasesListOptionsResponseOptions) -> Self
Converts to this type from the input type.