pub struct DatabasesListOptionsResponseOptionsPg {
pub layouts: Vec<DatabasesListOptionsResponseOptionsPgLayoutsItem>,
pub regions: Vec<String>,
pub versions: Vec<String>,
}Expand description
DatabasesListOptionsResponseOptionsPg
JSON schema
{
"allOf": [
{
"type": "object",
"properties": {
"regions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"ams3",
"blr1"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"versions": {
"description": "An array of strings containing the names of available regions",
"readOnly": true,
"examples": [
[
"4.4",
"5.0"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
},
{
"type": "object",
"properties": {
"layouts": {
"description": "An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node's identifier, CPU, and RAM (in that order).",
"readOnly": true,
"type": "array",
"items": {
"type": "object",
"properties": {
"num_nodes": {
"examples": [
1
],
"type": "integer"
},
"sizes": {
"description": "An array of objects containing the slugs available with various node counts",
"readOnly": true,
"examples": [
[
"db-s-1vcpu-1gb",
"db-s-1vcpu-2gb"
]
],
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
}
]
}Fields
layouts: Vec<DatabasesListOptionsResponseOptionsPgLayoutsItem>An array of objects, each indicating the node sizes (otherwise referred to as slugs) that are available with various numbers of nodes in the database cluster. Each slugs denotes the node’s identifier, CPU, and RAM (in that order).
regions: Vec<String>An array of strings containing the names of available regions
versions: Vec<String>An array of strings containing the names of available regions