DatabasesListOptionsResponseVersionAvailabilityMongodbItem

Struct DatabasesListOptionsResponseVersionAvailabilityMongodbItem 

pub struct DatabasesListOptionsResponseVersionAvailabilityMongodbItem {
    pub end_of_availability: Option<String>,
    pub end_of_life: Option<String>,
    pub version: Option<String>,
}
DatabasesListOptionsResponseVersionAvailabilityMongodbItem

JSON schema
{
 "type": "object",
 "properties": {
   "end_of_availability": {
     "description": "A timestamp referring to the date when the particular version will no longer be available for creating new clusters. If null, the version does not have an end of availability timeline.",
     "examples": [
       "2023-05-09T00:00:00Z"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "end_of_life": {
     "description": "A timestamp referring to the date when the particular version will no longer be supported. If null, the version does not have an end of life timeline.",
     "examples": [
       "2023-11-09T00:00:00Z"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "version": {
     "description": "The engine version.",
     "examples": [
       "8"
     ],
     "type": "string"
   }
 }
}

Fields

end_of_availability: Option<String>

A timestamp referring to the date when the particular version will no longer be available for creating new clusters. If null, the version does not have an end of availability timeline.

end_of_life: Option<String>

A timestamp referring to the date when the particular version will no longer be supported. If null, the version does not have an end of life timeline.

version: Option<String>

The engine version.