DatabasesListUsersResponseUsersItemSettings

Struct DatabasesListUsersResponseUsersItemSettings 

pub struct DatabasesListUsersResponseUsersItemSettings {
    pub acl: Vec<DatabasesListUsersResponseUsersItemSettingsAclItem>,
    pub mongo_user_settings: Option<DatabasesListUsersResponseUsersItemSettingsMongoUserSettings>,
    pub opensearch_acl: Vec<DatabasesListUsersResponseUsersItemSettingsOpensearchAclItem>,
    pub pg_allow_replication: Option<bool>,
}
DatabasesListUsersResponseUsersItemSettings

JSON schema
{
 "type": "object",
 "properties": {
   "acl": {
     "description": "ACLs (Access Control Lists) specifying permissions on topics within a Kafka cluster.",
     "type": "array",
     "items": {
       "type": "object",
       "required": [
         "permission",
         "topic"
       ],
       "properties": {
         "id": {
           "description": "An identifier for the ACL. Will be computed after the ACL is created/updated.",
           "examples": [
             "aaa"
           ],
           "type": "string"
         },
         "permission": {
           "description": "Permission set applied to the ACL. 'consume' allows for messages to be consumed from the topic. 'produce' allows for messages to be published to the topic. 'produceconsume' allows for both 'consume' and 'produce' permission. 'admin' allows for 'produceconsume' as well as any operations to administer the topic (delete, update).",
           "examples": [
             "consume"
           ],
           "type": "string",
           "enum": [
             "admin",
             "consume",
             "produce",
             "produceconsume"
           ]
         },
         "topic": {
           "description": "A regex for matching the topic(s) that this ACL should apply to.",
           "examples": [
             "topic-abc.*"
           ],
           "type": "string"
         }
       }
     }
   },
   "mongo_user_settings": {
     "description": "MongoDB-specific settings for the user. This option is not currently supported for other database engines.",
     "type": "object",
     "properties": {
       "databases": {
         "description": "A list of databases to which the user should have access. When the database is set to `admin`, the user will have access to all databases based on the user's role i.e. a user with the role `readOnly` assigned to the `admin` database will have read access to all databases.",
         "examples": [
           [
             "my-db",
             "my-db-2"
           ]
         ],
         "type": "array",
         "items": {
           "examples": [
             "my-db"
           ],
           "type": "string"
         }
       },
       "role": {
         "description": "The role to assign to the user with each role mapping to a MongoDB built-in role.  `readOnly` maps to a [read](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-read) role. `readWrite` maps to a [readWrite](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-readWrite) role. `dbAdmin` maps to a [dbAdmin](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-dbAdmin) role.",
         "examples": [
           "readOnly"
         ],
         "type": "string",
         "enum": [
           "readOnly",
           "readWrite",
           "dbAdmin"
         ]
       }
     }
   },
   "opensearch_acl": {
     "description": "ACLs (Access Control Lists) specifying permissions on index within a OpenSearch cluster.",
     "type": "array",
     "items": {
       "type": "object",
       "properties": {
         "index": {
           "description": "A regex for matching the indexes that this ACL should apply to.",
           "examples": [
             "index-abc.*"
           ],
           "type": "string"
         },
         "permission": {
           "description": "Permission set applied to the ACL. 'read' allows user to read from the index. 'write' allows for user to write to the index. 'readwrite' allows for both 'read' and 'write' permission. 'deny'(default) restricts user from performing any operation over an index. 'admin' allows for 'readwrite' as well as any operations to administer the index.",
           "examples": [
             "read"
           ],
           "type": "string",
           "enum": [
             "deny",
             "admin",
             "read",
             "readwrite",
             "write"
           ]
         }
       }
     }
   },
   "pg_allow_replication": {
     "description": "For PostgreSQL clusters, set to `true` to grant the user replication\nprivileges. When omitted on create or update, the value defaults to\n`false` and replication privileges are not granted. This option is not\ncurrently supported for other database engines.\n",
     "examples": [
       true
     ],
     "type": "boolean"
   }
 }
}

Fields

acl: Vec<DatabasesListUsersResponseUsersItemSettingsAclItem>

ACLs (Access Control Lists) specifying permissions on topics within a Kafka cluster.

mongo_user_settings: Option<DatabasesListUsersResponseUsersItemSettingsMongoUserSettings>opensearch_acl: Vec<DatabasesListUsersResponseUsersItemSettingsOpensearchAclItem>

ACLs (Access Control Lists) specifying permissions on index within a OpenSearch cluster.

pg_allow_replication: Option<bool>

For PostgreSQL clusters, set to true to grant the user replication privileges. When omitted on create or update, the value defaults to false and replication privileges are not granted. This option is not currently supported for other database engines.