DatabasesPatchConfigBodyConfigSubtype1Timescaledb

Struct DatabasesPatchConfigBodyConfigSubtype1Timescaledb 

pub struct DatabasesPatchConfigBodyConfigSubtype1Timescaledb {
    pub max_background_workers: Option<NonZeroU64>,
}
TimescaleDB extension configuration values

JSON schema
{
 "description": "TimescaleDB extension configuration values",
 "type": "object",
 "properties": {
   "max_background_workers": {
     "description": "The number of background workers for timescaledb operations.  Set to the sum of your number of databases and the total number of concurrent background workers you want running at any given point in time.",
     "examples": [
       8
     ],
     "type": "integer",
     "maximum": 4096.0,
     "minimum": 1.0
   }
 }
}

Fields

max_background_workers: Option<NonZeroU64>

The number of background workers for timescaledb operations. Set to the sum of your number of databases and the total number of concurrent background workers you want running at any given point in time.