pub struct DatabasesResetAuthResponseUserSettingsAclItem {
pub id: Option<String>,
pub permission: DatabasesResetAuthResponseUserSettingsAclItemPermission,
pub topic: String,
}Expand description
DatabasesResetAuthResponseUserSettingsAclItem
JSON schema
{
"type": "object",
"required": [
"permission",
"topic"
],
"properties": {
"id": {
"description": "An identifier for the ACL. Will be computed after the ACL is created/updated.",
"examples": [
"aaa"
],
"type": "string"
},
"permission": {
"description": "Permission set applied to the ACL. 'consume' allows for messages to be consumed from the topic. 'produce' allows for messages to be published to the topic. 'produceconsume' allows for both 'consume' and 'produce' permission. 'admin' allows for 'produceconsume' as well as any operations to administer the topic (delete, update).",
"examples": [
"consume"
],
"type": "string",
"enum": [
"admin",
"consume",
"produce",
"produceconsume"
]
},
"topic": {
"description": "A regex for matching the topic(s) that this ACL should apply to.",
"examples": [
"topic-abc.*"
],
"type": "string"
}
}
}Fields
id: Option<String>An identifier for the ACL. Will be computed after the ACL is created/updated.
permission: DatabasesResetAuthResponseUserSettingsAclItemPermissionPermission set applied to the ACL. ‘consume’ allows for messages to be consumed from the topic. ‘produce’ allows for messages to be published to the topic. ‘produceconsume’ allows for both ‘consume’ and ‘produce’ permission. ‘admin’ allows for ‘produceconsume’ as well as any operations to administer the topic (delete, update).
topic: StringA regex for matching the topic(s) that this ACL should apply to.