pub struct DatabasesUpdateFirewallRulesBody {
pub rules: Vec<DatabasesUpdateFirewallRulesBodyRulesItem>,
}Expand description
DatabasesUpdateFirewallRulesBody
JSON schema
{
"type": "object",
"properties": {
"rules": {
"type": "array",
"items": {
"type": "object",
"required": [
"type",
"value"
],
"properties": {
"cluster_uuid": {
"description": "A unique ID for the database cluster to which the rule is applied.",
"readOnly": true,
"examples": [
"9cc10173-e9ea-4176-9dbc-a4cee4c4ff30"
],
"type": "string",
"pattern": "^$|[0-9a-f]{8}\\b-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-\\b[0-9a-f]{12}"
},
"created_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the firewall rule was created.",
"readOnly": true,
"examples": [
"2019-01-11T18:37:36Z"
],
"type": "string",
"format": "date-time"
},
"description": {
"description": "A human-readable description of the rule.",
"examples": [
"an IP address for local development"
],
"type": "string"
},
"type": {
"description": "The type of resource that the firewall rule allows to access the database cluster.",
"examples": [
"droplet"
],
"type": "string",
"enum": [
"droplet",
"k8s",
"ip_addr",
"tag",
"app"
]
},
"uuid": {
"description": "A unique ID for the firewall rule itself.",
"examples": [
"79f26d28-ea8a-41f2-8ad8-8cfcdd020095"
],
"type": "string",
"pattern": "^$|[0-9a-f]{8}\\b-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-\\b[0-9a-f]{12}"
},
"value": {
"description": "The ID of the specific resource, the name of a tag applied to a group of resources, or the IP address that the firewall rule allows to access the database cluster.",
"examples": [
"ff2a6c52-5a44-4b63-b99c-0e98e7a63d61"
],
"type": "string"
}
}
}
}
}
}Fields
rules: Vec<DatabasesUpdateFirewallRulesBodyRulesItem>Trait Implementations
Sourceimpl Clone for DatabasesUpdateFirewallRulesBody
impl Clone for DatabasesUpdateFirewallRulesBody
Sourcefn clone(&self) -> DatabasesUpdateFirewallRulesBody
fn clone(&self) -> DatabasesUpdateFirewallRulesBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DatabasesUpdateFirewallRulesBody
impl<'de> Deserialize<'de> for DatabasesUpdateFirewallRulesBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&DatabasesUpdateFirewallRulesBody> for DatabasesUpdateFirewallRulesBody
impl From<&DatabasesUpdateFirewallRulesBody> for DatabasesUpdateFirewallRulesBody
Sourcefn from(value: &DatabasesUpdateFirewallRulesBody) -> Self
fn from(value: &DatabasesUpdateFirewallRulesBody) -> Self
Converts to this type from the input type.