DatabasesUpdateKafkaTopicResponse

Struct DatabasesUpdateKafkaTopicResponse 

pub struct DatabasesUpdateKafkaTopicResponse {
    pub topic: Option<DatabasesUpdateKafkaTopicResponseTopic>,
}
DatabasesUpdateKafkaTopicResponse

JSON schema
{
 "properties": {
   "topic": {
     "type": "object",
     "properties": {
       "config": {
         "type": "object",
         "properties": {
           "cleanup_policy": {
             "description": "The cleanup_policy sets the retention policy to use on log segments. 'delete' will discard old segments when retention time/size limits are reached. 'compact' will enable log compaction, resulting in retention of the latest value for each key.",
             "default": "delete",
             "examples": [
               "delete"
             ],
             "type": "string",
             "enum": [
               "delete",
               "compact",
               "compact_delete"
             ]
           },
           "compression_type": {
             "description": "The compression_type specifies the compression type of the topic.",
             "default": "producer",
             "examples": [
               "producer"
             ],
             "type": "string",
             "enum": [
               "producer",
               "gzip",
               "snappy",
               "Iz4",
               "zstd",
               "uncompressed"
             ]
           },
           "delete_retention_ms": {
             "description": "The delete_retention_ms specifies how long (in ms) to retain delete tombstone markers for topics.",
             "default": 86400000,
             "examples": [
               86400000
             ],
             "type": "integer"
           },
           "file_delete_delay_ms": {
             "description": "The file_delete_delay_ms specifies the time (in ms) to wait before deleting a file from the filesystem.",
             "default": 60000,
             "examples": [
               60000
             ],
             "type": "integer"
           },
           "flush_messages": {
             "description": "The flush_messages specifies the number of messages to accumulate on a log partition before messages are flushed to disk.",
             "default": 9223372036854776000,
             "examples": [
               9223372036854776000
             ],
             "type": "integer"
           },
           "flush_ms": {
             "description": "The flush_ms specifies the maximum time (in ms) that a message is kept in memory before being flushed to disk.",
             "default": 9223372036854776000,
             "examples": [
               9223372036854776000
             ],
             "type": "integer"
           },
           "index_interval_bytes": {
             "description": "The index_interval_bytes specifies the number of bytes between entries being added into te offset index.",
             "default": 4096,
             "examples": [
               4096
             ],
             "type": "integer"
           },
           "max_compaction_lag_ms": {
             "description": "The max_compaction_lag_ms specifies the maximum amount of time (in ms) that a message will remain uncompacted. This is only applicable if the logs are have compaction enabled.",
             "default": 9223372036854776000,
             "examples": [
               9223372036854776000
             ],
             "type": "integer"
           },
           "max_message_bytes": {
             "description": "The max_messages_bytes specifies the largest record batch size (in bytes) that can be sent to the server.  This is calculated after compression if compression is enabled.",
             "default": 1048588,
             "examples": [
               1048588
             ],
             "type": "integer"
           },
           "message_down_conversion_enable": {
             "description": "The message_down_conversion_enable specifies whether down-conversion of message formats is enabled to satisfy consumer requests. When 'false', the broker will not perform conversion for consumers expecting older message formats. The broker will respond with an `UNSUPPORTED_VERSION` error for consume requests from these older clients.",
             "default": true,
             "examples": [
               true
             ],
             "type": "boolean"
           },
           "message_format_version": {
             "description": "The message_format_version specifies the message format version used by the broker to append messages to the logs. The value of this setting is assumed to be 3.0-IV1 if the broker protocol version is 3.0 or higher. By setting a  particular message format version, all existing messages on disk must be smaller or equal to the specified version.",
             "default": "3.0-IV1",
             "examples": [
               "3.0-IV1"
             ],
             "type": "string",
             "enum": [
               "0.8.0",
               "0.8.1",
               "0.8.2",
               "0.9.0",
               "0.10.0-IV0",
               "0.10.0-IV1",
               "0.10.1-IV0",
               "0.10.1-IV1",
               "0.10.1-IV2",
               "0.10.2-IV0",
               "0.11.0-IV0",
               "0.11.0-IV1",
               "0.11.0-IV2",
               "1.0-IV0",
               "1.1-IV0",
               "2.0-IV0",
               "2.0-IV1",
               "2.1-IV0",
               "2.1-IV1",
               "2.1-IV2",
               "2.2-IV0",
               "2.2-IV1",
               "2.3-IV0",
               "2.3-IV1",
               "2.4-IV0",
               "2.4-IV1",
               "2.5-IV0",
               "2.6-IV0",
               "2.7-IV0",
               "2.7-IV1",
               "2.7-IV2",
               "2.8-IV0",
               "2.8-IV1",
               "3.0-IV0",
               "3.0-IV1",
               "3.1-IV0",
               "3.2-IV0",
               "3.3-IV0",
               "3.3-IV1",
               "3.3-IV2",
               "3.3-IV3"
             ]
           },
           "message_timestamp_type": {
             "description": "The message_timestamp_type specifies whether to use the message create time or log append time as the timestamp on a message.",
             "default": "create_time",
             "examples": [
               "create_time"
             ],
             "type": "string",
             "enum": [
               "create_time",
               "log_append_time"
             ]
           },
           "min_cleanable_dirty_ratio": {
             "description": "The min_cleanable_dirty_ratio specifies the frequency of log compaction (if enabled) in relation to duplicates present in the logs. For example, at 0.5, at most 50% of the log could be duplicates before compaction would begin.",
             "default": 0.5,
             "examples": [
               0.5
             ],
             "type": "number",
             "format": "float",
             "maximum": 1.0,
             "minimum": 0.0
           },
           "min_compaction_lag_ms": {
             "description": "The min_compaction_lag_ms specifies the minimum time (in ms) that a message will remain uncompacted in the log. Only relevant if log compaction is enabled.",
             "default": 0,
             "examples": [
               0
             ],
             "type": "integer"
           },
           "min_insync_replicas": {
             "description": "The min_insync_replicas specifies the number of replicas that must ACK a write for the write to be considered successful.",
             "default": 1,
             "examples": [
               1
             ],
             "type": "integer",
             "minimum": 1.0
           },
           "preallocate": {
             "description": "The preallocate specifies whether a file should be preallocated on disk when creating a new log segment.",
             "default": false,
             "examples": [
               false
             ],
             "type": "boolean"
           },
           "retention_bytes": {
             "description": "The retention_bytes specifies the maximum size of the log (in bytes) before deleting messages. -1 indicates that there is no limit.",
             "default": -1,
             "examples": [
               1000000
             ],
             "type": "integer"
           },
           "retention_ms": {
             "description": "The retention_ms specifies the maximum amount of time (in ms) to keep a message before deleting it.",
             "default": 604800000,
             "examples": [
               604800000
             ],
             "type": "integer"
           },
           "segment_bytes": {
             "description": "The segment_bytes specifies the maximum size of a single log file (in bytes).",
             "default": 209715200,
             "examples": [
               209715200
             ],
             "type": "integer",
             "minimum": 14.0
           },
           "segment_jitter_ms": {
             "description": "The segment_jitter_ms specifies the maximum random jitter subtracted from the scheduled segment roll time to avoid thundering herds of segment rolling.",
             "default": 0,
             "examples": [
               0
             ],
             "type": "integer"
           },
           "segment_ms": {
             "description": "The segment_ms specifies the period of time after which the log will be forced to roll if the segment file isn't full. This ensures that retention can delete or compact old data.",
             "default": 604800000,
             "examples": [
               604800000
             ],
             "type": "integer",
             "minimum": 1.0
           }
         }
       },
       "name": {
         "description": "The name of the Kafka topic.",
         "examples": [
           "events"
         ],
         "type": "string"
       },
       "partitions": {
         "type": "array",
         "items": {
           "type": "object",
           "properties": {
             "consumer_groups": {
               "type": [
                 "array",
                 "null"
               ],
               "items": {
                 "type": "object",
                 "properties": {
                   "group_name": {
                     "description": "Name of the consumer group.",
                     "examples": [
                       "consumer"
                     ],
                     "type": "string"
                   },
                   "offset": {
                     "description": "The current offset of the consumer group.",
                     "examples": [
                       0
                     ],
                     "type": "integer"
                   }
                 }
               }
             },
             "earliest_offset": {
               "description": "The earliest consumer offset amongst consumer groups.",
               "examples": [
                 0
               ],
               "type": "integer"
             },
             "id": {
               "description": "An identifier for the partition.",
               "examples": [
                 1
               ],
               "type": "integer"
             },
             "in_sync_replicas": {
               "description": "The number of nodes that are in-sync (have the latest data) for the given partition",
               "examples": [
                 3
               ],
               "type": "integer"
             },
             "size": {
               "description": "Size of the topic partition in bytes.",
               "examples": [
                 4096
               ],
               "type": "integer"
             }
           }
         }
       },
       "replication_factor": {
         "description": "The number of nodes to replicate data across the cluster.",
         "examples": [
           2
         ],
         "type": "integer"
       },
       "state": {
         "description": "The state of the Kafka topic.",
         "examples": [
           "active"
         ],
         "type": "string",
         "enum": [
           "active",
           "configuring",
           "deleting",
           "unknown"
         ]
       }
     }
   }
 }
}

Fields

topic: Option<DatabasesUpdateKafkaTopicResponseTopic>