DatabasesUpdateLogsinkBody

Struct DatabasesUpdateLogsinkBody 

pub struct DatabasesUpdateLogsinkBody {
    pub config: DatabasesUpdateLogsinkBodyConfig,
}
DatabasesUpdateLogsinkBody

JSON schema
{
 "type": "object",
 "required": [
   "config"
 ],
 "properties": {
   "config": {
     "anyOf": [
       {
         "type": "object",
         "required": [
           "format",
           "port",
           "server",
           "tls"
         ],
         "properties": {
           "ca": {
             "description": "PEM encoded CA certificate",
             "examples": [
               "-----BEGIN CERTIFICATE-----\\n...\\n-----END CERTIFICATE-----\\n"
             ],
             "type": "string"
           },
           "cert": {
             "description": "(PEM format) client cert to use",
             "examples": [
               "-----BEGIN CERTIFICATE-----\\n...\\n-----END CERTIFICATE-----\\n"
             ],
             "type": "string"
           },
           "format": {
             "description": "Message format used by the server, this can be either rfc3164 (the old BSD style message format), `rfc5424` (current syslog message format) or custom",
             "examples": [
               "rfc5424"
             ],
             "type": "string",
             "enum": [
               "rfc5424",
               "rfc3164",
               "custom"
             ]
           },
           "key": {
             "description": "(PEM format) client key if the server requires client authentication",
             "examples": [
               "-----BEGIN PRIVATE KEY-----\\nREDACTED-EXAMPLE-KEY\\n-----END PRIVATE KEY-----\\n"
             ],
             "type": "string"
           },
           "logline": {
             "description": "Conditional (required if `format` == `custom`).\n\nSyslog log line template for a custom format, supporting limited rsyslog style templating (using `%tag%`). Supported tags are: `HOSTNAME`, `app-name`, `msg`, `msgid`, `pri`, `procid`, `structured-data`, `timestamp` and `timestamp:::date-rfc3339`.\n\n---\n**Datadog Integration Example for Non-Mongo clusters**:\n```text\nDD_KEY <%pri%>1 %timestamp:::date-rfc3339% %HOSTNAME%.DB_NAME %app-name% - - - %msg%\n```text\n- Replace `DD_KEY` with your actual Datadog API key.\n- Replace `DB_NAME` with the actual name of your database cluster.\n- Configure the Server:\n  - US Region: Use `intake.logs.datadoghq.com`\n  - EU Region: Use `tcp-intake.logs.datadoghq.eu`\n- Configure the Port:\n  - US Region: Use port `10516`\n  - EU Region: Use port `443`\n- Enable TLS:\n  - Ensure the TLS checkbox is enabled.\n- Note: This configuration applies to **non-Mongo clusters only**. For **Mongo clusters**, use the `datadog_logsink` integration instead.\n",
             "examples": [
               "\\<%pri%\\>%timestamp:::date-rfc3339% %HOSTNAME% %app-name% %msg%"
             ],
             "type": "string"
           },
           "port": {
             "description": "The internal port on which the rsyslog server is listening",
             "examples": [
               514
             ],
             "type": "integer",
             "maximum": 65535.0
           },
           "sd": {
             "description": "content of the structured data block of rfc5424 message",
             "examples": [
               "TOKEN tag=\"LiteralValue\""
             ],
             "type": "string"
           },
           "server": {
             "description": "DNS name or IPv4 address of the rsyslog server",
             "examples": [
               "192.168.0.1"
             ],
             "type": "string"
           },
           "tls": {
             "description": "Use TLS (as the messages are not filtered and may contain sensitive information, it is highly recommended to set this to true if the remote server supports it)",
             "examples": [
               false
             ],
             "type": "boolean"
           }
         }
       },
       {
         "type": "object",
         "required": [
           "index_prefix",
           "url"
         ],
         "properties": {
           "ca": {
             "description": "PEM encoded CA certificate",
             "examples": [
               "-----BEGIN CERTIFICATE-----\\n...\\n-----END CERTIFICATE-----\\n"
             ],
             "type": "string"
           },
           "index_days_max": {
             "description": "Maximum number of days of logs to keep",
             "default": 7,
             "examples": [
               5
             ],
             "type": "integer",
             "maximum": 10000.0,
             "minimum": 1.0
           },
           "index_prefix": {
             "description": "Elasticsearch index prefix",
             "examples": [
               "elastic-logs"
             ],
             "type": "string"
           },
           "timeout": {
             "description": "Elasticsearch request timeout limit",
             "default": 10.0,
             "examples": [
               10.0
             ],
             "type": "number",
             "format": "float",
             "maximum": 120.0,
             "minimum": 10.0
           },
           "url": {
             "description": "Elasticsearch connection URL",
             "examples": [
               "https://user:passwd@192.168.0.1:9200"
             ],
             "type": "string"
           }
         }
       },
       {
         "type": "object",
         "required": [
           "index_prefix",
           "url"
         ],
         "properties": {
           "ca": {
             "description": "PEM encoded CA certificate",
             "examples": [
               "-----BEGIN CERTIFICATE-----\\n...\\n-----END CERTIFICATE-----\\n"
             ],
             "type": "string"
           },
           "index_days_max": {
             "description": "Maximum number of days of logs to keep",
             "default": 7,
             "examples": [
               5
             ],
             "type": "integer",
             "maximum": 10000.0,
             "minimum": 1.0
           },
           "index_prefix": {
             "description": "Opensearch index prefix",
             "examples": [
               "opensearch-logs"
             ],
             "type": "string"
           },
           "timeout": {
             "description": "Opensearch request timeout limit",
             "default": 10.0,
             "examples": [
               10.0
             ],
             "type": "number",
             "format": "float",
             "maximum": 120.0,
             "minimum": 10.0
           },
           "url": {
             "description": "Opensearch connection URL",
             "examples": [
               "https://user:passwd@192.168.0.1:9200"
             ],
             "type": "string"
           }
         }
       },
       {
         "description": "Configuration for Datadog integration **applicable only to MongoDB clusters**.\n",
         "type": "object",
         "required": [
           "datadog_api_key",
           "site"
         ],
         "properties": {
           "datadog_api_key": {
             "description": "Datadog API key",
             "examples": [
               "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
             ],
             "type": "string"
           },
           "site": {
             "description": "Datadog connection URL",
             "examples": [
               "http-intake.logs.datadoghq.com"
             ],
             "type": "string"
           }
         }
       }
     ]
   }
 }
}

Fields

config: DatabasesUpdateLogsinkBodyConfig