pub struct DatabasesUpdateUserBodySettingsMongoUserSettings {
pub databases: Vec<String>,
pub role: Option<DatabasesUpdateUserBodySettingsMongoUserSettingsRole>,
}Expand description
MongoDB-specific settings for the user. This option is not currently supported for other database engines.
JSON schema
{
"description": "MongoDB-specific settings for the user. This option is not currently supported for other database engines.",
"type": "object",
"properties": {
"databases": {
"description": "A list of databases to which the user should have access. When the database is set to `admin`, the user will have access to all databases based on the user's role i.e. a user with the role `readOnly` assigned to the `admin` database will have read access to all databases.",
"examples": [
[
"my-db",
"my-db-2"
]
],
"type": "array",
"items": {
"examples": [
"my-db"
],
"type": "string"
}
},
"role": {
"description": "The role to assign to the user with each role mapping to a MongoDB built-in role. `readOnly` maps to a [read](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-read) role. `readWrite` maps to a [readWrite](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-readWrite) role. `dbAdmin` maps to a [dbAdmin](https://www.mongodb.com/docs/manual/reference/built-in-roles/#mongodb-authrole-dbAdmin) role.",
"examples": [
"readOnly"
],
"type": "string",
"enum": [
"readOnly",
"readWrite",
"dbAdmin"
]
}
}
}Fields
databases: Vec<String>A list of databases to which the user should have access. When the database is set to admin, the user will have access to all databases based on the user’s role i.e. a user with the role readOnly assigned to the admin database will have read access to all databases.
role: Option<DatabasesUpdateUserBodySettingsMongoUserSettingsRole>The role to assign to the user with each role mapping to a MongoDB built-in role. readOnly maps to a read role. readWrite maps to a readWrite role. dbAdmin maps to a dbAdmin role.