pub struct DedicatedInferencesListTokensResponseTokensItem {
pub created_at: Option<DateTime<Utc>>,
pub id: Option<Uuid>,
pub is_managed: Option<bool>,
pub name: Option<String>,
pub value: Option<String>,
}Expand description
Access token for authenticating to Dedicated Inference endpoints.
JSON schema
{
"description": "Access token for authenticating to Dedicated Inference endpoints.",
"type": "object",
"properties": {
"created_at": {
"readOnly": true,
"examples": [
"2024-01-09T20:44:32Z"
],
"type": "string",
"format": "date-time"
},
"id": {
"description": "Unique ID of the token.",
"readOnly": true,
"examples": [
"01333f14-a903-4b8e-92b3-363a767aa052"
],
"type": "string",
"format": "uuid"
},
"is_managed": {
"description": "When true, the token is managed by DigitalOcean (for example, system-provisioned). When false, the token was created by the user.",
"readOnly": true,
"examples": [
false
],
"type": "boolean"
},
"name": {
"description": "Name of the token.",
"readOnly": true,
"examples": [
"first-token"
],
"type": "string"
},
"value": {
"description": "Token value; only returned once on create. Store securely.",
"readOnly": true,
"examples": [
"di_xxxxxxxxxxxxxxxxxxxxxxxx"
],
"type": "string"
}
}
}Fields
created_at: Option<DateTime<Utc>>id: Option<Uuid>Unique ID of the token.
is_managed: Option<bool>When true, the token is managed by DigitalOcean (for example, system-provisioned). When false, the token was created by the user.
name: Option<String>Name of the token.
value: Option<String>Token value; only returned once on create. Store securely.