pub struct DimensionsItem {
pub display_name: String,
pub feature_name: String,
pub id: i64,
pub sku: String,
pub slug: String,
pub volumes: Vec<VolumesItem>,
}Expand description
DimensionsItem
JSON schema
{
"type": "object",
"required": [
"display_name",
"feature_name",
"id",
"sku",
"slug",
"volumes"
],
"properties": {
"display_name": {
"title": "display_name",
"description": "Display name for the dimension.",
"examples": [
"Addon Dimension Display Name"
],
"type": "string"
},
"feature_name": {
"title": "feature_name",
"description": "Name of the feature associated with the dimension.",
"examples": [
"Feature Name"
],
"type": "string"
},
"id": {
"title": "id",
"description": "Unique identifier for the dimension.",
"examples": [
1
],
"type": "integer"
},
"sku": {
"title": "sku",
"description": "Unique string identifier for the dimension, tied to a price.",
"examples": [
"addon_sku_123"
],
"type": "string"
},
"slug": {
"title": "slug",
"description": "Slug identifier for the dimension.",
"examples": [
"addon_dimension_slug"
],
"type": "string"
},
"volumes": {
"title": "volumes",
"description": "A list of volumes associated with the dimension, each with its own price.",
"type": "array",
"items": {
"type": "object",
"required": [
"id",
"low_volume",
"max_volume",
"price_per_unit"
],
"properties": {
"id": {
"title": "id",
"description": "Unique identifier for the addon.",
"examples": [
123
],
"type": "integer"
},
"low_volume": {
"title": "low_volume",
"description": "The minimum volume for the volume pricing tier.",
"examples": [
1
],
"type": "integer"
},
"max_volume": {
"title": "max_volume",
"description": "The maximum volume for the volume pricing tier.",
"examples": [
100
],
"type": "integer"
},
"price_per_unit": {
"title": "price_per_unit",
"description": "The price per unit for the volume tier in US dollars.",
"examples": [
"0.10"
],
"type": "string"
}
}
}
}
}
}Fields
display_name: StringDisplay name for the dimension.
feature_name: StringName of the feature associated with the dimension.
id: i64Unique identifier for the dimension.
sku: StringUnique string identifier for the dimension, tied to a price.
slug: StringSlug identifier for the dimension.
volumes: Vec<VolumesItem>A list of volumes associated with the dimension, each with its own price.