DomainsUpdateRecordBody

Struct DomainsUpdateRecordBody 

pub struct DomainsUpdateRecordBody {
    pub data: Option<String>,
    pub flags: Option<i64>,
    pub id: Option<i64>,
    pub name: Option<String>,
    pub port: Option<i64>,
    pub priority: Option<i64>,
    pub tag: Option<String>,
    pub ttl: Option<i64>,
    pub type_: String,
    pub weight: Option<i64>,
}
DomainsUpdateRecordBody

JSON schema
{
 "type": "object",
 "required": [
   "type"
 ],
 "properties": {
   "data": {
     "description": "Variable data depending on record type. For example, the \"data\" value for an A record would be the IPv4 address to which the domain will be mapped. For a CAA record, it would contain the domain name of the CA being granted permission to issue certificates.",
     "examples": [
       "ns1.digitalocean.com"
     ],
     "type": "string"
   },
   "flags": {
     "description": "An unsigned integer between 0-255 used for CAA records.",
     "type": [
       "integer",
       "null"
     ]
   },
   "id": {
     "description": "A unique identifier for each domain record.",
     "readOnly": true,
     "examples": [
       28448429
     ],
     "type": "integer"
   },
   "name": {
     "description": "The host name, alias, or service being defined by the record.",
     "examples": [
       "@"
     ],
     "type": "string"
   },
   "port": {
     "description": "The port for SRV records.",
     "type": [
       "integer",
       "null"
     ]
   },
   "priority": {
     "description": "The priority for SRV and MX records.",
     "type": [
       "integer",
       "null"
     ]
   },
   "tag": {
     "description": "The parameter tag for CAA records. Valid values are \"issue\", \"issuewild\", or \"iodef\"",
     "type": [
       "string",
       "null"
     ]
   },
   "ttl": {
     "description": "This value is the time to live for the record, in seconds. This defines the time frame that clients can cache queried information before a refresh should be requested.",
     "examples": [
       1800
     ],
     "type": "integer"
   },
   "type": {
     "description": "The type of the DNS record. For example: A, CNAME, TXT, ...",
     "examples": [
       "NS"
     ],
     "type": "string"
   },
   "weight": {
     "description": "The weight for SRV records.",
     "type": [
       "integer",
       "null"
     ]
   }
 }
}

Fields

data: Option<String>

Variable data depending on record type. For example, the “data” value for an A record would be the IPv4 address to which the domain will be mapped. For a CAA record, it would contain the domain name of the CA being granted permission to issue certificates.

flags: Option<i64>

An unsigned integer between 0-255 used for CAA records.

id: Option<i64>

A unique identifier for each domain record.

name: Option<String>

The host name, alias, or service being defined by the record.

port: Option<i64>

The port for SRV records.

priority: Option<i64>

The priority for SRV and MX records.

tag: Option<String>

The parameter tag for CAA records. Valid values are “issue”, “issuewild”, or “iodef”

ttl: Option<i64>

This value is the time to live for the record, in seconds. This defines the time frame that clients can cache queried information before a refresh should be requested.

type_: String

The type of the DNS record. For example: A, CNAME, TXT, …

weight: Option<i64>

The weight for SRV records.