pub struct DropletsGetBackupPolicyResponsePolicyNextBackupWindow {
pub end: Option<DateTime<Utc>>,
pub start: Option<DateTime<Utc>>,
}Expand description
DropletsGetBackupPolicyResponsePolicyNextBackupWindow
JSON schema
{
"type": "object",
"properties": {
"end": {
"description": "A time value given in ISO8601 combined date and time format specifying the end of the Droplet's backup window.",
"examples": [
"2019-12-04T23:00:00Z"
],
"type": "string",
"format": "date-time"
},
"start": {
"description": "A time value given in ISO8601 combined date and time format specifying the start of the Droplet's backup window.",
"examples": [
"2019-12-04T00:00:00Z"
],
"type": "string",
"format": "date-time"
}
}
}Fields
end: Option<DateTime<Utc>>A time value given in ISO8601 combined date and time format specifying the end of the Droplet’s backup window.
start: Option<DateTime<Utc>>A time value given in ISO8601 combined date and time format specifying the start of the Droplet’s backup window.