DropletsListBackupPoliciesResponse

Struct DropletsListBackupPoliciesResponse 

pub struct DropletsListBackupPoliciesResponse {
    pub links: Option<DropletsListBackupPoliciesResponseLinks>,
    pub meta: DropletsListBackupPoliciesResponseMeta,
    pub policies: HashMap<String, DropletsListBackupPoliciesResponsePoliciesValue>,
}
DropletsListBackupPoliciesResponse

JSON schema
{
 "allOf": [
   {
     "type": "object",
     "properties": {
       "policies": {
         "description": "A map where the keys are the Droplet IDs and the values are\nobjects containing the backup policy information for each Droplet.\n",
         "type": "object",
         "additionalProperties": {
           "type": "object",
           "properties": {
             "backup_enabled": {
               "description": "A boolean value indicating whether backups are enabled for the Droplet.",
               "examples": [
                 true
               ],
               "type": "boolean"
             },
             "backup_policy": {
               "allOf": [
                 {
                   "type": "object",
                   "properties": {
                     "hour": {
                       "description": "The hour of the day that the backup window will start.",
                       "examples": [
                         0
                       ],
                       "type": "integer",
                       "enum": [
                         0,
                         4,
                         8,
                         12,
                         16,
                         20
                       ]
                     },
                     "plan": {
                       "description": "The backup plan used for the Droplet. The plan can be either `daily` or `weekly`.",
                       "examples": [
                         "daily"
                       ],
                       "type": "string",
                       "enum": [
                         "daily",
                         "weekly"
                       ]
                     },
                     "retention_period_days": {
                       "description": "The number of days the backup will be retained.",
                       "readOnly": true,
                       "examples": [
                         7
                       ],
                       "type": "integer"
                     },
                     "weekday": {
                       "description": "The day of the week on which the backup will occur.",
                       "examples": [
                         "SUN"
                       ],
                       "type": "string",
                       "enum": [
                         "SUN",
                         "MON",
                         "TUE",
                         "WED",
                         "THU",
                         "FRI",
                         "SAT"
                       ]
                     },
                     "window_length_hours": {
                       "description": "The length of the backup window starting from `hour`.",
                       "readOnly": true,
                       "examples": [
                         4
                       ],
                       "type": "integer"
                     }
                   }
                 },
                 {
                   "description": "An object specifying the backup policy for the Droplet."
                 }
               ]
             },
             "droplet_id": {
               "description": "The unique identifier for the Droplet.",
               "examples": [
                 7101383
               ],
               "type": "integer"
             },
             "next_backup_window": {
               "allOf": [
                 {
                   "type": [
                     "object",
                     "null"
                   ],
                   "properties": {
                     "end": {
                       "description": "A time value given in ISO8601 combined date and time format specifying the end of the Droplet's backup window.",
                       "examples": [
                         "2019-12-04T23:00:00Z"
                       ],
                       "type": "string",
                       "format": "date-time"
                     },
                     "start": {
                       "description": "A time value given in ISO8601 combined date and time format specifying the start of the Droplet's backup window.",
                       "examples": [
                         "2019-12-04T00:00:00Z"
                       ],
                       "type": "string",
                       "format": "date-time"
                     }
                   }
                 },
                 {
                   "description": "An object containing keys with the start and end times of the window during which the backup will occur."
                 }
               ]
             }
           }
         }
       }
     }
   },
   {
     "type": "object",
     "properties": {
       "links": {
         "type": "object",
         "properties": {
           "pages": {
             "examples": [
               {
                 "pages": {
                   "first": "https://api.digitalocean.com/v2/account/keys?page=1",
                   "prev": "https://api.digitalocean.com/v2/account/keys?page=2"
                 }
               }
             ],
             "anyOf": [
               {
                 "type": "object",
                 "properties": {
                   "first": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=1"
                     ],
                     "type": "string",
                     "format": "uri"
                   },
                   "last": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=3"
                     ],
                     "type": "string",
                     "format": "uri"
                   },
                   "next": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=2"
                     ],
                     "type": "string",
                     "format": "uri"
                   }
                 }
               },
               {
                 "type": "object",
                 "properties": {
                   "first": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=1"
                     ],
                     "type": "string",
                     "format": "uri"
                   },
                   "last": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=3"
                     ],
                     "type": "string",
                     "format": "uri"
                   },
                   "prev": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=1"
                     ],
                     "type": "string",
                     "format": "uri"
                   }
                 }
               },
               {}
             ]
           }
         }
       }
     }
   },
   {
     "type": "object",
     "required": [
       "meta"
     ],
     "properties": {
       "meta": {
         "allOf": [
           {
             "description": "Information about the response itself.",
             "type": "object",
             "properties": {
               "total": {
                 "description": "Number of objects returned by the request.",
                 "examples": [
                   1
                 ],
                 "type": "integer"
               }
             }
           },
           {
             "required": [
               "total"
             ]
           }
         ]
       }
     }
   }
 ]
}

Fields

links: Option<DropletsListBackupPoliciesResponseLinks>meta: DropletsListBackupPoliciesResponseMetapolicies: HashMap<String, DropletsListBackupPoliciesResponsePoliciesValue>

A map where the keys are the Droplet IDs and the values are objects containing the backup policy information for each Droplet.