pub struct DropletsListKernelsResponse {
pub kernels: Vec<Option<DropletsListKernelsResponseKernelsItem>>,
pub links: Option<DropletsListKernelsResponseLinks>,
pub meta: DropletsListKernelsResponseMeta,
}Expand description
DropletsListKernelsResponse
JSON schema
{
"allOf": [
{
"type": "object",
"properties": {
"kernels": {
"type": "array",
"items": {
"description": "**Note**: All Droplets created after March 2017 use internal kernels by default.\nThese Droplets will have this attribute set to `null`.\n\nThe current [kernel](https://docs.digitalocean.com/products/droplets/how-to/kernel/)\nfor Droplets with externally managed kernels. This will initially be set to\nthe kernel of the base image when the Droplet is created.\n",
"deprecated": true,
"type": [
"object",
"null"
],
"properties": {
"id": {
"description": "A unique number used to identify and reference a specific kernel.",
"examples": [
7515
],
"type": "integer"
},
"name": {
"description": "The display name of the kernel. This is shown in the web UI and is generally a descriptive title for the kernel in question.",
"examples": [
"DigitalOcean GrubLoader v0.2 (20160714)"
],
"type": "string"
},
"version": {
"description": "A standard kernel version string representing the version, patch, and release information.",
"examples": [
"2016.07.13-DigitalOcean_loader_Ubuntu"
],
"type": "string"
}
}
}
}
}
},
{
"type": "object",
"properties": {
"links": {
"type": "object",
"properties": {
"pages": {
"examples": [
{
"pages": {
"first": "https://api.digitalocean.com/v2/account/keys?page=1",
"prev": "https://api.digitalocean.com/v2/account/keys?page=2"
}
}
],
"anyOf": [
{
"type": "object",
"properties": {
"first": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
},
"last": {
"examples": [
"https://api.digitalocean.com/v2/images?page=3"
],
"type": "string",
"format": "uri"
},
"next": {
"examples": [
"https://api.digitalocean.com/v2/images?page=2"
],
"type": "string",
"format": "uri"
}
}
},
{
"type": "object",
"properties": {
"first": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
},
"last": {
"examples": [
"https://api.digitalocean.com/v2/images?page=3"
],
"type": "string",
"format": "uri"
},
"prev": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
}
}
},
{}
]
}
}
}
}
},
{
"type": "object",
"required": [
"meta"
],
"properties": {
"meta": {
"allOf": [
{
"description": "Information about the response itself.",
"type": "object",
"properties": {
"total": {
"description": "Number of objects returned by the request.",
"examples": [
1
],
"type": "integer"
}
}
},
{
"required": [
"total"
]
}
]
}
}
}
]
}Fields
kernels: Vec<Option<DropletsListKernelsResponseKernelsItem>>links: Option<DropletsListKernelsResponseLinks>meta: DropletsListKernelsResponseMetaTrait Implementations
Sourceimpl Clone for DropletsListKernelsResponse
impl Clone for DropletsListKernelsResponse
Sourcefn clone(&self) -> DropletsListKernelsResponse
fn clone(&self) -> DropletsListKernelsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DropletsListKernelsResponse
impl Debug for DropletsListKernelsResponse
Sourceimpl<'de> Deserialize<'de> for DropletsListKernelsResponse
impl<'de> Deserialize<'de> for DropletsListKernelsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&DropletsListKernelsResponse> for DropletsListKernelsResponse
impl From<&DropletsListKernelsResponse> for DropletsListKernelsResponse
Sourcefn from(value: &DropletsListKernelsResponse) -> Self
fn from(value: &DropletsListKernelsResponse) -> Self
Converts to this type from the input type.