pub struct DropletsListKernelsResponseKernelsItem {
pub id: Option<i64>,
pub name: Option<String>,
pub version: Option<String>,
}Expand description
Note: All Droplets created after March 2017 use internal kernels by default.
These Droplets will have this attribute set to null.
The current kernel for Droplets with externally managed kernels. This will initially be set to the kernel of the base image when the Droplet is created.
JSON schema
{
"description": "**Note**: All Droplets created after March 2017 use internal kernels by default.\nThese Droplets will have this attribute set to `null`.\n\nThe current [kernel](https://docs.digitalocean.com/products/droplets/how-to/kernel/)\nfor Droplets with externally managed kernels. This will initially be set to\nthe kernel of the base image when the Droplet is created.\n",
"deprecated": true,
"type": "object",
"properties": {
"id": {
"description": "A unique number used to identify and reference a specific kernel.",
"examples": [
7515
],
"type": "integer"
},
"name": {
"description": "The display name of the kernel. This is shown in the web UI and is generally a descriptive title for the kernel in question.",
"examples": [
"DigitalOcean GrubLoader v0.2 (20160714)"
],
"type": "string"
},
"version": {
"description": "A standard kernel version string representing the version, patch, and release information.",
"examples": [
"2016.07.13-DigitalOcean_loader_Ubuntu"
],
"type": "string"
}
}
}Fields
id: Option<i64>A unique number used to identify and reference a specific kernel.
name: Option<String>The display name of the kernel. This is shown in the web UI and is generally a descriptive title for the kernel in question.
version: Option<String>A standard kernel version string representing the version, patch, and release information.