FirewallsDeleteRulesBodyVariant1OutboundRulesItemDestinations

Struct FirewallsDeleteRulesBodyVariant1OutboundRulesItemDestinations 

pub struct FirewallsDeleteRulesBodyVariant1OutboundRulesItemDestinations {
    pub addresses: Vec<String>,
    pub droplet_ids: Vec<i64>,
    pub kubernetes_ids: Vec<String>,
    pub load_balancer_uids: Vec<String>,
    pub tags: Option<Vec<String>>,
}
FirewallsDeleteRulesBodyVariant1OutboundRulesItemDestinations

JSON schema
{
 "allOf": [
   {
     "type": "object",
     "properties": {
       "addresses": {
         "description": "An array of strings containing the IPv4 addresses, IPv6 addresses, IPv4 CIDRs, and/or IPv6 CIDRs to which the firewall will allow traffic.",
         "examples": [
           [
             "1.2.3.4",
             "18.0.0.0/8"
           ]
         ],
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "droplet_ids": {
         "description": "An array containing the IDs of the Droplets to which the firewall will allow traffic.",
         "examples": [
           [
             8043964
           ]
         ],
         "type": "array",
         "items": {
           "type": "integer"
         }
       },
       "kubernetes_ids": {
         "description": "An array containing the IDs of the Kubernetes clusters to which the firewall will allow traffic.",
         "examples": [
           [
             "41b74c5d-9bd0-5555-5555-a57c495b81a3"
           ]
         ],
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "load_balancer_uids": {
         "description": "An array containing the IDs of the load balancers to which the firewall will allow traffic.",
         "examples": [
           [
             "4de7ac8b-495b-4884-9a69-1050c6793cd6"
           ]
         ],
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "tags": {
         "allOf": [
           {
             "description": "A flat array of tag names as strings to be applied to the resource. Tag names must exist in order to be referenced in a request. <br><br>Requires `tag:create` and `tag:read` scopes.",
             "examples": [
               [
                 "base-image",
                 "prod"
               ]
             ],
             "type": [
               "array",
               "null"
             ],
             "items": {
               "type": "string"
             }
           },
           {
             "description": "An array containing the names of Tags corresponding to groups of Droplets to which the firewall will allow traffic.",
             "examples": [
               [
                 "frontend"
               ]
             ]
           }
         ]
       }
     }
   },
   {
     "description": "An object specifying locations to which outbound traffic that will be allowed."
   }
 ]
}

Fields

addresses: Vec<String>

An array of strings containing the IPv4 addresses, IPv6 addresses, IPv4 CIDRs, and/or IPv6 CIDRs to which the firewall will allow traffic.

droplet_ids: Vec<i64>

An array containing the IDs of the Droplets to which the firewall will allow traffic.

kubernetes_ids: Vec<String>

An array containing the IDs of the Kubernetes clusters to which the firewall will allow traffic.

load_balancer_uids: Vec<String>

An array containing the IDs of the load balancers to which the firewall will allow traffic.

tags: Option<Vec<String>>