FloatingIPsGetResponseFloatingIpDropletSubtype1

Struct FloatingIPsGetResponseFloatingIpDropletSubtype1 

pub struct FloatingIPsGetResponseFloatingIpDropletSubtype1 {
Show 23 fields pub backup_ids: Vec<i64>, pub created_at: DateTime<Utc>, pub disk: i64, pub disk_info: Vec<FloatingIPsGetResponseFloatingIpDropletSubtype1DiskInfoItem>, pub features: Vec<String>, pub gpu_info: Option<FloatingIPsGetResponseFloatingIpDropletSubtype1GpuInfo>, pub id: i64, pub image: FloatingIPsGetResponseFloatingIpDropletSubtype1Image, pub kernel: Option<FloatingIPsGetResponseFloatingIpDropletSubtype1Kernel>, pub locked: bool, pub memory: i64, pub name: String, pub networks: FloatingIPsGetResponseFloatingIpDropletSubtype1Networks, pub next_backup_window: Option<FloatingIPsGetResponseFloatingIpDropletSubtype1NextBackupWindow>, pub region: FloatingIPsGetResponseFloatingIpDropletSubtype1Region, pub size: FloatingIPsGetResponseFloatingIpDropletSubtype1Size, pub size_slug: String, pub snapshot_ids: Vec<i64>, pub status: FloatingIPsGetResponseFloatingIpDropletSubtype1Status, pub tags: Vec<String>, pub vcpus: i64, pub volume_ids: Vec<String>, pub vpc_uuid: Option<String>,
}
FloatingIPsGetResponseFloatingIpDropletSubtype1

JSON schema
{
 "type": "object",
 "required": [
   "backup_ids",
   "created_at",
   "disk",
   "features",
   "id",
   "image",
   "locked",
   "memory",
   "name",
   "networks",
   "next_backup_window",
   "region",
   "size",
   "size_slug",
   "snapshot_ids",
   "status",
   "tags",
   "vcpus",
   "volume_ids"
 ],
 "properties": {
   "backup_ids": {
     "description": "An array of backup IDs of any backups that have been taken of the Droplet instance.  Droplet backups are enabled at the time of the instance creation.<br>Requires `image:read` scope.",
     "examples": [
       [
         53893572
       ]
     ],
     "type": "array",
     "items": {
       "type": "integer"
     }
   },
   "created_at": {
     "description": "A time value given in ISO8601 combined date and time format that represents when the Droplet was created.",
     "examples": [
       "2020-07-21T18:37:44Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "disk": {
     "description": "The size of the Droplet's disk in gigabytes.",
     "examples": [
       25
     ],
     "type": "integer"
   },
   "disk_info": {
     "description": "An array of objects containing information about the disks available to the Droplet.",
     "type": "array",
     "items": {
       "type": "object",
       "properties": {
         "size": {
           "type": "object",
           "properties": {
             "amount": {
               "description": "The amount of space allocated to the disk.",
               "examples": [
                 25
               ],
               "type": "integer"
             },
             "unit": {
               "description": "The unit of measure for the disk size.",
               "examples": [
                 "gib"
               ],
               "type": "string"
             }
           }
         },
         "type": {
           "description": "The type of disk. All Droplets contain a `local` or `boot` disk. Additionally, GPU Droplets can also have a `scratch` disk for non-persistent data.",
           "examples": [
             "local"
           ],
           "type": "string",
           "enum": [
             "local",
             "boot",
             "scratch"
           ]
         }
       }
     }
   },
   "features": {
     "description": "An array of features enabled on this Droplet.",
     "examples": [
       [
         "backups",
         "private_networking",
         "ipv6"
       ]
     ],
     "type": "array",
     "items": {
       "type": "string"
     }
   },
   "gpu_info": {
     "description": "An object containing information about the GPU capabilities of Droplets created with this size.",
     "type": "object",
     "properties": {
       "count": {
         "description": "The number of GPUs allocated to the Droplet.",
         "examples": [
           1
         ],
         "type": "integer"
       },
       "model": {
         "description": "The model of the GPU.",
         "examples": [
           "nvidia_h100"
         ],
         "type": "string"
       },
       "vram": {
         "type": "object",
         "properties": {
           "amount": {
             "description": "The amount of VRAM allocated to the GPU.",
             "examples": [
               25
             ],
             "type": "integer"
           },
           "unit": {
             "description": "The unit of measure for the VRAM.",
             "examples": [
               "gib"
             ],
             "type": "string"
           }
         }
       }
     }
   },
   "id": {
     "description": "A unique identifier for each Droplet instance. This is automatically generated upon Droplet creation.",
     "examples": [
       3164444
     ],
     "type": "integer"
   },
   "image": {
     "allOf": [
       {
         "type": "object",
         "properties": {
           "created_at": {
             "description": "A time value given in ISO8601 combined date and time format that represents when the image was created.",
             "examples": [
               "2020-05-04T22:23:02Z"
             ],
             "type": "string",
             "format": "date-time"
           },
           "description": {
             "description": "An optional free-form text field to describe an image.",
             "examples": [
               " "
             ],
             "type": "string"
           },
           "distribution": {
             "description": "The name of a custom image's distribution. Currently, the valid values are  `Arch Linux`, `CentOS`, `CoreOS`, `Debian`, `Fedora`, `Fedora Atomic`,  `FreeBSD`, `Gentoo`, `openSUSE`, `RancherOS`, `Rocky Linux`, `Ubuntu`, and `Unknown`.  Any other value will be accepted but ignored, and `Unknown` will be used in its place.",
             "examples": [
               "Ubuntu"
             ],
             "type": "string",
             "enum": [
               "Arch Linux",
               "CentOS",
               "CoreOS",
               "Debian",
               "Fedora",
               "Fedora Atomic",
               "FreeBSD",
               "Gentoo",
               "openSUSE",
               "RancherOS",
               "Rocky Linux",
               "Ubuntu",
               "Unknown"
             ]
           },
           "error_message": {
             "description": "A string containing information about errors that may occur when importing\n a custom image.",
             "examples": [
               " "
             ],
             "type": "string"
           },
           "id": {
             "description": "A unique number that can be used to identify and reference a specific image.",
             "readOnly": true,
             "examples": [
               7555620
             ],
             "type": "integer"
           },
           "min_disk_size": {
             "description": "The minimum disk size in GB required for a Droplet to use this image.",
             "examples": [
               20
             ],
             "type": [
               "integer",
               "null"
             ],
             "minimum": 0.0
           },
           "name": {
             "description": "The display name that has been given to an image.  This is what is shown in the control panel and is generally a descriptive title for the image in question.",
             "examples": [
               "Nifty New Snapshot"
             ],
             "type": "string"
           },
           "public": {
             "description": "This is a boolean value that indicates whether the image in question is public or not. An image that is public is available to all accounts. A non-public image is only accessible from your account.",
             "examples": [
               true
             ],
             "type": "boolean"
           },
           "regions": {
             "description": "This attribute is an array of the regions that the image is available in. The regions are represented by their identifying slug values.",
             "examples": [
               [
                 "nyc1",
                 "nyc2"
               ]
             ],
             "type": "array",
             "items": {
               "description": "The slug identifier for the region where the resource will initially be  available.",
               "examples": [
                 "nyc3"
               ],
               "type": "string",
               "enum": [
                 "ams1",
                 "ams2",
                 "ams3",
                 "blr1",
                 "fra1",
                 "lon1",
                 "nyc1",
                 "nyc2",
                 "nyc3",
                 "sfo1",
                 "sfo2",
                 "sfo3",
                 "sgp1",
                 "tor1",
                 "syd1"
               ]
             }
           },
           "size_gigabytes": {
             "description": "The size of the image in gigabytes.",
             "examples": [
               2.34
             ],
             "type": [
               "number",
               "null"
             ],
             "format": "float"
           },
           "slug": {
             "description": "A uniquely identifying string that is associated with each of the DigitalOcean-provided public images. These can be used to reference a public image as an alternative to the numeric id.",
             "examples": [
               "nifty1"
             ],
             "type": [
               "string",
               "null"
             ]
           },
           "status": {
             "description": "A status string indicating the state of a custom image. This may be `NEW`,\n `available`, `pending`, `deleted`, or `retired`.",
             "examples": [
               "NEW"
             ],
             "type": "string",
             "enum": [
               "NEW",
               "available",
               "pending",
               "deleted",
               "retired"
             ]
           },
           "tags": {
             "description": "A flat array of tag names as strings to be applied to the resource. Tag names may be for either existing or new tags. <br><br>Requires `tag:create` scope.",
             "examples": [
               [
                 "base-image",
                 "prod"
               ]
             ],
             "type": [
               "array",
               "null"
             ],
             "items": {
               "type": "string"
             }
           },
           "type": {
             "description": "Describes the kind of image. It may be one of `base`, `snapshot`, `backup`, `custom`, or `admin`. Respectively, this specifies whether an image is a DigitalOcean base OS image, user-generated Droplet snapshot, automatically created Droplet backup, user-provided virtual machine image, or an image used for DigitalOcean managed resources (e.g. DOKS worker nodes).",
             "examples": [
               "snapshot"
             ],
             "type": "string",
             "enum": [
               "base",
               "snapshot",
               "backup",
               "custom",
               "admin"
             ]
           }
         }
       },
       {
         "description": "The Droplet's image.<br>Requires `image:read` scope."
       }
     ]
   },
   "kernel": {
     "description": "**Note**: All Droplets created after March 2017 use internal kernels by default.\nThese Droplets will have this attribute set to `null`.\n\nThe current [kernel](https://docs.digitalocean.com/products/droplets/how-to/kernel/)\nfor Droplets with externally managed kernels. This will initially be set to\nthe kernel of the base image when the Droplet is created.\n",
     "deprecated": true,
     "type": [
       "object",
       "null"
     ],
     "properties": {
       "id": {
         "description": "A unique number used to identify and reference a specific kernel.",
         "examples": [
           7515
         ],
         "type": "integer"
       },
       "name": {
         "description": "The display name of the kernel. This is shown in the web UI and is generally a descriptive title for the kernel in question.",
         "examples": [
           "DigitalOcean GrubLoader v0.2 (20160714)"
         ],
         "type": "string"
       },
       "version": {
         "description": "A standard kernel version string representing the version, patch, and release information.",
         "examples": [
           "2016.07.13-DigitalOcean_loader_Ubuntu"
         ],
         "type": "string"
       }
     }
   },
   "locked": {
     "description": "A boolean value indicating whether the Droplet has been locked, preventing actions by users.",
     "examples": [
       false
     ],
     "type": "boolean"
   },
   "memory": {
     "description": "Memory of the Droplet in megabytes.",
     "examples": [
       1024
     ],
     "type": "integer",
     "multipleOf": 8.0
   },
   "name": {
     "description": "The human-readable name set for the Droplet instance.",
     "examples": [
       "example.com"
     ],
     "type": "string"
   },
   "networks": {
     "description": "The details of the network that are configured for the Droplet instance.  This is an object that contains keys for IPv4 and IPv6.  The value of each of these is an array that contains objects describing an individual IP resource allocated to the Droplet.  These will define attributes like the IP address, netmask, and gateway of the specific network depending on the type of network it is.",
     "type": "object",
     "properties": {
       "v4": {
         "type": "array",
         "items": {
           "type": "object",
           "properties": {
             "gateway": {
               "description": "The gateway of the specified IPv4 network interface.\n\nFor private interfaces, a gateway is not provided. This is denoted by\nreturning `nil` as its value.\n",
               "examples": [
                 "104.236.0.1"
               ],
               "type": "string"
             },
             "ip_address": {
               "description": "The IP address of the IPv4 network interface.",
               "examples": [
                 "104.236.32.182"
               ],
               "type": "string",
               "format": "ipv4"
             },
             "netmask": {
               "description": "The netmask of the IPv4 network interface.",
               "examples": [
                 "255.255.192.0"
               ],
               "type": "string",
               "format": "ipv4"
             },
             "type": {
               "description": "The type of the IPv4 network interface.",
               "examples": [
                 "public"
               ],
               "type": "string",
               "enum": [
                 "public",
                 "private"
               ]
             }
           }
         }
       },
       "v6": {
         "type": "array",
         "items": {
           "type": "object",
           "properties": {
             "gateway": {
               "description": "The gateway of the specified IPv6 network interface.",
               "examples": [
                 "2604:a880:0:1010::1"
               ],
               "type": "string",
               "format": "ipv6"
             },
             "ip_address": {
               "description": "The IP address of the IPv6 network interface.",
               "examples": [
                 "2604:a880:0:1010::18a:a001"
               ],
               "type": "string",
               "format": "ipv6"
             },
             "netmask": {
               "description": "The netmask of the IPv6 network interface.",
               "examples": [
                 64
               ],
               "type": "integer"
             },
             "type": {
               "description": "The type of the IPv6 network interface.\n\n**Note**: IPv6 private  networking is not currently supported.\n",
               "examples": [
                 "public"
               ],
               "type": "string",
               "enum": [
                 "public"
               ]
             }
           }
         }
       }
     }
   },
   "next_backup_window": {
     "allOf": [
       {
         "type": [
           "object",
           "null"
         ],
         "properties": {
           "end": {
             "description": "A time value given in ISO8601 combined date and time format specifying the end of the Droplet's backup window.",
             "examples": [
               "2019-12-04T23:00:00Z"
             ],
             "type": "string",
             "format": "date-time"
           },
           "start": {
             "description": "A time value given in ISO8601 combined date and time format specifying the start of the Droplet's backup window.",
             "examples": [
               "2019-12-04T00:00:00Z"
             ],
             "type": "string",
             "format": "date-time"
           }
         }
       },
       {
         "description": "The details of the Droplet's backups feature, if backups are configured for the Droplet. This object contains keys for the start and end times of the window during which the backup will start."
       }
     ]
   },
   "region": {
     "type": "object",
     "required": [
       "available",
       "features",
       "name",
       "sizes",
       "slug"
     ],
     "properties": {
       "available": {
         "description": "This is a boolean value that represents whether new Droplets can be created in this region.",
         "examples": [
           true
         ],
         "type": "boolean"
       },
       "features": {
         "description": "This attribute is set to an array which contains features available in this region",
         "examples": [
           [
             "private_networking",
             "backups",
             "ipv6",
             "metadata",
             "install_agent",
             "storage",
             "image_transfer"
           ]
         ],
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "name": {
         "description": "The display name of the region.  This will be a full name that is used in the control panel and other interfaces.",
         "examples": [
           "New York 3"
         ],
         "type": "string"
       },
       "sizes": {
         "description": "This attribute is set to an array which contains the identifying slugs for the sizes available in this region. sizes:read is required to view.",
         "examples": [
           [
             "s-1vcpu-1gb",
             "s-1vcpu-2gb",
             "s-1vcpu-3gb",
             "s-2vcpu-2gb",
             "s-3vcpu-1gb",
             "s-2vcpu-4gb",
             "s-4vcpu-8gb",
             "s-6vcpu-16gb",
             "s-8vcpu-32gb",
             "s-12vcpu-48gb",
             "s-16vcpu-64gb",
             "s-20vcpu-96gb",
             "s-24vcpu-128gb",
             "s-32vcpu-192g"
           ]
         ],
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "slug": {
         "description": "A human-readable string that is used as a unique identifier for each region.",
         "examples": [
           "nyc3"
         ],
         "type": "string"
       }
     }
   },
   "size": {
     "type": "object",
     "required": [
       "available",
       "description",
       "disk",
       "memory",
       "price_hourly",
       "price_monthly",
       "regions",
       "slug",
       "transfer",
       "vcpus"
     ],
     "properties": {
       "available": {
         "description": "This is a boolean value that represents whether new Droplets can be created with this size.",
         "default": true,
         "examples": [
           true
         ],
         "type": "boolean"
       },
       "description": {
         "description": "A string describing the class of Droplets created from this size. For example: Basic, General Purpose, CPU-Optimized, Memory-Optimized, or Storage-Optimized.",
         "examples": [
           "Basic"
         ],
         "type": "string"
       },
       "disk": {
         "description": "The amount of disk space set aside for Droplets of this size. The value is represented in gigabytes.",
         "examples": [
           25
         ],
         "type": "integer"
       },
       "disk_info": {
         "description": "An array of objects containing information about the disks available to Droplets created with this size.",
         "type": "array",
         "items": {
           "type": "object",
           "properties": {
             "size": {
               "type": "object",
               "properties": {
                 "amount": {
                   "description": "The amount of space allocated to the disk.",
                   "examples": [
                     25
                   ],
                   "type": "integer"
                 },
                 "unit": {
                   "description": "The unit of measure for the disk size.",
                   "examples": [
                     "gib"
                   ],
                   "type": "string"
                 }
               }
             },
             "type": {
               "description": "The type of disk. All Droplets contain a `local` or `boot` disk. Additionally, GPU Droplets can also have a `scratch` disk for non-persistent data.",
               "examples": [
                 "local"
               ],
               "type": "string",
               "enum": [
                 "local",
                 "boot",
                 "scratch"
               ]
             }
           }
         }
       },
       "gpu_info": {
         "description": "An object containing information about the GPU capabilities of Droplets created with this size.",
         "type": "object",
         "properties": {
           "count": {
             "description": "The number of GPUs allocated to the Droplet.",
             "examples": [
               1
             ],
             "type": "integer"
           },
           "model": {
             "description": "The model of the GPU.",
             "examples": [
               "nvidia_h100"
             ],
             "type": "string"
           },
           "vram": {
             "type": "object",
             "properties": {
               "amount": {
                 "description": "The amount of VRAM allocated to the GPU.",
                 "examples": [
                   25
                 ],
                 "type": "integer"
               },
               "unit": {
                 "description": "The unit of measure for the VRAM.",
                 "examples": [
                   "gib"
                 ],
                 "type": "string"
               }
             }
           }
         }
       },
       "memory": {
         "description": "The amount of RAM allocated to Droplets created of this size. The value is represented in megabytes.",
         "examples": [
           1024
         ],
         "type": "integer",
         "multipleOf": 8.0,
         "minimum": 8.0
       },
       "price_hourly": {
         "description": "This describes the price of the Droplet size as measured hourly. The value is measured in US dollars.",
         "examples": [
           0.00743999984115362
         ],
         "type": "number",
         "format": "float"
       },
       "price_monthly": {
         "description": "This attribute describes the monthly cost of this Droplet size if the Droplet is kept for an entire month. The value is measured in US dollars.",
         "examples": [
           5.0
         ],
         "type": "number",
         "format": "float"
       },
       "regions": {
         "description": "An array containing the region slugs where this size is available for Droplet creates.",
         "examples": [
           [
             "ams2",
             "ams3",
             "blr1",
             "fra1",
             "lon1",
             "nyc1",
             "nyc2",
             "nyc3",
             "sfo1",
             "sfo2",
             "sfo3",
             "sgp1",
             "tor1"
           ]
         ],
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "slug": {
         "description": "A human-readable string that is used to uniquely identify each size.",
         "examples": [
           "s-1vcpu-1gb"
         ],
         "type": "string"
       },
       "transfer": {
         "description": "The amount of transfer bandwidth that is available for Droplets created in this size. This only counts traffic on the public interface. The value is given in terabytes.",
         "examples": [
           1.0
         ],
         "type": "number",
         "format": "float"
       },
       "vcpus": {
         "description": "The number of CPUs allocated to Droplets of this size.",
         "examples": [
           1
         ],
         "type": "integer"
       }
     }
   },
   "size_slug": {
     "description": "The unique slug identifier for the size of this Droplet.",
     "examples": [
       "s-1vcpu-1gb"
     ],
     "type": "string"
   },
   "snapshot_ids": {
     "description": "An array of snapshot IDs of any snapshots created from the Droplet instance.<br>Requires `image:read` scope.",
     "examples": [
       [
         67512819
       ]
     ],
     "type": "array",
     "items": {
       "type": "integer"
     }
   },
   "status": {
     "description": "A status string indicating the state of the Droplet instance. This may be \"new\", \"active\", \"off\", or \"archive\".",
     "examples": [
       "active"
     ],
     "type": "string",
     "enum": [
       "new",
       "active",
       "off",
       "archive"
     ]
   },
   "tags": {
     "description": "An array of Tags the Droplet has been tagged with.<br>Requires `tag:read` scope.",
     "examples": [
       [
         "web",
         "env:prod"
       ]
     ],
     "type": "array",
     "items": {
       "type": "string"
     }
   },
   "vcpus": {
     "description": "The number of virtual CPUs.",
     "examples": [
       1
     ],
     "type": "integer"
   },
   "volume_ids": {
     "description": "A flat array including the unique identifier for each Block Storage volume attached to the Droplet.<br>Requires `block_storage:read` scope.",
     "examples": [
       [
         "506f78a4-e098-11e5-ad9f-000f53306ae1"
       ]
     ],
     "type": "array",
     "items": {
       "type": "string"
     }
   },
   "vpc_uuid": {
     "description": "A string specifying the UUID of the VPC to which the Droplet is assigned.<br>Requires `vpc:read` scope.",
     "examples": [
       "760e09ef-dc84-11e8-981e-3cfdfeaae000"
     ],
     "type": "string"
   }
 }
}

Fields

backup_ids: Vec<i64>

An array of backup IDs of any backups that have been taken of the Droplet instance. Droplet backups are enabled at the time of the instance creation.
Requires image:read scope.

created_at: DateTime<Utc>

A time value given in ISO8601 combined date and time format that represents when the Droplet was created.

disk: i64

The size of the Droplet’s disk in gigabytes.

disk_info: Vec<FloatingIPsGetResponseFloatingIpDropletSubtype1DiskInfoItem>

An array of objects containing information about the disks available to the Droplet.

features: Vec<String>

An array of features enabled on this Droplet.

gpu_info: Option<FloatingIPsGetResponseFloatingIpDropletSubtype1GpuInfo>id: i64

A unique identifier for each Droplet instance. This is automatically generated upon Droplet creation.

image: FloatingIPsGetResponseFloatingIpDropletSubtype1Imagekernel: Option<FloatingIPsGetResponseFloatingIpDropletSubtype1Kernel>

Note: All Droplets created after March 2017 use internal kernels by default. These Droplets will have this attribute set to null.

The current kernel for Droplets with externally managed kernels. This will initially be set to the kernel of the base image when the Droplet is created.

locked: bool

A boolean value indicating whether the Droplet has been locked, preventing actions by users.

memory: i64

Memory of the Droplet in megabytes.

name: String

The human-readable name set for the Droplet instance.

networks: FloatingIPsGetResponseFloatingIpDropletSubtype1Networksnext_backup_window: Option<FloatingIPsGetResponseFloatingIpDropletSubtype1NextBackupWindow>region: FloatingIPsGetResponseFloatingIpDropletSubtype1Regionsize: FloatingIPsGetResponseFloatingIpDropletSubtype1Sizesize_slug: String

The unique slug identifier for the size of this Droplet.

snapshot_ids: Vec<i64>

An array of snapshot IDs of any snapshots created from the Droplet instance.
Requires image:read scope.

status: FloatingIPsGetResponseFloatingIpDropletSubtype1Status

A status string indicating the state of the Droplet instance. This may be “new”, “active”, “off”, or “archive”.

tags: Vec<String>

An array of Tags the Droplet has been tagged with.
Requires tag:read scope.

vcpus: i64

The number of virtual CPUs.

volume_ids: Vec<String>

A flat array including the unique identifier for each Block Storage volume attached to the Droplet.
Requires block_storage:read scope.

vpc_uuid: Option<String>

A string specifying the UUID of the VPC to which the Droplet is assigned.
Requires vpc:read scope.