pub struct FunctionsAccessKeyListResponseAccessKeysItem {
pub created_at: Option<DateTime<Utc>>,
pub expires_at: Option<DateTime<Utc>>,
pub id: Option<String>,
pub name: Option<String>,
pub updated_at: Option<DateTime<Utc>>,
}Expand description
FunctionsAccessKeyListResponseAccessKeysItem
JSON schema
{
"type": "object",
"properties": {
"created_at": {
"description": "The date and time the key was created.",
"readOnly": true,
"examples": [
"2025-12-19T10:30:00Z"
],
"type": "string",
"format": "date-time"
},
"expires_at": {
"description": "When the key expires (null for non-expiring keys).",
"readOnly": true,
"examples": [
"2026-12-19T10:30:00Z"
],
"type": [
"string",
"null"
],
"format": "date-time"
},
"id": {
"description": "The access key's unique identifier with prefix 'dof_v1_'.",
"readOnly": true,
"examples": [
"dof_v1_d79e8aeb42e5476893c7d4c59a166264"
],
"type": "string"
},
"name": {
"description": "The access key's name.",
"examples": [
"my-function-access-key"
],
"type": "string"
},
"updated_at": {
"description": "The date and time the key was last updated.",
"readOnly": true,
"examples": [
"2025-12-19T10:30:00Z"
],
"type": "string",
"format": "date-time"
}
}
}Fields
created_at: Option<DateTime<Utc>>The date and time the key was created.
expires_at: Option<DateTime<Utc>>When the key expires (null for non-expiring keys).
id: Option<String>The access key’s unique identifier with prefix ‘dof_v1_’.
name: Option<String>The access key’s name.
updated_at: Option<DateTime<Utc>>The date and time the key was last updated.