pub struct FunctionsComponentsThatArePartOfThisDeploymentItem {
pub name: Option<String>,
pub namespace: Option<String>,
pub source_commit_hash: Option<String>,
}Expand description
FunctionsComponentsThatArePartOfThisDeploymentItem
JSON schema
{
"type": "object",
"properties": {
"name": {
"title": "The name of this functions component",
"examples": [
"my-functions-component"
],
"type": "string"
},
"namespace": {
"description": "The namespace where the functions are deployed.",
"examples": [
"ap-b2a93513-8d9b-4223-9d61-5e7272c81c32"
],
"type": "string"
},
"source_commit_hash": {
"description": "The commit hash of the repository that was used to build this functions component.",
"examples": [
"54d4a727f457231062439895000d45437c7bb405"
],
"type": "string"
}
}
}Fields
name: Option<String>namespace: Option<String>The namespace where the functions are deployed.
source_commit_hash: Option<String>The commit hash of the repository that was used to build this functions component.