pub struct FunctionsUpdateTriggerBodyScheduledDetails {
pub body: Option<FunctionsUpdateTriggerBodyScheduledDetailsBody>,
pub cron: String,
}Expand description
Trigger details for SCHEDULED type, where body is optional.
JSON schema
{
"description": "Trigger details for SCHEDULED type, where body is optional.\n",
"type": "object",
"required": [
"cron"
],
"properties": {
"body": {
"description": "Optional data to be sent to function while triggering the function.",
"type": [
"object",
"null"
],
"properties": {
"name": {
"examples": [
"Welcome to DO!"
],
"type": "string"
}
}
},
"cron": {
"description": "valid cron expression string which is required for SCHEDULED type triggers.",
"examples": [
"* * * * *"
],
"type": "string"
}
}
}Fields
body: Option<FunctionsUpdateTriggerBodyScheduledDetailsBody>Optional data to be sent to function while triggering the function.
cron: Stringvalid cron expression string which is required for SCHEDULED type triggers.