pub struct FunctionsUpdateTriggerResponseTrigger {
pub created_at: Option<String>,
pub function: Option<String>,
pub is_enabled: Option<bool>,
pub name: Option<String>,
pub namespace: Option<String>,
pub scheduled_details: Option<FunctionsUpdateTriggerResponseTriggerScheduledDetails>,
pub scheduled_runs: Option<FunctionsUpdateTriggerResponseTriggerScheduledRuns>,
pub type_: Option<String>,
pub updated_at: Option<String>,
}Expand description
FunctionsUpdateTriggerResponseTrigger
JSON schema
{
"type": "object",
"properties": {
"created_at": {
"description": "UTC time string.",
"examples": [
"2022-11-11T04:16:45Z"
],
"type": "string"
},
"function": {
"description": "Name of function(action) that exists in the given namespace.",
"examples": [
"hello"
],
"type": "string"
},
"is_enabled": {
"description": "Indicates weather the trigger is paused or unpaused.",
"examples": [
true
],
"type": "boolean"
},
"name": {
"description": "The trigger's unique name within the namespace.",
"examples": [
"my trigger"
],
"type": "string"
},
"namespace": {
"description": "A unique string format of UUID with a prefix fn-.",
"examples": [
"fn-xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx"
],
"type": "string"
},
"scheduled_details": {
"description": "Trigger details for SCHEDULED type, where body is optional.\n",
"type": "object",
"required": [
"cron"
],
"properties": {
"body": {
"description": "Optional data to be sent to function while triggering the function.",
"type": [
"object",
"null"
],
"properties": {
"name": {
"examples": [
"Welcome to DO!"
],
"type": "string"
}
}
},
"cron": {
"description": "valid cron expression string which is required for SCHEDULED type triggers.",
"examples": [
"* * * * *"
],
"type": "string"
}
}
},
"scheduled_runs": {
"type": "object",
"properties": {
"last_run_at": {
"description": "Indicates last run time. null value indicates trigger not run yet.",
"examples": [
"2022-11-11T04:16:45Z"
],
"type": [
"string",
"null"
]
},
"next_run_at": {
"description": "Indicates next run time. null value indicates trigger will not run.",
"examples": [
"2022-11-11T04:16:45Z"
],
"type": [
"string",
"null"
]
}
}
},
"type": {
"description": "String which indicates the type of trigger source like SCHEDULED.",
"examples": [
"SCHEDULED"
],
"type": "string"
},
"updated_at": {
"description": "UTC time string.",
"examples": [
"2022-11-11T04:16:45Z"
],
"type": "string"
}
}
}Fields
created_at: Option<String>UTC time string.
function: Option<String>Name of function(action) that exists in the given namespace.
is_enabled: Option<bool>Indicates weather the trigger is paused or unpaused.
name: Option<String>The trigger’s unique name within the namespace.
namespace: Option<String>A unique string format of UUID with a prefix fn-.
scheduled_details: Option<FunctionsUpdateTriggerResponseTriggerScheduledDetails>scheduled_runs: Option<FunctionsUpdateTriggerResponseTriggerScheduledRuns>type_: Option<String>String which indicates the type of trigger source like SCHEDULED.
updated_at: Option<String>UTC time string.