pub struct GenaiCreateIndexingJobResponse {
pub job: Option<GenaiCreateIndexingJobResponseJob>,
}Expand description
StartKnowledgeBaseIndexingJobOutput description
JSON schema
{
"description": "StartKnowledgeBaseIndexingJobOutput description",
"type": "object",
"properties": {
"job": {
"description": "IndexingJob description",
"type": "object",
"properties": {
"completed_datasources": {
"description": "Number of datasources indexed completed",
"examples": [
123
],
"type": "integer",
"format": "int64"
},
"created_at": {
"description": "Creation date / time",
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"data_source_jobs": {
"description": "Details on Data Sources included in the Indexing Job",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiIndexedDataSource",
"type": "object",
"additionalProperties": true
}
},
"data_source_uuids": {
"examples": [
[
"example string"
]
],
"type": "array",
"items": {
"examples": [
"example string"
],
"type": "string"
}
},
"finished_at": {
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"is_report_available": {
"description": "Boolean value to determine if the indexing job details are available",
"examples": [
true
],
"type": "boolean"
},
"knowledge_base_uuid": {
"description": "Knowledge base id",
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": "string"
},
"phase": {
"description": "Auto-generated fallback definition for: apiBatchJobPhase",
"type": "object",
"additionalProperties": true
},
"started_at": {
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"status": {
"description": "Auto-generated fallback definition for: apiIndexJobStatus",
"type": "object",
"additionalProperties": true
},
"tokens": {
"description": "Number of tokens [This field is deprecated]",
"examples": [
123
],
"type": "integer",
"format": "int64"
},
"total_datasources": {
"description": "Number of datasources being indexed",
"examples": [
123
],
"type": "integer",
"format": "int64"
},
"total_tokens": {
"description": "Total Tokens Consumed By the Indexing Job",
"examples": [
"12345"
],
"type": "string",
"format": "uint64"
},
"updated_at": {
"description": "Last modified",
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"uuid": {
"description": "Unique id",
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": "string"
}
}
}
}
}Fields
job: Option<GenaiCreateIndexingJobResponseJob>Trait Implementations
Sourceimpl Clone for GenaiCreateIndexingJobResponse
impl Clone for GenaiCreateIndexingJobResponse
Sourcefn clone(&self) -> GenaiCreateIndexingJobResponse
fn clone(&self) -> GenaiCreateIndexingJobResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for GenaiCreateIndexingJobResponse
impl<'de> Deserialize<'de> for GenaiCreateIndexingJobResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&GenaiCreateIndexingJobResponse> for GenaiCreateIndexingJobResponse
impl From<&GenaiCreateIndexingJobResponse> for GenaiCreateIndexingJobResponse
Sourcefn from(value: &GenaiCreateIndexingJobResponse) -> Self
fn from(value: &GenaiCreateIndexingJobResponse) -> Self
Converts to this type from the input type.