pub struct GenaiDetachAgentFunctionResponseAgent {Show 49 fields
pub anthropic_api_key: Map<String, Value>,
pub api_key_infos: Vec<Map<String, Value>>,
pub api_keys: Vec<Map<String, Value>>,
pub chatbot: Option<GenaiDetachAgentFunctionResponseAgentChatbot>,
pub chatbot_identifiers: Vec<Map<String, Value>>,
pub child_agents: Vec<Map<String, Value>>,
pub conversation_logs_enabled: Option<bool>,
pub created_at: Option<DateTime<Utc>>,
pub deployment: Map<String, Value>,
pub description: Option<String>,
pub functions: Vec<Map<String, Value>>,
pub guardrails: Vec<Map<String, Value>>,
pub if_case: Option<String>,
pub instruction: Option<String>,
pub k: Option<i64>,
pub knowledge_bases: Vec<Map<String, Value>>,
pub logging_config: Map<String, Value>,
pub max_tokens: Option<i64>,
pub mcp_servers: Vec<Map<String, Value>>,
pub model: Map<String, Value>,
pub model_provider_key: Map<String, Value>,
pub model_router: Map<String, Value>,
pub name: Option<String>,
pub openai_api_key: Map<String, Value>,
pub parent_agents: Vec<Map<String, Value>>,
pub project_id: Option<String>,
pub provide_citations: Option<bool>,
pub reasoning_effort: Option<String>,
pub region: Option<String>,
pub retrieval_method: Map<String, Value>,
pub route_created_at: Option<DateTime<Utc>>,
pub route_created_by: Option<String>,
pub route_name: Option<String>,
pub route_uuid: Option<String>,
pub tags: Vec<String>,
pub temperature: Option<f32>,
pub template: Map<String, Value>,
pub thinking_token_budget: Option<i64>,
pub top_p: Option<f32>,
pub updated_at: Option<DateTime<Utc>>,
pub url: Option<String>,
pub user_id: Option<String>,
pub uuid: Option<String>,
pub version_hash: Option<String>,
pub vpc_egress_ips: Vec<String>,
pub vpc_uuid: Option<String>,
pub web_fetch_enabled: Option<bool>,
pub web_search_enabled: Option<bool>,
pub workspace: Map<String, Value>,
}Expand description
An Agent
JSON schema
{
"description": "An Agent",
"type": "object",
"properties": {
"anthropic_api_key": {
"description": "Auto-generated fallback definition for: apiAnthropicAPIKeyInfo",
"type": "object",
"additionalProperties": true
},
"api_key_infos": {
"description": "Api key infos",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiAgentAPIKeyInfo",
"type": "object",
"additionalProperties": true
}
},
"api_keys": {
"description": "Api keys",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiAgentAPIKey",
"type": "object",
"additionalProperties": true
}
},
"chatbot": {
"type": "object",
"properties": {
"enabled": {
"examples": [
true
],
"type": "boolean"
},
"id": {
"examples": [
"chatbot-123"
],
"type": "string"
},
"name": {
"examples": [
"Customer Support Bot"
],
"type": "string"
},
"settings": {
"type": "object",
"additionalProperties": true
}
}
},
"chatbot_identifiers": {
"description": "Chatbot identifiers",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiAgentChatbotIdentifier",
"type": "object",
"additionalProperties": true
}
},
"child_agents": {
"description": "Child agents",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiAgent",
"type": "object",
"additionalProperties": true
}
},
"conversation_logs_enabled": {
"description": "Whether conversation logs are enabled for the agent",
"examples": [
true
],
"type": "boolean"
},
"created_at": {
"description": "Creation date / time",
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"deployment": {
"description": "Auto-generated fallback definition for: apiDeployment",
"type": "object",
"additionalProperties": true
},
"description": {
"description": "Description of agent",
"examples": [
"example string"
],
"type": "string"
},
"functions": {
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiAgentFunction",
"type": "object",
"additionalProperties": true
}
},
"guardrails": {
"description": "The guardrails the agent is attached to",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiAgentGuardrail",
"type": "object",
"additionalProperties": true
}
},
"if_case": {
"examples": [
"example string"
],
"type": "string"
},
"instruction": {
"description": "Agent instruction. Instructions help your agent to perform its job effectively. See [Write Effective Agent Instructions](https://docs.digitalocean.com/products/genai-platform/concepts/best-practices/#agent-instructions) for best practices.",
"examples": [
"example string"
],
"type": "string"
},
"k": {
"examples": [
123
],
"type": "integer",
"format": "int64"
},
"knowledge_bases": {
"description": "Knowledge bases",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiKnowledgeBase",
"type": "object",
"additionalProperties": true
}
},
"logging_config": {
"description": "Auto-generated fallback definition for: apiAgentLoggingConfig",
"type": "object",
"additionalProperties": true
},
"max_tokens": {
"examples": [
123
],
"type": "integer",
"format": "int64"
},
"mcp_servers": {
"description": "MCP (Model Context Protocol) servers attached to this agent",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiMcpServer",
"type": "object",
"additionalProperties": true
}
},
"model": {
"description": "Auto-generated fallback definition for: apiModel",
"type": "object",
"additionalProperties": true
},
"model_provider_key": {
"description": "Auto-generated fallback definition for: apiModelProviderKeyInfo",
"type": "object",
"additionalProperties": true
},
"model_router": {
"description": "Auto-generated fallback definition for: apiModelRouter",
"type": "object",
"additionalProperties": true
},
"name": {
"description": "Agent name",
"examples": [
"example name"
],
"type": "string"
},
"openai_api_key": {
"description": "Auto-generated fallback definition for: apiOpenAIAPIKeyInfo",
"type": "object",
"additionalProperties": true
},
"parent_agents": {
"description": "Parent agents",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiAgent",
"type": "object",
"additionalProperties": true
}
},
"project_id": {
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": "string"
},
"provide_citations": {
"description": "Whether the agent should provide in-response citations",
"examples": [
true
],
"type": "boolean"
},
"reasoning_effort": {
"description": "The reasoning effort for the agent",
"examples": [
"example string"
],
"type": "string"
},
"region": {
"description": "Region code",
"examples": [
"example string"
],
"type": "string"
},
"retrieval_method": {
"description": "Auto-generated fallback definition for: apiRetrievalMethod",
"type": "object",
"additionalProperties": true
},
"route_created_at": {
"description": "Creation of route date / time",
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"route_created_by": {
"examples": [
"12345"
],
"type": "string",
"format": "uint64"
},
"route_name": {
"description": "Route name",
"examples": [
"example name"
],
"type": "string"
},
"route_uuid": {
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": "string"
},
"tags": {
"description": "Agent tag to organize related resources",
"examples": [
[
"example string"
]
],
"type": "array",
"items": {
"examples": [
"example string"
],
"type": "string"
}
},
"temperature": {
"examples": [
123
],
"type": "number",
"format": "float"
},
"template": {
"description": "Auto-generated fallback definition for: apiAgentTemplate",
"type": "object",
"additionalProperties": true
},
"thinking_token_budget": {
"description": "The thinking token budget for Anthropic extended thinking (0 = disabled)",
"examples": [
123
],
"type": "integer",
"format": "int64"
},
"top_p": {
"examples": [
123
],
"type": "number",
"format": "float"
},
"updated_at": {
"description": "Last modified",
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"url": {
"description": "Access your agent under this url",
"examples": [
"example string"
],
"type": "string"
},
"user_id": {
"description": "Id of user that created the agent",
"examples": [
"12345"
],
"type": "string",
"format": "uint64"
},
"uuid": {
"description": "Unique agent id",
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": "string"
},
"version_hash": {
"description": "The latest version of the agent",
"examples": [
"example string"
],
"type": "string"
},
"vpc_egress_ips": {
"description": "VPC Egress IPs",
"examples": [
[
"example string"
]
],
"type": "array",
"items": {
"examples": [
"example string"
],
"type": "string"
}
},
"vpc_uuid": {
"examples": [
"\"12345678-1234-1234-1234-123456789012\""
],
"type": "string"
},
"web_fetch_enabled": {
"description": "Whether this agent can use the built-in web_fetch tool.",
"examples": [
true
],
"type": "boolean"
},
"web_search_enabled": {
"description": "Whether this agent can use the built-in web_search tool.",
"examples": [
true
],
"type": "boolean"
},
"workspace": {
"description": "Auto-generated fallback definition for: apiWorkspace",
"type": "object",
"additionalProperties": true
}
}
}Fields
anthropic_api_key: Map<String, Value>Auto-generated fallback definition for: apiAnthropicAPIKeyInfo
api_key_infos: Vec<Map<String, Value>>Api key infos
api_keys: Vec<Map<String, Value>>Api keys
chatbot: Option<GenaiDetachAgentFunctionResponseAgentChatbot>chatbot_identifiers: Vec<Map<String, Value>>Chatbot identifiers
child_agents: Vec<Map<String, Value>>Child agents
conversation_logs_enabled: Option<bool>Whether conversation logs are enabled for the agent
created_at: Option<DateTime<Utc>>Creation date / time
deployment: Map<String, Value>Auto-generated fallback definition for: apiDeployment
description: Option<String>Description of agent
functions: Vec<Map<String, Value>>guardrails: Vec<Map<String, Value>>The guardrails the agent is attached to
if_case: Option<String>instruction: Option<String>Agent instruction. Instructions help your agent to perform its job effectively. See Write Effective Agent Instructions for best practices.
k: Option<i64>knowledge_bases: Vec<Map<String, Value>>Knowledge bases
logging_config: Map<String, Value>Auto-generated fallback definition for: apiAgentLoggingConfig
max_tokens: Option<i64>mcp_servers: Vec<Map<String, Value>>MCP (Model Context Protocol) servers attached to this agent
model: Map<String, Value>Auto-generated fallback definition for: apiModel
model_provider_key: Map<String, Value>Auto-generated fallback definition for: apiModelProviderKeyInfo
model_router: Map<String, Value>Auto-generated fallback definition for: apiModelRouter
name: Option<String>Agent name
openai_api_key: Map<String, Value>Auto-generated fallback definition for: apiOpenAIAPIKeyInfo
parent_agents: Vec<Map<String, Value>>Parent agents
project_id: Option<String>provide_citations: Option<bool>Whether the agent should provide in-response citations
reasoning_effort: Option<String>The reasoning effort for the agent
region: Option<String>Region code
retrieval_method: Map<String, Value>Auto-generated fallback definition for: apiRetrievalMethod
route_created_at: Option<DateTime<Utc>>Creation of route date / time
route_created_by: Option<String>route_name: Option<String>Route name
route_uuid: Option<String>Agent tag to organize related resources
temperature: Option<f32>template: Map<String, Value>Auto-generated fallback definition for: apiAgentTemplate
thinking_token_budget: Option<i64>The thinking token budget for Anthropic extended thinking (0 = disabled)
top_p: Option<f32>updated_at: Option<DateTime<Utc>>Last modified
url: Option<String>Access your agent under this url
user_id: Option<String>Id of user that created the agent
uuid: Option<String>Unique agent id
version_hash: Option<String>The latest version of the agent
vpc_egress_ips: Vec<String>VPC Egress IPs
vpc_uuid: Option<String>web_fetch_enabled: Option<bool>Whether this agent can use the built-in web_fetch tool.
web_search_enabled: Option<bool>Whether this agent can use the built-in web_search tool.
workspace: Map<String, Value>Auto-generated fallback definition for: apiWorkspace