GenaiGetEvaluationRunResponseEvaluationRun

Struct GenaiGetEvaluationRunResponseEvaluationRun 

pub struct GenaiGetEvaluationRunResponseEvaluationRun {
Show 23 fields pub agent_deleted: Option<bool>, pub agent_deployment_name: Option<String>, pub agent_name: Option<String>, pub agent_uuid: Option<String>, pub agent_version_hash: Option<String>, pub agent_workspace_uuid: Option<String>, pub created_by_user_email: Option<String>, pub created_by_user_id: Option<String>, pub error_description: Option<String>, pub evaluation_run_uuid: Option<String>, pub evaluation_test_case_workspace_uuid: Option<String>, pub finished_at: Option<DateTime<Utc>>, pub pass_status: Option<bool>, pub queued_at: Option<DateTime<Utc>>, pub run_level_metric_results: Vec<Map<String, Value>>, pub run_name: Option<String>, pub star_metric_result: Map<String, Value>, pub started_at: Option<DateTime<Utc>>, pub status: Map<String, Value>, pub test_case_description: Option<String>, pub test_case_name: Option<String>, pub test_case_uuid: Option<String>, pub test_case_version: Option<i64>,
}
GenaiGetEvaluationRunResponseEvaluationRun

JSON schema
{
 "type": "object",
 "properties": {
   "agent_deleted": {
     "description": "Whether agent is deleted",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "agent_deployment_name": {
     "description": "The agent deployment name",
     "examples": [
       "example name"
     ],
     "type": "string"
   },
   "agent_name": {
     "description": "Agent name",
     "examples": [
       "example name"
     ],
     "type": "string"
   },
   "agent_uuid": {
     "description": "Agent UUID.",
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "agent_version_hash": {
     "description": "Version hash",
     "examples": [
       "example string"
     ],
     "type": "string"
   },
   "agent_workspace_uuid": {
     "description": "Agent workspace uuid",
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "created_by_user_email": {
     "examples": [
       "example@example.com"
     ],
     "type": "string"
   },
   "created_by_user_id": {
     "examples": [
       "12345"
     ],
     "type": "string",
     "format": "uint64"
   },
   "error_description": {
     "description": "The error description",
     "examples": [
       "example string"
     ],
     "type": "string"
   },
   "evaluation_run_uuid": {
     "description": "Evaluation run UUID.",
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "evaluation_test_case_workspace_uuid": {
     "description": "Evaluation test case workspace uuid",
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "finished_at": {
     "description": "Run end time.",
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "pass_status": {
     "description": "The pass status of the evaluation run based on the star metric.",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "queued_at": {
     "description": "Run queued time.",
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "run_level_metric_results": {
     "type": "array",
     "items": {
       "description": "Auto-generated fallback definition for: apiEvaluationMetricResult",
       "type": "object",
       "additionalProperties": true
     }
   },
   "run_name": {
     "description": "Run name.",
     "examples": [
       "example name"
     ],
     "type": "string"
   },
   "star_metric_result": {
     "description": "Auto-generated fallback definition for: apiEvaluationMetricResult",
     "type": "object",
     "additionalProperties": true
   },
   "started_at": {
     "description": "Run start time.",
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "status": {
     "description": "Auto-generated fallback definition for: apiEvaluationRunStatus",
     "type": "object",
     "additionalProperties": true
   },
   "test_case_description": {
     "description": "Test case description.",
     "examples": [
       "example string"
     ],
     "type": "string"
   },
   "test_case_name": {
     "description": "Test case name.",
     "examples": [
       "example name"
     ],
     "type": "string"
   },
   "test_case_uuid": {
     "description": "Test-case UUID.",
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "test_case_version": {
     "description": "Test-case-version.",
     "examples": [
       123
     ],
     "type": "integer",
     "format": "int64"
   }
 }
}

Fields

agent_deleted: Option<bool>

Whether agent is deleted

agent_deployment_name: Option<String>

The agent deployment name

agent_name: Option<String>

Agent name

agent_uuid: Option<String>

Agent UUID.

agent_version_hash: Option<String>

Version hash

agent_workspace_uuid: Option<String>

Agent workspace uuid

created_by_user_email: Option<String>created_by_user_id: Option<String>error_description: Option<String>

The error description

evaluation_run_uuid: Option<String>

Evaluation run UUID.

evaluation_test_case_workspace_uuid: Option<String>

Evaluation test case workspace uuid

finished_at: Option<DateTime<Utc>>

Run end time.

pass_status: Option<bool>

The pass status of the evaluation run based on the star metric.

queued_at: Option<DateTime<Utc>>

Run queued time.

run_level_metric_results: Vec<Map<String, Value>>run_name: Option<String>

Run name.

star_metric_result: Map<String, Value>

Auto-generated fallback definition for: apiEvaluationMetricResult

started_at: Option<DateTime<Utc>>

Run start time.

status: Map<String, Value>

Auto-generated fallback definition for: apiEvaluationRunStatus

test_case_description: Option<String>

Test case description.

test_case_name: Option<String>

Test case name.

test_case_uuid: Option<String>

Test-case UUID.

test_case_version: Option<i64>

Test-case-version.