GenaiGetKnowledgeBaseResponseKnowledgeBase

Struct GenaiGetKnowledgeBaseResponseKnowledgeBase 

pub struct GenaiGetKnowledgeBaseResponseKnowledgeBase {
Show 14 fields pub added_to_agent_at: Option<DateTime<Utc>>, pub created_at: Option<DateTime<Utc>>, pub database_id: Option<String>, pub embedding_model_uuid: Option<String>, pub is_public: Option<bool>, pub last_indexing_job: Map<String, Value>, pub name: Option<String>, pub project_id: Option<String>, pub region: Option<String>, pub reranking_config: Map<String, Value>, pub tags: Vec<String>, pub updated_at: Option<DateTime<Utc>>, pub user_id: Option<String>, pub uuid: Option<String>,
}
Knowledgebase Description

JSON schema
{
 "description": "Knowledgebase Description",
 "type": "object",
 "properties": {
   "added_to_agent_at": {
     "description": "Time when the knowledge base was added to the agent",
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "created_at": {
     "description": "Creation date / time",
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "database_id": {
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "embedding_model_uuid": {
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "is_public": {
     "description": "Whether the knowledge base is public or not",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "last_indexing_job": {
     "description": "Auto-generated fallback definition for: apiIndexingJob",
     "type": "object",
     "additionalProperties": true
   },
   "name": {
     "description": "Name of knowledge base",
     "examples": [
       "example name"
     ],
     "type": "string"
   },
   "project_id": {
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "region": {
     "description": "Region code",
     "examples": [
       "example string"
     ],
     "type": "string"
   },
   "reranking_config": {
     "description": "Auto-generated fallback definition for: apiRerankingConfiguration",
     "type": "object",
     "additionalProperties": true
   },
   "tags": {
     "description": "Tags to organize related resources",
     "examples": [
       [
         "example string"
       ]
     ],
     "type": "array",
     "items": {
       "examples": [
         "example string"
       ],
       "type": "string"
     }
   },
   "updated_at": {
     "description": "Last modified",
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "user_id": {
     "description": "Id of user that created the knowledge base",
     "examples": [
       "12345"
     ],
     "type": "string",
     "format": "int64"
   },
   "uuid": {
     "description": "Unique id for knowledge base",
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   }
 }
}

Fields

added_to_agent_at: Option<DateTime<Utc>>

Time when the knowledge base was added to the agent

created_at: Option<DateTime<Utc>>

Creation date / time

database_id: Option<String>embedding_model_uuid: Option<String>is_public: Option<bool>

Whether the knowledge base is public or not

last_indexing_job: Map<String, Value>

Auto-generated fallback definition for: apiIndexingJob

name: Option<String>

Name of knowledge base

project_id: Option<String>region: Option<String>

Region code

reranking_config: Map<String, Value>

Auto-generated fallback definition for: apiRerankingConfiguration

tags: Vec<String>

Tags to organize related resources

updated_at: Option<DateTime<Utc>>

Last modified

user_id: Option<String>

Id of user that created the knowledge base

uuid: Option<String>

Unique id for knowledge base