pub struct GenaiGetModelEvaluationRunResponseResultsItem {
pub candidate_model_name: Option<String>,
pub candidate_model_uuid: Option<String>,
pub candidate_routed_task: Option<String>,
pub ground_truth: Option<String>,
pub input: Option<String>,
pub metric_results: Vec<Map<String, Value>>,
pub output: Option<String>,
}Expand description
Result for a single prompt in a model evaluation run.
JSON schema
{
"description": "Result for a single prompt in a model evaluation run.",
"type": "object",
"properties": {
"candidate_model_name": {
"examples": [
"example name"
],
"type": "string"
},
"candidate_model_uuid": {
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": "string"
},
"candidate_routed_task": {
"examples": [
"Coding & brainstorming"
],
"type": "string"
},
"ground_truth": {
"examples": [
"example string"
],
"type": "string"
},
"input": {
"description": "The input query sent to the candidate model.",
"examples": [
"example string"
],
"type": "string"
},
"metric_results": {
"description": "Per-metric scores and judge reasoning for this prompt.",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiEvaluationMetricResult",
"type": "object",
"additionalProperties": true
}
},
"output": {
"description": "The response from the candidate model.",
"examples": [
"example string"
],
"type": "string"
}
}
}Fields
candidate_model_name: Option<String>candidate_model_uuid: Option<String>candidate_routed_task: Option<String>ground_truth: Option<String>input: Option<String>The input query sent to the candidate model.
metric_results: Vec<Map<String, Value>>Per-metric scores and judge reasoning for this prompt.
output: Option<String>The response from the candidate model.