GenaiListIndexingJobsByKnowledgeBaseResponseJobsItem

Struct GenaiListIndexingJobsByKnowledgeBaseResponseJobsItem 

pub struct GenaiListIndexingJobsByKnowledgeBaseResponseJobsItem {
Show 15 fields pub completed_datasources: Option<i64>, pub created_at: Option<DateTime<Utc>>, pub data_source_jobs: Vec<Map<String, Value>>, pub data_source_uuids: Vec<String>, pub finished_at: Option<DateTime<Utc>>, pub is_report_available: Option<bool>, pub knowledge_base_uuid: Option<String>, pub phase: Map<String, Value>, pub started_at: Option<DateTime<Utc>>, pub status: Map<String, Value>, pub tokens: Option<i64>, pub total_datasources: Option<i64>, pub total_tokens: Option<String>, pub updated_at: Option<DateTime<Utc>>, pub uuid: Option<String>,
}
IndexingJob description

JSON schema
{
 "description": "IndexingJob description",
 "type": "object",
 "properties": {
   "completed_datasources": {
     "description": "Number of datasources indexed completed",
     "examples": [
       123
     ],
     "type": "integer",
     "format": "int64"
   },
   "created_at": {
     "description": "Creation date / time",
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "data_source_jobs": {
     "description": "Details on Data Sources included in the Indexing Job",
     "type": "array",
     "items": {
       "description": "Auto-generated fallback definition for: apiIndexedDataSource",
       "type": "object",
       "additionalProperties": true
     }
   },
   "data_source_uuids": {
     "examples": [
       [
         "example string"
       ]
     ],
     "type": "array",
     "items": {
       "examples": [
         "example string"
       ],
       "type": "string"
     }
   },
   "finished_at": {
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "is_report_available": {
     "description": "Boolean value to determine if the indexing job details are available",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "knowledge_base_uuid": {
     "description": "Knowledge base id",
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   },
   "phase": {
     "description": "Auto-generated fallback definition for: apiBatchJobPhase",
     "type": "object",
     "additionalProperties": true
   },
   "started_at": {
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "status": {
     "description": "Auto-generated fallback definition for: apiIndexJobStatus",
     "type": "object",
     "additionalProperties": true
   },
   "tokens": {
     "description": "Number of tokens [This field is deprecated]",
     "examples": [
       123
     ],
     "type": "integer",
     "format": "int64"
   },
   "total_datasources": {
     "description": "Number of datasources being indexed",
     "examples": [
       123
     ],
     "type": "integer",
     "format": "int64"
   },
   "total_tokens": {
     "description": "Total Tokens Consumed By the Indexing Job",
     "examples": [
       "12345"
     ],
     "type": "string",
     "format": "uint64"
   },
   "updated_at": {
     "description": "Last modified",
     "examples": [
       "2023-01-01T00:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "uuid": {
     "description": "Unique id",
     "examples": [
       "123e4567-e89b-12d3-a456-426614174000"
     ],
     "type": "string"
   }
 }
}

Fields

completed_datasources: Option<i64>

Number of datasources indexed completed

created_at: Option<DateTime<Utc>>

Creation date / time

data_source_jobs: Vec<Map<String, Value>>

Details on Data Sources included in the Indexing Job

data_source_uuids: Vec<String>finished_at: Option<DateTime<Utc>>is_report_available: Option<bool>

Boolean value to determine if the indexing job details are available

knowledge_base_uuid: Option<String>

Knowledge base id

phase: Map<String, Value>

Auto-generated fallback definition for: apiBatchJobPhase

started_at: Option<DateTime<Utc>>status: Map<String, Value>

Auto-generated fallback definition for: apiIndexJobStatus

tokens: Option<i64>

Number of tokens [This field is deprecated]

total_datasources: Option<i64>

Number of datasources being indexed

total_tokens: Option<String>

Total Tokens Consumed By the Indexing Job

updated_at: Option<DateTime<Utc>>

Last modified

uuid: Option<String>

Unique id