pub struct GenaiUpdateAgentDeploymentVisibilityBody {
pub uuid: Option<String>,
pub visibility: GenaiUpdateAgentDeploymentVisibilityBodyVisibility,
}Expand description
UpdateAgentDeploymentVisibilityInputPublic description
JSON schema
{
"description": "UpdateAgentDeploymentVisibilityInputPublic description",
"type": "object",
"properties": {
"uuid": {
"description": "Unique id",
"examples": [
"\"12345678-1234-1234-1234-123456789012\""
],
"type": "string"
},
"visibility": {
"description": "- VISIBILITY_UNKNOWN: The status of the deployment is unknown\n - VISIBILITY_DISABLED: The deployment is disabled and will no longer service requests\n - VISIBILITY_PLAYGROUND: Deprecated: No longer a valid state\n - VISIBILITY_PUBLIC: The deployment is public and will service requests from the public internet\n - VISIBILITY_PRIVATE: The deployment is private and will only service requests from other agents, or through API keys",
"default": "VISIBILITY_UNKNOWN",
"examples": [
"VISIBILITY_UNKNOWN"
],
"type": "string",
"enum": [
"VISIBILITY_UNKNOWN",
"VISIBILITY_DISABLED",
"VISIBILITY_PLAYGROUND",
"VISIBILITY_PUBLIC",
"VISIBILITY_PRIVATE"
]
}
}
}Fields
uuid: Option<String>Unique id
visibility: GenaiUpdateAgentDeploymentVisibilityBodyVisibility- VISIBILITY_UNKNOWN: The status of the deployment is unknown
- VISIBILITY_DISABLED: The deployment is disabled and will no longer service requests
- VISIBILITY_PLAYGROUND: Deprecated: No longer a valid state
- VISIBILITY_PUBLIC: The deployment is public and will service requests from the public internet
- VISIBILITY_PRIVATE: The deployment is private and will only service requests from other agents, or through API keys