pub struct GenaiUpdateCustomEvaluationMetricBody {
pub config: Option<GenaiUpdateCustomEvaluationMetricBodyConfig>,
pub description: Option<String>,
pub metric_name: Option<String>,
pub metric_uuid: Option<String>,
}Expand description
GenaiUpdateCustomEvaluationMetricBody
JSON schema
{
"type": "object",
"properties": {
"config": {
"description": "Configuration for a custom model-evaluation metric scored by an LLM judge.\nPrompt and model response are always included in the judge context.",
"type": "object",
"properties": {
"created_at": {
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"deleted_at": {
"description": "When set, the custom metric is soft-deleted and must not appear in pickers.",
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"requires_ground_truth": {
"description": "When true, each row must provide ground truth and it is included in the judge context.\nWhen false, ground truth is not required and is not sent to the judge.",
"examples": [
true
],
"type": "boolean"
},
"scoring_prompt": {
"description": "Instructions for the judge model (multi-line).",
"examples": [
"example string"
],
"type": "string"
},
"updated_at": {
"examples": [
"2023-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
}
}
},
"description": {
"examples": [
"example string"
],
"type": "string"
},
"metric_name": {
"examples": [
"\"My domain tone metric\""
],
"type": "string"
},
"metric_uuid": {
"examples": [
"\"12345678-1234-1234-1234-123456789012\""
],
"type": "string"
}
}
}Fields
config: Option<GenaiUpdateCustomEvaluationMetricBodyConfig>description: Option<String>metric_name: Option<String>metric_uuid: Option<String>Trait Implementations
Sourceimpl Clone for GenaiUpdateCustomEvaluationMetricBody
impl Clone for GenaiUpdateCustomEvaluationMetricBody
Sourcefn clone(&self) -> GenaiUpdateCustomEvaluationMetricBody
fn clone(&self) -> GenaiUpdateCustomEvaluationMetricBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for GenaiUpdateCustomEvaluationMetricBody
impl<'de> Deserialize<'de> for GenaiUpdateCustomEvaluationMetricBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&GenaiUpdateCustomEvaluationMetricBody> for GenaiUpdateCustomEvaluationMetricBody
impl From<&GenaiUpdateCustomEvaluationMetricBody> for GenaiUpdateCustomEvaluationMetricBody
Sourcefn from(value: &GenaiUpdateCustomEvaluationMetricBody) -> Self
fn from(value: &GenaiUpdateCustomEvaluationMetricBody) -> Self
Converts to this type from the input type.