InferenceCreateChatCompletionResponseChoicesItemLogprobsRefusalItem

Struct InferenceCreateChatCompletionResponseChoicesItemLogprobsRefusalItem 

pub struct InferenceCreateChatCompletionResponseChoicesItemLogprobsRefusalItem {
    pub bytes: Option<Vec<i64>>,
    pub logprob: f64,
    pub token: String,
    pub top_logprobs: Vec<InferenceCreateChatCompletionResponseChoicesItemLogprobsRefusalItemTopLogprobsItem>,
}
InferenceCreateChatCompletionResponseChoicesItemLogprobsRefusalItem

JSON schema
{
 "type": "object",
 "required": [
   "bytes",
   "logprob",
   "token",
   "top_logprobs"
 ],
 "properties": {
   "bytes": {
     "description": "A list of integers representing the UTF-8 bytes representation of the token. Can be null if there is no bytes representation for the token.",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "type": "integer"
     }
   },
   "logprob": {
     "description": "The log probability of this token, if it is within the top 20 most likely tokens. Otherwise, the value -9999.0 is used to signify that the token is very unlikely.",
     "examples": [
       -1.2345
     ],
     "type": "number"
   },
   "token": {
     "description": "The token.",
     "examples": [
       "Hello"
     ],
     "type": "string"
   },
   "top_logprobs": {
     "description": "List of the most likely tokens and their log probability, at this token position.",
     "type": "array",
     "items": {
       "type": "object",
       "required": [
         "bytes",
         "logprob",
         "token"
       ],
       "properties": {
         "bytes": {
           "type": [
             "array",
             "null"
           ],
           "items": {
             "type": "integer"
           }
         },
         "logprob": {
           "description": "The log probability of this token.",
           "examples": [
             -1.2345
           ],
           "type": "number"
         },
         "token": {
           "description": "The token.",
           "examples": [
             "Hello"
           ],
           "type": "string"
         }
       }
     }
   }
 }
}

Fields

bytes: Option<Vec<i64>>

A list of integers representing the UTF-8 bytes representation of the token. Can be null if there is no bytes representation for the token.

logprob: f64token: String

The token.

top_logprobs: Vec<InferenceCreateChatCompletionResponseChoicesItemLogprobsRefusalItemTopLogprobsItem>

List of the most likely tokens and their log probability, at this token position.