KubernetesAddNodePoolResponseNodePool

Struct KubernetesAddNodePoolResponseNodePool 

pub struct KubernetesAddNodePoolResponseNodePool {
    pub auto_scale: Option<bool>,
    pub count: i64,
    pub id: Option<Uuid>,
    pub labels: Option<Map<String, Value>>,
    pub max_nodes: Option<i64>,
    pub min_nodes: Option<i64>,
    pub name: String,
    pub nodes: Vec<Map<String, Value>>,
    pub size: String,
    pub tags: Vec<String>,
    pub taints: Vec<KubernetesAddNodePoolResponseNodePoolTaintsItem>,
}
KubernetesAddNodePoolResponseNodePool

JSON schema
{
 "type": "object",
 "allOf": [
   {
     "type": "object",
     "properties": {
       "size": {
         "description": "The slug identifier for the type of Droplet used as workers in the node pool.",
         "examples": [
           "s-1vcpu-2gb"
         ],
         "type": "string"
       }
     }
   },
   {
     "type": "object",
     "properties": {
       "auto_scale": {
         "description": "A boolean value indicating whether auto-scaling is enabled for this node pool.",
         "examples": [
           true
         ],
         "type": "boolean"
       },
       "count": {
         "description": "The number of Droplet instances in the node pool.",
         "examples": [
           3
         ],
         "type": "integer"
       },
       "id": {
         "description": "A unique ID that can be used to identify and reference a specific node pool.",
         "readOnly": true,
         "examples": [
           "cdda885e-7663-40c8-bc74-3a036c66545d"
         ],
         "type": "string",
         "format": "uuid"
       },
       "labels": {
         "description": "An object of key/value mappings specifying labels to apply to all nodes in a pool. Labels will automatically be applied to all existing nodes and any subsequent nodes added to the pool. Note that when a label is removed, it is not deleted from the nodes in the pool.",
         "type": [
           "object",
           "null"
         ]
       },
       "max_nodes": {
         "description": "The maximum number of nodes that this node pool can be auto-scaled to. The value will be `0` if `auto_scale` is set to `false`.",
         "examples": [
           6
         ],
         "type": "integer"
       },
       "min_nodes": {
         "description": "The minimum number of nodes that this node pool can be auto-scaled to. The value will be `0` if `auto_scale` is set to `false`.",
         "examples": [
           3
         ],
         "type": "integer"
       },
       "name": {
         "description": "A human-readable name for the node pool.",
         "examples": [
           "frontend-pool"
         ],
         "type": "string"
       },
       "nodes": {
         "description": "An object specifying the details of a specific worker node in a node pool.",
         "readOnly": true,
         "type": "array",
         "items": {
           "description": "Fallback schema for missing file reference",
           "type": "object",
           "additionalProperties": true
         }
       },
       "tags": {
         "description": "An array containing the tags applied to the node pool. All node pools are automatically tagged `k8s`, `k8s-worker`, and `k8s:$K8S_CLUSTER_ID`. <br><br>Requires `tag:read` scope.",
         "examples": [
           [
             "k8s",
             "k8s:bd5f5959-5e1e-4205-a714-a914373942af",
             "k8s-worker",
             "production",
             "web-team"
           ]
         ],
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "taints": {
         "description": "An array of taints to apply to all nodes in a pool. Taints will automatically be applied to all existing nodes and any subsequent nodes added to the pool. When a taint is removed, it is deleted from all nodes in the pool.",
         "type": "array",
         "items": {
           "type": "object",
           "required": [
             "effect",
             "key"
           ],
           "properties": {
             "effect": {
               "description": "The taint effect",
               "examples": [
                 "NoSchedule"
               ],
               "type": "string",
               "enum": [
                 "NoSchedule",
                 "PreferNoSchedule",
                 "NoExecute"
               ]
             },
             "key": {
               "description": "The taint key",
               "examples": [
                 "node.kubernetes.io/example-key"
               ],
               "type": "string"
             },
             "value": {
               "description": "The taint value",
               "examples": [
                 "example-value"
               ],
               "type": "string"
             }
           }
         }
       }
     }
   }
 ],
 "required": [
   "count",
   "name",
   "size"
 ]
}

Fields

auto_scale: Option<bool>

A boolean value indicating whether auto-scaling is enabled for this node pool.

count: i64

The number of Droplet instances in the node pool.

id: Option<Uuid>

A unique ID that can be used to identify and reference a specific node pool.

labels: Option<Map<String, Value>>

An object of key/value mappings specifying labels to apply to all nodes in a pool. Labels will automatically be applied to all existing nodes and any subsequent nodes added to the pool. Note that when a label is removed, it is not deleted from the nodes in the pool.

max_nodes: Option<i64>

The maximum number of nodes that this node pool can be auto-scaled to. The value will be 0 if auto_scale is set to false.

min_nodes: Option<i64>

The minimum number of nodes that this node pool can be auto-scaled to. The value will be 0 if auto_scale is set to false.

name: String

A human-readable name for the node pool.

nodes: Vec<Map<String, Value>>

An object specifying the details of a specific worker node in a node pool.

size: String

The slug identifier for the type of Droplet used as workers in the node pool.

tags: Vec<String>

An array containing the tags applied to the node pool. All node pools are automatically tagged k8s, k8s-worker, and k8s:$K8S_CLUSTER_ID.

Requires tag:read scope.

taints: Vec<KubernetesAddNodePoolResponseNodePoolTaintsItem>

An array of taints to apply to all nodes in a pool. Taints will automatically be applied to all existing nodes and any subsequent nodes added to the pool. When a taint is removed, it is deleted from all nodes in the pool.