pub struct KubernetesUpdateClusterBodyControlPlaneFirewall {
pub allowed_addresses: Vec<String>,
pub enabled: Option<bool>,
}Expand description
An object specifying the control plane firewall for the Kubernetes cluster. Control plane firewall is in early availability (invite only).
JSON schema
{
"description": "An object specifying the control plane firewall for the Kubernetes cluster. Control plane firewall is in early availability (invite only).",
"type": "object",
"properties": {
"allowed_addresses": {
"description": "An array of public addresses (IPv4 or CIDR) allowed to access the control plane.",
"examples": [
[
"1.2.3.4/32",
"1.1.0.0/16"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"enabled": {
"description": "Indicates whether the control plane firewall is enabled.",
"examples": [
true
],
"type": "boolean"
}
}
}Fields
allowed_addresses: Vec<String>An array of public addresses (IPv4 or CIDR) allowed to access the control plane.
enabled: Option<bool>Indicates whether the control plane firewall is enabled.