pub struct KubernetesUpdateClusterBodyRoutingAgent {
pub enabled: Option<bool>,
}Expand description
An object specifying whether the routing-agent component should be enabled for the Kubernetes cluster.
JSON schema
{
"description": "An object specifying whether the routing-agent component should be enabled for the Kubernetes cluster.",
"type": "object",
"properties": {
"enabled": {
"description": "Indicates whether the routing-agent component is enabled.",
"examples": [
true
],
"type": "boolean"
}
}
}Fields
enabled: Option<bool>Indicates whether the routing-agent component is enabled.