LoadBalancersRemoveForwardingRulesBodyForwardingRulesItem

Struct LoadBalancersRemoveForwardingRulesBodyForwardingRulesItem 

pub struct LoadBalancersRemoveForwardingRulesBodyForwardingRulesItem {
    pub certificate_id: Option<String>,
    pub entry_port: i64,
    pub entry_protocol: LoadBalancersRemoveForwardingRulesBodyForwardingRulesItemEntryProtocol,
    pub target_port: i64,
    pub target_protocol: LoadBalancersRemoveForwardingRulesBodyForwardingRulesItemTargetProtocol,
    pub tls_passthrough: Option<bool>,
}
An object specifying a forwarding rule for a load balancer.

JSON schema
{
 "description": "An object specifying a forwarding rule for a load balancer.",
 "type": "object",
 "required": [
   "entry_port",
   "entry_protocol",
   "target_port",
   "target_protocol"
 ],
 "properties": {
   "certificate_id": {
     "description": "The ID of the TLS certificate used for SSL termination if enabled.",
     "examples": [
       "892071a0-bb95-49bc-8021-3afd67a210bf"
     ],
     "type": "string"
   },
   "entry_port": {
     "description": "An integer representing the port on which the load balancer instance will listen.",
     "examples": [
       443
     ],
     "type": "integer"
   },
   "entry_protocol": {
     "description": "The protocol used for traffic to the load balancer. The possible values are: `http`, `https`, `http2`, `http3`, `tcp`, or `udp`. If you set the  `entry_protocol` to `udp`, the `target_protocol` must be set to `udp`.  When using UDP, the load balancer requires that you set up a health  check with a port that uses TCP, HTTP, or HTTPS to work properly.\n",
     "examples": [
       "https"
     ],
     "type": "string",
     "enum": [
       "http",
       "https",
       "http2",
       "http3",
       "tcp",
       "udp"
     ]
   },
   "target_port": {
     "description": "An integer representing the port on the backend Droplets to which the load balancer will send traffic.",
     "examples": [
       80
     ],
     "type": "integer"
   },
   "target_protocol": {
     "description": "The protocol used for traffic from the load balancer to the backend Droplets. The possible values are: `http`, `https`, `http2`, `tcp`, or `udp`. If you set the `target_protocol` to `udp`, the `entry_protocol` must be set to  `udp`. When using UDP, the load balancer requires that you set up a health  check with a port that uses TCP, HTTP, or HTTPS to work properly.\n",
     "examples": [
       "http"
     ],
     "type": "string",
     "enum": [
       "http",
       "https",
       "http2",
       "tcp",
       "udp"
     ]
   },
   "tls_passthrough": {
     "description": "A boolean value indicating whether SSL encrypted traffic will be passed through to the backend Droplets.",
     "examples": [
       false
     ],
     "type": "boolean"
   }
 }
}

Fields

certificate_id: Option<String>

The ID of the TLS certificate used for SSL termination if enabled.

entry_port: i64

An integer representing the port on which the load balancer instance will listen.

entry_protocol: LoadBalancersRemoveForwardingRulesBodyForwardingRulesItemEntryProtocol

The protocol used for traffic to the load balancer. The possible values are: http, https, http2, http3, tcp, or udp. If you set the entry_protocol to udp, the target_protocol must be set to udp. When using UDP, the load balancer requires that you set up a health check with a port that uses TCP, HTTP, or HTTPS to work properly.

target_port: i64

An integer representing the port on the backend Droplets to which the load balancer will send traffic.

target_protocol: LoadBalancersRemoveForwardingRulesBodyForwardingRulesItemTargetProtocol

The protocol used for traffic from the load balancer to the backend Droplets. The possible values are: http, https, http2, tcp, or udp. If you set the target_protocol to udp, the entry_protocol must be set to udp. When using UDP, the load balancer requires that you set up a health check with a port that uses TCP, HTTP, or HTTPS to work properly.

tls_passthrough: Option<bool>

A boolean value indicating whether SSL encrypted traffic will be passed through to the backend Droplets.