pub struct LoadBalancersUpdateResponseLoadBalancerStickySessions {
pub cookie_name: Option<String>,
pub cookie_ttl_seconds: Option<i64>,
pub type_: LoadBalancersUpdateResponseLoadBalancerStickySessionsType,
}Expand description
An object specifying sticky sessions settings for the load balancer.
JSON schema
{
"description": "An object specifying sticky sessions settings for the load balancer.",
"type": "object",
"properties": {
"cookie_name": {
"description": "The name of the cookie sent to the client. This attribute is only returned when using `cookies` for the sticky sessions type.",
"examples": [
"DO-LB"
],
"type": "string"
},
"cookie_ttl_seconds": {
"description": "The number of seconds until the cookie set by the load balancer expires. This attribute is only returned when using `cookies` for the sticky sessions type.",
"examples": [
300
],
"type": "integer"
},
"type": {
"description": "An attribute indicating how and if requests from a client will be persistently served by the same backend Droplet. The possible values are `cookies` or `none`.",
"default": "none",
"examples": [
"cookies"
],
"type": "string",
"enum": [
"cookies",
"none"
]
}
}
}Fields
The name of the cookie sent to the client. This attribute is only returned when using cookies for the sticky sessions type.
The number of seconds until the cookie set by the load balancer expires. This attribute is only returned when using cookies for the sticky sessions type.
type_: LoadBalancersUpdateResponseLoadBalancerStickySessionsTypeAn attribute indicating how and if requests from a client will be persistently served by the same backend Droplet. The possible values are cookies or none.