pub struct MonitoringGetLbFrontendHttpRequestsPerSecondResponseDataResultItem {
pub metric: HashMap<String, String>,
pub values: Vec<Vec<MonitoringGetLbFrontendHttpRequestsPerSecondResponseDataResultItemValuesItemItem>>,
}Expand description
MonitoringGetLbFrontendHttpRequestsPerSecondResponseDataResultItem
JSON schema
{
"type": "object",
"required": [
"metric",
"values"
],
"properties": {
"metric": {
"description": "An object containing the metric's labels. These labels are key/value pairs that vary depending on the metric being queried. For example, load balancer metrics contain a `lb_id` label, while Droplet metrics contain a `host_id` label, and App Platform metrics contain a `app_component` label.",
"examples": [
{
"host_id": "19201920"
}
],
"type": "object",
"additionalProperties": {
"type": "string"
}
},
"values": {
"description": "An array of values for the metric.",
"examples": [
[
[
1435781430,
"1"
],
[
1435781445,
"1"
]
]
],
"type": "array",
"items": {
"type": "array",
"items": {
"oneOf": [
{
"type": "integer"
},
{
"type": "string"
}
]
}
}
}
}
}Fields
metric: HashMap<String, String>An object containing the metric’s labels. These labels are key/value pairs that vary depending on the metric being queried. For example, load balancer metrics contain a lb_id label, while Droplet metrics contain a host_id label, and App Platform metrics contain a app_component label.
values: Vec<Vec<MonitoringGetLbFrontendHttpRequestsPerSecondResponseDataResultItemValuesItemItem>>An array of values for the metric.