pub struct ProjectsAssignResourcesResponseResourcesItemLinks {
pub self_: Option<String>,
}Expand description
The links object contains the self object, which contains the resource relationship.
JSON schema
{
"description": "The links object contains the `self` object, which contains the resource relationship.",
"type": "object",
"properties": {
"self": {
"description": "A URI that can be used to retrieve the resource.",
"examples": [
"https://api.digitalocean.com/v2/droplets/13457723"
],
"type": "string",
"format": "uri"
}
}
}Fields
self_: Option<String>A URI that can be used to retrieve the resource.