pub struct ProjectsPatchDefaultBody {
pub created_at: Option<DateTime<Utc>>,
pub description: Option<ProjectsPatchDefaultBodyDescription>,
pub environment: Option<ProjectsPatchDefaultBodyEnvironment>,
pub id: Option<Uuid>,
pub is_default: Option<bool>,
pub name: Option<ProjectsPatchDefaultBodyName>,
pub owner_id: Option<i64>,
pub owner_uuid: Option<String>,
pub purpose: Option<ProjectsPatchDefaultBodyPurpose>,
pub updated_at: Option<DateTime<Utc>>,
}Expand description
ProjectsPatchDefaultBody
JSON schema
{
"allOf": [
{
"type": "object",
"properties": {
"created_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the project was created.",
"readOnly": true,
"examples": [
"2018-09-27T20:10:35Z"
],
"type": "string",
"format": "date-time"
},
"description": {
"description": "The description of the project. The maximum length is 255 characters.",
"examples": [
"My website API"
],
"type": "string",
"maxLength": 255
},
"environment": {
"description": "The environment of the project's resources.",
"examples": [
"Production"
],
"type": "string",
"enum": [
"Development",
"Staging",
"Production"
]
},
"id": {
"description": "The unique universal identifier of this project.",
"readOnly": true,
"examples": [
"4e1bfbc3-dc3e-41f2-a18f-1b4d7ba71679"
],
"type": "string",
"format": "uuid"
},
"name": {
"description": "The human-readable name for the project. The maximum length is 175 characters and the name must be unique.",
"examples": [
"my-web-api"
],
"type": "string",
"maxLength": 175
},
"owner_id": {
"description": "The integer id of the project owner.",
"readOnly": true,
"examples": [
258992
],
"type": "integer"
},
"owner_uuid": {
"description": "The unique universal identifier of the project owner.",
"readOnly": true,
"examples": [
"99525febec065ca37b2ffe4f852fd2b2581895e7"
],
"type": "string"
},
"purpose": {
"description": "The purpose of the project. The maximum length is 255 characters. It can\nhave one of the following values:\n\n- Just trying out DigitalOcean\n- Class project / Educational purposes\n- Website or blog\n- Web Application\n- Service or API\n- Mobile Application\n- Machine learning / AI / Data processing\n- IoT\n- Operational / Developer tooling\n\nIf another value for purpose is specified, for example, \"your custom purpose\",\nyour purpose will be stored as `Other: your custom purpose`.\n",
"examples": [
"Service or API"
],
"type": "string",
"maxLength": 255
},
"updated_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the project was updated.",
"readOnly": true,
"examples": [
"2018-09-27T20:10:35Z"
],
"type": "string",
"format": "date-time"
}
}
},
{
"type": "object",
"properties": {
"is_default": {
"description": "If true, all resources will be added to this project if no project is specified.",
"examples": [
false
],
"type": "boolean"
}
}
}
]
}Fields
created_at: Option<DateTime<Utc>>A time value given in ISO8601 combined date and time format that represents when the project was created.
description: Option<ProjectsPatchDefaultBodyDescription>The description of the project. The maximum length is 255 characters.
environment: Option<ProjectsPatchDefaultBodyEnvironment>The environment of the project’s resources.
id: Option<Uuid>The unique universal identifier of this project.
is_default: Option<bool>If true, all resources will be added to this project if no project is specified.
name: Option<ProjectsPatchDefaultBodyName>The human-readable name for the project. The maximum length is 175 characters and the name must be unique.
owner_id: Option<i64>The integer id of the project owner.
owner_uuid: Option<String>The unique universal identifier of the project owner.
purpose: Option<ProjectsPatchDefaultBodyPurpose>The purpose of the project. The maximum length is 255 characters. It can have one of the following values:
- Just trying out DigitalOcean
- Class project / Educational purposes
- Website or blog
- Web Application
- Service or API
- Mobile Application
- Machine learning / AI / Data processing
- IoT
- Operational / Developer tooling
If another value for purpose is specified, for example, “your custom purpose”,
your purpose will be stored as Other: your custom purpose.
updated_at: Option<DateTime<Utc>>A time value given in ISO8601 combined date and time format that represents when the project was updated.