pub struct RegistriesCreateResponse {
pub registry: Option<RegistriesCreateResponseRegistry>,
}Expand description
RegistriesCreateResponse
JSON schema
{
"properties": {
"registry": {
"type": "object",
"allOf": [
{
"type": "object",
"properties": {
"created_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the registry was created.",
"readOnly": true,
"examples": [
"2020-03-21T16:02:37Z"
],
"type": "string",
"format": "date-time"
},
"name": {
"description": "A globally unique name for the container registry. Must be lowercase and be composed only of numbers, letters and `-`, up to a limit of 63 characters.",
"examples": [
"example"
],
"type": "string",
"maxLength": 63,
"pattern": "^[a-z0-9-]{1,63}$"
},
"region": {
"description": "Slug of the region where registry data is stored",
"examples": [
"fra1"
],
"type": "string"
},
"storage_usage_bytes": {
"description": "The amount of storage used in the registry in bytes.",
"readOnly": true,
"examples": [
29393920
],
"type": "integer"
},
"storage_usage_bytes_updated_at": {
"description": "The time at which the storage usage was updated. Storage usage is calculated asynchronously, and may not immediately reflect pushes to the registry.",
"readOnly": true,
"examples": [
"2020-11-04T21:39:49.530562231Z"
],
"type": "string",
"format": "date-time"
}
}
}
]
}
}
}Fields
registry: Option<RegistriesCreateResponseRegistry>Trait Implementations
Sourceimpl Clone for RegistriesCreateResponse
impl Clone for RegistriesCreateResponse
Sourcefn clone(&self) -> RegistriesCreateResponse
fn clone(&self) -> RegistriesCreateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegistriesCreateResponse
impl Debug for RegistriesCreateResponse
Sourceimpl Default for RegistriesCreateResponse
impl Default for RegistriesCreateResponse
Sourceimpl<'de> Deserialize<'de> for RegistriesCreateResponse
impl<'de> Deserialize<'de> for RegistriesCreateResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&RegistriesCreateResponse> for RegistriesCreateResponse
impl From<&RegistriesCreateResponse> for RegistriesCreateResponse
Sourcefn from(value: &RegistriesCreateResponse) -> Self
fn from(value: &RegistriesCreateResponse) -> Self
Converts to this type from the input type.