pub struct RegistriesGetOptionsResponse {
pub options: Option<RegistriesGetOptionsResponseOptions>,
}Expand description
RegistriesGetOptionsResponse
JSON schema
{
"type": "object",
"properties": {
"options": {
"type": "object",
"properties": {
"available_regions": {
"examples": [
[
"nyc3"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"subscription_tiers": {
"type": "array",
"items": {
"allOf": [
{
"type": "object",
"properties": {
"allow_storage_overage": {
"description": "A boolean indicating whether the subscription tier supports additional storage above what is included in the base plan at an additional cost per GiB used.",
"examples": [
true
],
"type": "boolean"
},
"included_bandwidth_bytes": {
"description": "The amount of outbound data transfer included in the subscription tier in bytes.",
"examples": [
5368709120
],
"type": "integer"
},
"included_repositories": {
"description": "The number of repositories included in the subscription tier. `0` indicates that the subscription tier includes unlimited repositories.",
"examples": [
5
],
"type": "integer"
},
"included_storage_bytes": {
"description": "The amount of storage included in the subscription tier in bytes.",
"examples": [
5368709120
],
"type": "integer"
},
"monthly_price_in_cents": {
"description": "The monthly cost of the subscription tier in cents.",
"examples": [
500
],
"type": "integer"
},
"name": {
"description": "The name of the subscription tier.",
"examples": [
"Basic"
],
"type": "string"
},
"slug": {
"description": "The slug identifier of the subscription tier.",
"examples": [
"basic"
],
"type": "string"
},
"storage_overage_price_in_cents": {
"description": "The price paid in cents per GiB for additional storage beyond what is included in the subscription plan.",
"examples": [
2
],
"type": "integer"
}
}
},
{
"type": "object",
"properties": {
"eligibility_reasons": {
"description": "If your account is not eligible to use a certain subscription tier, this will include a list of reasons that prevent you from using the tier.",
"examples": [
[
"OverRepositoryLimit"
]
],
"type": "array",
"items": {
"type": "string",
"enum": [
"OverRepositoryLimit",
"OverStorageLimit"
]
}
},
"eligible": {
"description": "A boolean indicating whether your account it eligible to use a certain subscription tier.",
"examples": [
true
],
"type": "boolean"
}
}
}
]
}
}
}
}
}
}Fields
options: Option<RegistriesGetOptionsResponseOptions>Trait Implementations
Sourceimpl Clone for RegistriesGetOptionsResponse
impl Clone for RegistriesGetOptionsResponse
Sourcefn clone(&self) -> RegistriesGetOptionsResponse
fn clone(&self) -> RegistriesGetOptionsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegistriesGetOptionsResponse
impl Debug for RegistriesGetOptionsResponse
Sourceimpl<'de> Deserialize<'de> for RegistriesGetOptionsResponse
impl<'de> Deserialize<'de> for RegistriesGetOptionsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&RegistriesGetOptionsResponse> for RegistriesGetOptionsResponse
impl From<&RegistriesGetOptionsResponse> for RegistriesGetOptionsResponse
Sourcefn from(value: &RegistriesGetOptionsResponse) -> Self
fn from(value: &RegistriesGetOptionsResponse) -> Self
Converts to this type from the input type.