pub struct RegistriesUpdateSubscriptionResponseSubscriptionTier {
pub allow_storage_overage: Option<bool>,
pub included_bandwidth_bytes: Option<i64>,
pub included_repositories: Option<i64>,
pub included_storage_bytes: Option<i64>,
pub monthly_price_in_cents: Option<i64>,
pub name: Option<String>,
pub slug: Option<String>,
pub storage_overage_price_in_cents: Option<i64>,
}Expand description
RegistriesUpdateSubscriptionResponseSubscriptionTier
JSON schema
{
"type": "object",
"properties": {
"allow_storage_overage": {
"description": "A boolean indicating whether the subscription tier supports additional storage above what is included in the base plan at an additional cost per GiB used.",
"examples": [
true
],
"type": "boolean"
},
"included_bandwidth_bytes": {
"description": "The amount of outbound data transfer included in the subscription tier in bytes.",
"examples": [
5368709120
],
"type": "integer"
},
"included_repositories": {
"description": "The number of repositories included in the subscription tier. `0` indicates that the subscription tier includes unlimited repositories.",
"examples": [
5
],
"type": "integer"
},
"included_storage_bytes": {
"description": "The amount of storage included in the subscription tier in bytes.",
"examples": [
5368709120
],
"type": "integer"
},
"monthly_price_in_cents": {
"description": "The monthly cost of the subscription tier in cents.",
"examples": [
500
],
"type": "integer"
},
"name": {
"description": "The name of the subscription tier.",
"examples": [
"Basic"
],
"type": "string"
},
"slug": {
"description": "The slug identifier of the subscription tier.",
"examples": [
"basic"
],
"type": "string"
},
"storage_overage_price_in_cents": {
"description": "The price paid in cents per GiB for additional storage beyond what is included in the subscription plan.",
"examples": [
2
],
"type": "integer"
}
}
}Fields
allow_storage_overage: Option<bool>A boolean indicating whether the subscription tier supports additional storage above what is included in the base plan at an additional cost per GiB used.
included_bandwidth_bytes: Option<i64>The amount of outbound data transfer included in the subscription tier in bytes.
included_repositories: Option<i64>The number of repositories included in the subscription tier. 0 indicates that the subscription tier includes unlimited repositories.
included_storage_bytes: Option<i64>The amount of storage included in the subscription tier in bytes.
monthly_price_in_cents: Option<i64>The monthly cost of the subscription tier in cents.
name: Option<String>The name of the subscription tier.
slug: Option<String>The slug identifier of the subscription tier.
storage_overage_price_in_cents: Option<i64>The price paid in cents per GiB for additional storage beyond what is included in the subscription plan.