RegistryGetResponse

Struct RegistryGetResponse 

pub struct RegistryGetResponse {
    pub registry: Option<RegistryGetResponseRegistry>,
}
RegistryGetResponse

JSON schema
{
 "properties": {
   "registry": {
     "type": "object",
     "allOf": [
       {
         "type": "object",
         "properties": {
           "created_at": {
             "description": "A time value given in ISO8601 combined date and time format that represents when the registry was created.",
             "readOnly": true,
             "examples": [
               "2020-03-21T16:02:37Z"
             ],
             "type": "string",
             "format": "date-time"
           },
           "name": {
             "description": "A globally unique name for the container registry. Must be lowercase and be composed only of numbers, letters and `-`, up to a limit of 63 characters.",
             "examples": [
               "example"
             ],
             "type": "string",
             "maxLength": 63,
             "pattern": "^[a-z0-9-]{1,63}$"
           },
           "region": {
             "description": "Slug of the region where registry data is stored",
             "examples": [
               "fra1"
             ],
             "type": "string"
           },
           "storage_usage_bytes": {
             "description": "The amount of storage used in the registry in bytes.",
             "readOnly": true,
             "examples": [
               29393920
             ],
             "type": "integer"
           },
           "storage_usage_bytes_updated_at": {
             "description": "The time at which the storage usage was updated. Storage usage is calculated asynchronously, and may not immediately reflect pushes to the registry.",
             "readOnly": true,
             "examples": [
               "2020-11-04T21:39:49.530562231Z"
             ],
             "type": "string",
             "format": "date-time"
           }
         }
       },
       {
         "type": "object",
         "properties": {
           "subscription": {
             "allOf": [
               {
                 "readOnly": true
               },
               {
                 "type": "object",
                 "properties": {
                   "created_at": {
                     "description": "The time at which the subscription was created.",
                     "readOnly": true,
                     "examples": [
                       "2020-01-23T21:19:12Z"
                     ],
                     "type": "string",
                     "format": "date-time"
                   },
                   "tier": {
                     "type": "object",
                     "properties": {
                       "allow_storage_overage": {
                         "description": "A boolean indicating whether the subscription tier supports additional storage above what is included in the base plan at an additional cost per GiB used.",
                         "examples": [
                           true
                         ],
                         "type": "boolean"
                       },
                       "included_bandwidth_bytes": {
                         "description": "The amount of outbound data transfer included in the subscription tier in bytes.",
                         "examples": [
                           5368709120
                         ],
                         "type": "integer"
                       },
                       "included_repositories": {
                         "description": "The number of repositories included in the subscription tier. `0` indicates that the subscription tier includes unlimited repositories.",
                         "examples": [
                           5
                         ],
                         "type": "integer"
                       },
                       "included_storage_bytes": {
                         "description": "The amount of storage included in the subscription tier in bytes.",
                         "examples": [
                           5368709120
                         ],
                         "type": "integer"
                       },
                       "monthly_price_in_cents": {
                         "description": "The monthly cost of the subscription tier in cents.",
                         "examples": [
                           500
                         ],
                         "type": "integer"
                       },
                       "name": {
                         "description": "The name of the subscription tier.",
                         "examples": [
                           "Basic"
                         ],
                         "type": "string"
                       },
                       "slug": {
                         "description": "The slug identifier of the subscription tier.",
                         "examples": [
                           "basic"
                         ],
                         "type": "string"
                       },
                       "storage_overage_price_in_cents": {
                         "description": "The price paid in cents per GiB for additional storage beyond what is included in the subscription plan.",
                         "examples": [
                           2
                         ],
                         "type": "integer"
                       }
                     }
                   },
                   "updated_at": {
                     "description": "The time at which the subscription was last updated.",
                     "readOnly": true,
                     "examples": [
                       "2020-11-05T15:53:24Z"
                     ],
                     "type": "string",
                     "format": "date-time"
                   }
                 }
               }
             ]
           }
         }
       }
     ]
   }
 }
}

Fields

registry: Option<RegistryGetResponseRegistry>