pub struct RegistryRunGarbageCollectionResponseGarbageCollection {
pub blobs_deleted: Option<i64>,
pub created_at: Option<DateTime<Utc>>,
pub freed_bytes: Option<i64>,
pub registry_name: Option<String>,
pub status: Option<RegistryRunGarbageCollectionResponseGarbageCollectionStatus>,
pub updated_at: Option<DateTime<Utc>>,
pub uuid: Option<String>,
}Expand description
RegistryRunGarbageCollectionResponseGarbageCollection
JSON schema
{
"type": "object",
"properties": {
"blobs_deleted": {
"description": "The number of blobs deleted as a result of this garbage collection.",
"examples": [
42
],
"type": "integer"
},
"created_at": {
"description": "The time the garbage collection was created.",
"examples": [
"2020-10-30T21:03:24Z"
],
"type": "string",
"format": "date-time"
},
"freed_bytes": {
"description": "The number of bytes freed as a result of this garbage collection.",
"examples": [
667
],
"type": "integer"
},
"registry_name": {
"description": "The name of the container registry.",
"examples": [
"example"
],
"type": "string"
},
"status": {
"description": "The current status of this garbage collection.",
"examples": [
"requested"
],
"type": "string",
"enum": [
"requested",
"waiting for write JWTs to expire",
"scanning manifests",
"deleting unreferenced blobs",
"cancelling",
"failed",
"succeeded",
"cancelled"
]
},
"updated_at": {
"description": "The time the garbage collection was last updated.",
"examples": [
"2020-10-30T21:03:44Z"
],
"type": "string",
"format": "date-time"
},
"uuid": {
"description": "A string specifying the UUID of the garbage collection.",
"examples": [
"eff0feee-49c7-4e8f-ba5c-a320c109c8a8"
],
"type": "string"
}
}
}Fields
blobs_deleted: Option<i64>The number of blobs deleted as a result of this garbage collection.
created_at: Option<DateTime<Utc>>The time the garbage collection was created.
freed_bytes: Option<i64>The number of bytes freed as a result of this garbage collection.
registry_name: Option<String>The name of the container registry.
status: Option<RegistryRunGarbageCollectionResponseGarbageCollectionStatus>The current status of this garbage collection.
updated_at: Option<DateTime<Utc>>The time the garbage collection was last updated.
uuid: Option<String>A string specifying the UUID of the garbage collection.