ReservedIPsGetResponseReservedIpDropletSubtype1Image

Struct ReservedIPsGetResponseReservedIpDropletSubtype1Image 

pub struct ReservedIPsGetResponseReservedIpDropletSubtype1Image {
Show 14 fields pub created_at: Option<DateTime<Utc>>, pub description: Option<String>, pub distribution: Option<ReservedIPsGetResponseReservedIpDropletSubtype1ImageDistribution>, pub error_message: Option<String>, pub id: Option<i64>, pub min_disk_size: Option<u64>, pub name: Option<String>, pub public: Option<bool>, pub regions: Vec<ReservedIPsGetResponseReservedIpDropletSubtype1ImageRegionsItem>, pub size_gigabytes: Option<f32>, pub slug: Option<String>, pub status: Option<ReservedIPsGetResponseReservedIpDropletSubtype1ImageStatus>, pub tags: Option<Vec<String>>, pub type_: Option<ReservedIPsGetResponseReservedIpDropletSubtype1ImageType>,
}
ReservedIPsGetResponseReservedIpDropletSubtype1Image

JSON schema
{
 "allOf": [
   {
     "type": "object",
     "properties": {
       "created_at": {
         "description": "A time value given in ISO8601 combined date and time format that represents when the image was created.",
         "examples": [
           "2020-05-04T22:23:02Z"
         ],
         "type": "string",
         "format": "date-time"
       },
       "description": {
         "description": "An optional free-form text field to describe an image.",
         "examples": [
           " "
         ],
         "type": "string"
       },
       "distribution": {
         "description": "The name of a custom image's distribution. Currently, the valid values are  `Arch Linux`, `CentOS`, `CoreOS`, `Debian`, `Fedora`, `Fedora Atomic`,  `FreeBSD`, `Gentoo`, `openSUSE`, `RancherOS`, `Rocky Linux`, `Ubuntu`, and `Unknown`.  Any other value will be accepted but ignored, and `Unknown` will be used in its place.",
         "examples": [
           "Ubuntu"
         ],
         "type": "string",
         "enum": [
           "Arch Linux",
           "CentOS",
           "CoreOS",
           "Debian",
           "Fedora",
           "Fedora Atomic",
           "FreeBSD",
           "Gentoo",
           "openSUSE",
           "RancherOS",
           "Rocky Linux",
           "Ubuntu",
           "Unknown"
         ]
       },
       "error_message": {
         "description": "A string containing information about errors that may occur when importing\n a custom image.",
         "examples": [
           " "
         ],
         "type": "string"
       },
       "id": {
         "description": "A unique number that can be used to identify and reference a specific image.",
         "readOnly": true,
         "examples": [
           7555620
         ],
         "type": "integer"
       },
       "min_disk_size": {
         "description": "The minimum disk size in GB required for a Droplet to use this image.",
         "examples": [
           20
         ],
         "type": [
           "integer",
           "null"
         ],
         "minimum": 0.0
       },
       "name": {
         "description": "The display name that has been given to an image.  This is what is shown in the control panel and is generally a descriptive title for the image in question.",
         "examples": [
           "Nifty New Snapshot"
         ],
         "type": "string"
       },
       "public": {
         "description": "This is a boolean value that indicates whether the image in question is public or not. An image that is public is available to all accounts. A non-public image is only accessible from your account.",
         "examples": [
           true
         ],
         "type": "boolean"
       },
       "regions": {
         "description": "This attribute is an array of the regions that the image is available in. The regions are represented by their identifying slug values.",
         "examples": [
           [
             "nyc1",
             "nyc2"
           ]
         ],
         "type": "array",
         "items": {
           "description": "The slug identifier for the region where the resource will initially be  available.",
           "examples": [
             "nyc3"
           ],
           "type": "string",
           "enum": [
             "ams1",
             "ams2",
             "ams3",
             "blr1",
             "fra1",
             "lon1",
             "nyc1",
             "nyc2",
             "nyc3",
             "sfo1",
             "sfo2",
             "sfo3",
             "sgp1",
             "tor1",
             "syd1"
           ]
         }
       },
       "size_gigabytes": {
         "description": "The size of the image in gigabytes.",
         "examples": [
           2.34
         ],
         "type": [
           "number",
           "null"
         ],
         "format": "float"
       },
       "slug": {
         "description": "A uniquely identifying string that is associated with each of the DigitalOcean-provided public images. These can be used to reference a public image as an alternative to the numeric id.",
         "examples": [
           "nifty1"
         ],
         "type": [
           "string",
           "null"
         ]
       },
       "status": {
         "description": "A status string indicating the state of a custom image. This may be `NEW`,\n `available`, `pending`, `deleted`, or `retired`.",
         "examples": [
           "NEW"
         ],
         "type": "string",
         "enum": [
           "NEW",
           "available",
           "pending",
           "deleted",
           "retired"
         ]
       },
       "tags": {
         "description": "A flat array of tag names as strings to be applied to the resource. Tag names may be for either existing or new tags. <br><br>Requires `tag:create` scope.",
         "examples": [
           [
             "base-image",
             "prod"
           ]
         ],
         "type": [
           "array",
           "null"
         ],
         "items": {
           "type": "string"
         }
       },
       "type": {
         "description": "Describes the kind of image. It may be one of `base`, `snapshot`, `backup`, `custom`, or `admin`. Respectively, this specifies whether an image is a DigitalOcean base OS image, user-generated Droplet snapshot, automatically created Droplet backup, user-provided virtual machine image, or an image used for DigitalOcean managed resources (e.g. DOKS worker nodes).",
         "examples": [
           "snapshot"
         ],
         "type": "string",
         "enum": [
           "base",
           "snapshot",
           "backup",
           "custom",
           "admin"
         ]
       }
     }
   },
   {
     "description": "The Droplet's image.<br>Requires `image:read` scope."
   }
 ]
}

Fields

created_at: Option<DateTime<Utc>>

A time value given in ISO8601 combined date and time format that represents when the image was created.

description: Option<String>

An optional free-form text field to describe an image.

distribution: Option<ReservedIPsGetResponseReservedIpDropletSubtype1ImageDistribution>

The name of a custom image’s distribution. Currently, the valid values are Arch Linux, CentOS, CoreOS, Debian, Fedora, Fedora Atomic, FreeBSD, Gentoo, openSUSE, RancherOS, Rocky Linux, Ubuntu, and Unknown. Any other value will be accepted but ignored, and Unknown will be used in its place.

error_message: Option<String>

A string containing information about errors that may occur when importing a custom image.

id: Option<i64>

A unique number that can be used to identify and reference a specific image.

min_disk_size: Option<u64>

The minimum disk size in GB required for a Droplet to use this image.

name: Option<String>

The display name that has been given to an image. This is what is shown in the control panel and is generally a descriptive title for the image in question.

public: Option<bool>

This is a boolean value that indicates whether the image in question is public or not. An image that is public is available to all accounts. A non-public image is only accessible from your account.

regions: Vec<ReservedIPsGetResponseReservedIpDropletSubtype1ImageRegionsItem>

This attribute is an array of the regions that the image is available in. The regions are represented by their identifying slug values.

size_gigabytes: Option<f32>

The size of the image in gigabytes.

slug: Option<String>

A uniquely identifying string that is associated with each of the DigitalOcean-provided public images. These can be used to reference a public image as an alternative to the numeric id.

status: Option<ReservedIPsGetResponseReservedIpDropletSubtype1ImageStatus>

A status string indicating the state of a custom image. This may be NEW, available, pending, deleted, or retired.

tags: Option<Vec<String>>

A flat array of tag names as strings to be applied to the resource. Tag names may be for either existing or new tags.

Requires tag:create scope.

type_: Option<ReservedIPsGetResponseReservedIpDropletSubtype1ImageType>

Describes the kind of image. It may be one of base, snapshot, backup, custom, or admin. Respectively, this specifies whether an image is a DigitalOcean base OS image, user-generated Droplet snapshot, automatically created Droplet backup, user-provided virtual machine image, or an image used for DigitalOcean managed resources (e.g. DOKS worker nodes).