ReservedIPsGetResponseReservedIpDropletSubtype1Networks

Struct ReservedIPsGetResponseReservedIpDropletSubtype1Networks 

pub struct ReservedIPsGetResponseReservedIpDropletSubtype1Networks {
    pub v4: Vec<ReservedIPsGetResponseReservedIpDropletSubtype1NetworksV4Item>,
    pub v6: Vec<ReservedIPsGetResponseReservedIpDropletSubtype1NetworksV6Item>,
}
The details of the network that are configured for the Droplet instance. This is an object that contains keys for IPv4 and IPv6. The value of each of these is an array that contains objects describing an individual IP resource allocated to the Droplet. These will define attributes like the IP address, netmask, and gateway of the specific network depending on the type of network it is.

JSON schema
{
 "description": "The details of the network that are configured for the Droplet instance.  This is an object that contains keys for IPv4 and IPv6.  The value of each of these is an array that contains objects describing an individual IP resource allocated to the Droplet.  These will define attributes like the IP address, netmask, and gateway of the specific network depending on the type of network it is.",
 "type": "object",
 "properties": {
   "v4": {
     "type": "array",
     "items": {
       "type": "object",
       "properties": {
         "gateway": {
           "description": "The gateway of the specified IPv4 network interface.\n\nFor private interfaces, a gateway is not provided. This is denoted by\nreturning `nil` as its value.\n",
           "examples": [
             "104.236.0.1"
           ],
           "type": "string"
         },
         "ip_address": {
           "description": "The IP address of the IPv4 network interface.",
           "examples": [
             "104.236.32.182"
           ],
           "type": "string",
           "format": "ipv4"
         },
         "netmask": {
           "description": "The netmask of the IPv4 network interface.",
           "examples": [
             "255.255.192.0"
           ],
           "type": "string",
           "format": "ipv4"
         },
         "type": {
           "description": "The type of the IPv4 network interface.",
           "examples": [
             "public"
           ],
           "type": "string",
           "enum": [
             "public",
             "private"
           ]
         }
       }
     }
   },
   "v6": {
     "type": "array",
     "items": {
       "type": "object",
       "properties": {
         "gateway": {
           "description": "The gateway of the specified IPv6 network interface.",
           "examples": [
             "2604:a880:0:1010::1"
           ],
           "type": "string",
           "format": "ipv6"
         },
         "ip_address": {
           "description": "The IP address of the IPv6 network interface.",
           "examples": [
             "2604:a880:0:1010::18a:a001"
           ],
           "type": "string",
           "format": "ipv6"
         },
         "netmask": {
           "description": "The netmask of the IPv6 network interface.",
           "examples": [
             64
           ],
           "type": "integer"
         },
         "type": {
           "description": "The type of the IPv6 network interface.\n\n**Note**: IPv6 private  networking is not currently supported.\n",
           "examples": [
             "public"
           ],
           "type": "string",
           "enum": [
             "public"
           ]
         }
       }
     }
   }
 }
}

Fields

v4: Vec<ReservedIPsGetResponseReservedIpDropletSubtype1NetworksV4Item>v6: Vec<ReservedIPsGetResponseReservedIpDropletSubtype1NetworksV6Item>