SshKeysGetResponse

Struct SshKeysGetResponse 

pub struct SshKeysGetResponse {
    pub ssh_key: Option<SshKeysGetResponseSshKey>,
}
SshKeysGetResponse

JSON schema
{
 "properties": {
   "ssh_key": {
     "type": "object",
     "required": [
       "name",
       "public_key"
     ],
     "properties": {
       "fingerprint": {
         "description": "A unique identifier that differentiates this key from other keys using  a format that SSH recognizes. The fingerprint is created when the key is added to your account.",
         "readOnly": true,
         "examples": [
           "3b:16:bf:e4:8b:00:8b:b8:59:8c:a9:d3:f0:19:45:fa"
         ],
         "type": "string"
       },
       "id": {
         "description": "A unique identification number for this key. Can be used to embed a  specific SSH key into a Droplet.",
         "readOnly": true,
         "examples": [
           512189
         ],
         "type": "integer"
       },
       "name": {
         "description": "A human-readable display name for this key, used to easily identify the SSH keys when they are displayed.",
         "examples": [
           "My SSH Public Key"
         ],
         "type": "string"
       },
       "public_key": {
         "description": "The entire public key string that was uploaded. Embedded into the root user's `authorized_keys` file if you include this key during Droplet creation.",
         "examples": [
           "ssh-rsa AEXAMPLEaC1yc2EAAAADAQABAAAAQQDDHr/jh2Jy4yALcK4JyWbVkPRaWmhck3IgCoeOO3z1e2dBowLh64QAM+Qb72pxekALga2oi4GvT+TlWNhzPH4V example"
         ],
         "type": "string"
       }
     }
   }
 }
}

Fields

ssh_key: Option<SshKeysGetResponseSshKey>