pub struct TagsCreateBodyResourcesDroplets {
pub count: Option<u64>,
pub last_tagged_uri: Option<String>,
}Expand description
TagsCreateBodyResourcesDroplets
JSON schema
{
"allOf": [
{
"description": "Droplets that are tagged with the specified tag.<br>Requires `droplet:read` scope."
},
{
"description": "Tagged Resource Statistics include metadata regarding the resource type that has been tagged.",
"type": "object",
"properties": {
"count": {
"description": "The number of tagged objects for this type of resource.",
"examples": [
5
],
"type": "integer",
"minimum": 0.0
},
"last_tagged_uri": {
"description": "The URI for the last tagged object for this type of resource.",
"examples": [
"https://api.digitalocean.com/v2/images/7555620"
],
"type": "string"
}
}
}
]
}Fields
count: Option<u64>The number of tagged objects for this type of resource.
last_tagged_uri: Option<String>The URI for the last tagged object for this type of resource.