UptimeGetAlertResponseAlert

Struct UptimeGetAlertResponseAlert 

pub struct UptimeGetAlertResponseAlert {
    pub comparison: Option<UptimeGetAlertResponseAlertComparison>,
    pub id: Option<Uuid>,
    pub name: Option<String>,
    pub notifications: Map<String, Value>,
    pub period: Option<UptimeGetAlertResponseAlertPeriod>,
    pub threshold: Option<i64>,
    pub type_: Option<UptimeGetAlertResponseAlertType>,
}
UptimeGetAlertResponseAlert

JSON schema
{
 "type": "object",
 "allOf": [
   {
     "type": "object",
     "properties": {
       "id": {
         "description": "A unique ID that can be used to identify and reference the alert.",
         "readOnly": true,
         "examples": [
           "5a4981aa-9653-4bd1-bef5-d6bff52042e4"
         ],
         "type": "string",
         "format": "uuid"
       }
     }
   },
   {
     "type": "object",
     "properties": {
       "comparison": {
         "description": "The comparison operator used against the alert's threshold.",
         "examples": [
           "greater_than"
         ],
         "type": "string",
         "enum": [
           "greater_than",
           "less_than"
         ]
       },
       "name": {
         "description": "A human-friendly display name.",
         "examples": [
           "Landing page degraded performance"
         ],
         "type": "string"
       },
       "notifications": {
         "description": "Fallback schema for missing file reference",
         "type": "object",
         "additionalProperties": true
       },
       "period": {
         "description": "Period of time the threshold must be exceeded to trigger the alert.",
         "examples": [
           "2m"
         ],
         "type": "string",
         "enum": [
           "2m",
           "3m",
           "5m",
           "10m",
           "15m",
           "30m",
           "1h"
         ]
       },
       "threshold": {
         "description": "The threshold at which the alert will enter a trigger state. The specific threshold is dependent on the alert type.",
         "examples": [
           300
         ],
         "type": "integer"
       },
       "type": {
         "description": "The type of alert.",
         "examples": [
           "latency"
         ],
         "type": "string",
         "enum": [
           "latency",
           "down",
           "down_global",
           "ssl_expiry"
         ]
       }
     }
   }
 ]
}

Fields

comparison: Option<UptimeGetAlertResponseAlertComparison>

The comparison operator used against the alert’s threshold.

id: Option<Uuid>

A unique ID that can be used to identify and reference the alert.

name: Option<String>

A human-friendly display name.

notifications: Map<String, Value>

Fallback schema for missing file reference

period: Option<UptimeGetAlertResponseAlertPeriod>

Period of time the threshold must be exceeded to trigger the alert.

threshold: Option<i64>

The threshold at which the alert will enter a trigger state. The specific threshold is dependent on the alert type.

type_: Option<UptimeGetAlertResponseAlertType>

The type of alert.