VolumesCreateBody

Struct VolumesCreateBody 

pub struct VolumesCreateBody {
    pub subtype_0: Option<VolumesCreateBodySubtype0>,
    pub subtype_1: Option<VolumesCreateBodySubtype1>,
}
VolumesCreateBody

JSON schema
{
 "anyOf": [
   {
     "type": "object",
     "allOf": [
       {
         "type": "object",
         "properties": {
           "created_at": {
             "description": "A time value given in ISO8601 combined date and time format that represents when the block storage volume was created.",
             "readOnly": true,
             "examples": [
               "2020-03-02T17:00:49Z"
             ],
             "type": "string"
           },
           "description": {
             "description": "An optional free-form text field to describe a block storage volume.",
             "examples": [
               "Block store for examples"
             ],
             "type": "string"
           },
           "droplet_ids": {
             "description": "An array containing the IDs of the Droplets the volume is attached to. Note that at this time, a volume can only be attached to a single Droplet.",
             "readOnly": true,
             "examples": [
               []
             ],
             "type": [
               "array",
               "null"
             ],
             "items": {
               "type": "integer"
             }
           },
           "id": {
             "description": "The unique identifier for the block storage volume.",
             "readOnly": true,
             "examples": [
               "506f78a4-e098-11e5-ad9f-000f53306ae1"
             ],
             "type": "string"
           },
           "name": {
             "description": "A human-readable name for the block storage volume. Must be lowercase and be composed only of numbers, letters and \"-\", up to a limit of 64 characters. The name must begin with a letter.",
             "examples": [
               "example"
             ],
             "type": "string"
           },
           "size_gigabytes": {
             "description": "The size of the block storage volume in GiB (1024^3). This field does not apply  when creating a volume from a snapshot.",
             "examples": [
               10
             ],
             "type": "integer"
           },
           "tags": {
             "description": "A flat array of tag names as strings to be applied to the resource. Tag names may be for either existing or new tags. <br><br>Requires `tag:create` scope.",
             "examples": [
               [
                 "base-image",
                 "prod"
               ]
             ],
             "type": [
               "array",
               "null"
             ],
             "items": {
               "type": "string"
             }
           }
         }
       },
       {
         "properties": {
           "snapshot_id": {
             "description": "The unique identifier for the volume snapshot from which to create the volume.",
             "examples": [
               "b0798135-fb76-11eb-946a-0a58ac146f33"
             ],
             "type": "string"
           }
         }
       },
       {
         "type": "object",
         "properties": {
           "filesystem_type": {
             "description": "The name of the filesystem type to be used on the volume. When provided, the volume will automatically be formatted to the specified filesystem type. Currently, the available options are `ext4` and `xfs`. Pre-formatted volumes are automatically mounted when attached to Ubuntu, Debian, Fedora, Fedora Atomic, and CentOS Droplets created on or after April 26, 2018. Attaching pre-formatted volumes to other Droplets is not recommended.",
             "examples": [
               "ext4"
             ],
             "type": "string"
           }
         }
       },
       {
         "required": [
           "name",
           "region",
           "size_gigabytes"
         ],
         "properties": {
           "filesystem_label": {
             "allOf": [
               {
                 "description": "The label applied to the filesystem. Labels for ext4 type filesystems may contain 16 characters while labels for xfs type filesystems are limited to 12 characters. May only be used in conjunction with filesystem_type.",
                 "examples": [
                   "example"
                 ],
                 "type": "string"
               },
               {
                 "maxLength": 16
               }
             ]
           },
           "region": {
             "description": "The slug identifier for the region where the resource will initially be  available.",
             "examples": [
               "nyc3"
             ],
             "type": "string",
             "enum": [
               "ams1",
               "ams2",
               "ams3",
               "blr1",
               "fra1",
               "lon1",
               "nyc1",
               "nyc2",
               "nyc3",
               "sfo1",
               "sfo2",
               "sfo3",
               "sgp1",
               "tor1",
               "syd1"
             ]
           }
         }
       }
     ]
   },
   {
     "type": "object",
     "allOf": [
       {
         "type": "object",
         "properties": {
           "created_at": {
             "description": "A time value given in ISO8601 combined date and time format that represents when the block storage volume was created.",
             "readOnly": true,
             "examples": [
               "2020-03-02T17:00:49Z"
             ],
             "type": "string"
           },
           "description": {
             "description": "An optional free-form text field to describe a block storage volume.",
             "examples": [
               "Block store for examples"
             ],
             "type": "string"
           },
           "droplet_ids": {
             "description": "An array containing the IDs of the Droplets the volume is attached to. Note that at this time, a volume can only be attached to a single Droplet.",
             "readOnly": true,
             "examples": [
               []
             ],
             "type": [
               "array",
               "null"
             ],
             "items": {
               "type": "integer"
             }
           },
           "id": {
             "description": "The unique identifier for the block storage volume.",
             "readOnly": true,
             "examples": [
               "506f78a4-e098-11e5-ad9f-000f53306ae1"
             ],
             "type": "string"
           },
           "name": {
             "description": "A human-readable name for the block storage volume. Must be lowercase and be composed only of numbers, letters and \"-\", up to a limit of 64 characters. The name must begin with a letter.",
             "examples": [
               "example"
             ],
             "type": "string"
           },
           "size_gigabytes": {
             "description": "The size of the block storage volume in GiB (1024^3). This field does not apply  when creating a volume from a snapshot.",
             "examples": [
               10
             ],
             "type": "integer"
           },
           "tags": {
             "description": "A flat array of tag names as strings to be applied to the resource. Tag names may be for either existing or new tags. <br><br>Requires `tag:create` scope.",
             "examples": [
               [
                 "base-image",
                 "prod"
               ]
             ],
             "type": [
               "array",
               "null"
             ],
             "items": {
               "type": "string"
             }
           }
         }
       },
       {
         "properties": {
           "snapshot_id": {
             "description": "The unique identifier for the volume snapshot from which to create the volume.",
             "examples": [
               "b0798135-fb76-11eb-946a-0a58ac146f33"
             ],
             "type": "string"
           }
         }
       },
       {
         "type": "object",
         "properties": {
           "filesystem_type": {
             "description": "The name of the filesystem type to be used on the volume. When provided, the volume will automatically be formatted to the specified filesystem type. Currently, the available options are `ext4` and `xfs`. Pre-formatted volumes are automatically mounted when attached to Ubuntu, Debian, Fedora, Fedora Atomic, and CentOS Droplets created on or after April 26, 2018. Attaching pre-formatted volumes to other Droplets is not recommended.",
             "examples": [
               "ext4"
             ],
             "type": "string"
           }
         }
       },
       {
         "required": [
           "name",
           "region",
           "size_gigabytes"
         ],
         "properties": {
           "filesystem_label": {
             "allOf": [
               {
                 "description": "The label applied to the filesystem. Labels for ext4 type filesystems may contain 16 characters while labels for xfs type filesystems are limited to 12 characters. May only be used in conjunction with filesystem_type.",
                 "examples": [
                   "example"
                 ],
                 "type": "string"
               },
               {
                 "maxLength": 12
               }
             ]
           },
           "region": {
             "description": "The slug identifier for the region where the resource will initially be  available.",
             "examples": [
               "nyc3"
             ],
             "type": "string",
             "enum": [
               "ams1",
               "ams2",
               "ams3",
               "blr1",
               "fra1",
               "lon1",
               "nyc1",
               "nyc2",
               "nyc3",
               "sfo1",
               "sfo2",
               "sfo3",
               "sgp1",
               "tor1",
               "syd1"
             ]
           }
         }
       }
     ]
   }
 ]
}

Fields

subtype_0: Option<VolumesCreateBodySubtype0>subtype_1: Option<VolumesCreateBodySubtype1>