pub struct VpcPeeringsCreateBody {
pub name: VpcPeeringsCreateBodyName,
pub vpc_ids: [Uuid; 2],
}Expand description
VpcPeeringsCreateBody
JSON schema
{
"type": "object",
"allOf": [
{
"type": "object",
"properties": {
"name": {
"description": "The name of the VPC peering. Must be unique within the team and may only contain alphanumeric characters and dashes.",
"examples": [
"nyc1-blr1-peering"
],
"type": "string",
"pattern": "^[a-zA-Z0-9\\-]+$"
}
}
},
{
"type": "object",
"properties": {
"vpc_ids": {
"description": "An array of the two peered VPCs IDs.",
"examples": [
[
"c140286f-e6ce-4131-8b7b-df4590ce8d6a",
"994a2735-dc84-11e8-80bc-3cfdfea9fba1"
]
],
"type": "array",
"items": {
"type": "string",
"format": "uuid"
},
"maxItems": 2,
"minItems": 2
}
}
}
],
"required": [
"name",
"vpc_ids"
]
}Fields
name: VpcPeeringsCreateBodyNameThe name of the VPC peering. Must be unique within the team and may only contain alphanumeric characters and dashes.
vpc_ids: [Uuid; 2]An array of the two peered VPCs IDs.