VpcnatgatewaysListResponseVpcNatGatewaysItem

Struct VpcnatgatewaysListResponseVpcNatGatewaysItem 

pub struct VpcnatgatewaysListResponseVpcNatGatewaysItem {
Show 13 fields pub created_at: Option<DateTime<Utc>>, pub egresses: Option<VpcnatgatewaysListResponseVpcNatGatewaysItemEgresses>, pub icmp_timeout_seconds: Option<i64>, pub id: Option<String>, pub name: Option<String>, pub region: Option<VpcnatgatewaysListResponseVpcNatGatewaysItemRegion>, pub size: Option<i64>, pub state: Option<VpcnatgatewaysListResponseVpcNatGatewaysItemState>, pub tcp_timeout_seconds: Option<i64>, pub type_: Option<VpcnatgatewaysListResponseVpcNatGatewaysItemType>, pub udp_timeout_seconds: Option<i64>, pub updated_at: Option<DateTime<Utc>>, pub vpcs: Vec<VpcnatgatewaysListResponseVpcNatGatewaysItemVpcsItem>,
}
VpcnatgatewaysListResponseVpcNatGatewaysItem

JSON schema
{
 "type": "object",
 "properties": {
   "created_at": {
     "title": "The creation time of the VPC NAT gateway.",
     "description": "A time value given in ISO8601 combined date and time format that represents when the VPC NAT gateway was created.",
     "examples": [
       "2020-07-28T18:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "egresses": {
     "description": "An object containing egress information for the VPC NAT gateway.",
     "type": "object",
     "properties": {
       "public_gateways": {
         "description": "An array of public gateway IP addresses for the VPC NAT gateway.",
         "type": "array",
         "items": {
           "type": "object",
           "properties": {
             "ipv4": {
               "description": "IPv4 address of the public gateway.",
               "examples": [
                 "174.138.113.197"
               ],
               "type": "string"
             }
           }
         }
       }
     }
   },
   "icmp_timeout_seconds": {
     "description": "The ICMP timeout in seconds for the VPC NAT gateway.",
     "examples": [
       30
     ],
     "type": "integer"
   },
   "id": {
     "description": "The unique identifier for the VPC NAT gateway. This is automatically generated upon creation.",
     "examples": [
       "70e1b58d-cdec-4e95-b3ee-2d4d95feff51"
     ],
     "type": "string"
   },
   "name": {
     "description": "The human-readable name of the VPC NAT gateway.",
     "examples": [
       "my-vpc-nat-gateway"
     ],
     "type": "string"
   },
   "region": {
     "description": "The region in which the VPC NAT gateway is created.",
     "examples": [
       "tor1"
     ],
     "type": "string",
     "enum": [
       "nyc1",
       "nyc2",
       "nyc3",
       "ams2",
       "ams3",
       "sfo1",
       "sfo2",
       "sfo3",
       "sgp1",
       "lon1",
       "fra1",
       "tor1",
       "blr1",
       "syd1",
       "atl1"
     ]
   },
   "size": {
     "description": "The size of the VPC NAT gateway.",
     "examples": [
       1
     ],
     "type": "integer"
   },
   "state": {
     "description": "The current state of the VPC NAT gateway.",
     "examples": [
       "ACTIVE"
     ],
     "type": "string",
     "enum": [
       "NEW",
       "PROVISIONING",
       "ACTIVE",
       "DELETING",
       "ERROR",
       "INVALID"
     ]
   },
   "tcp_timeout_seconds": {
     "description": "The TCP timeout in seconds for the VPC NAT gateway.",
     "examples": [
       30
     ],
     "type": "integer"
   },
   "type": {
     "description": "The type of the VPC NAT gateway.",
     "examples": [
       "PUBLIC"
     ],
     "type": "string",
     "enum": [
       "PUBLIC"
     ]
   },
   "udp_timeout_seconds": {
     "description": "The UDP timeout in seconds for the VPC NAT gateway.",
     "examples": [
       30
     ],
     "type": "integer"
   },
   "updated_at": {
     "title": "The last update time of the VPC NAT gateway.",
     "description": "A time value given in ISO8601 combined date and time format that represents when the VPC NAT gateway was last updated.",
     "examples": [
       "2020-07-28T18:00:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "vpcs": {
     "description": "An array of VPCs associated with the VPC NAT gateway.",
     "type": "array",
     "items": {
       "type": "object",
       "properties": {
         "gateway_ip": {
           "description": "The gateway IP address of the VPC NAT gateway.",
           "examples": [
             "10.118.0.35"
           ],
           "type": "string"
         },
         "vpc_uuid": {
           "description": "The unique identifier of the VPC to which the NAT gateway is attached.",
           "examples": [
             "0d3db13e-a604-4944-9827-7ec2642d32ac"
           ],
           "type": "string"
         }
       }
     }
   }
 }
}

Fields

created_at: Option<DateTime<Utc>>

A time value given in ISO8601 combined date and time format that represents when the VPC NAT gateway was created.

egresses: Option<VpcnatgatewaysListResponseVpcNatGatewaysItemEgresses>icmp_timeout_seconds: Option<i64>

The ICMP timeout in seconds for the VPC NAT gateway.

id: Option<String>

The unique identifier for the VPC NAT gateway. This is automatically generated upon creation.

name: Option<String>

The human-readable name of the VPC NAT gateway.

region: Option<VpcnatgatewaysListResponseVpcNatGatewaysItemRegion>

The region in which the VPC NAT gateway is created.

size: Option<i64>

The size of the VPC NAT gateway.

state: Option<VpcnatgatewaysListResponseVpcNatGatewaysItemState>

The current state of the VPC NAT gateway.

tcp_timeout_seconds: Option<i64>

The TCP timeout in seconds for the VPC NAT gateway.

type_: Option<VpcnatgatewaysListResponseVpcNatGatewaysItemType>

The type of the VPC NAT gateway.

udp_timeout_seconds: Option<i64>

The UDP timeout in seconds for the VPC NAT gateway.

updated_at: Option<DateTime<Utc>>

A time value given in ISO8601 combined date and time format that represents when the VPC NAT gateway was last updated.

vpcs: Vec<VpcnatgatewaysListResponseVpcNatGatewaysItemVpcsItem>

An array of VPCs associated with the VPC NAT gateway.