pub struct VpcsGetResponse {
pub vpc: Option<VpcsGetResponseVpc>,
}Expand description
VpcsGetResponse
JSON schema
{
"type": "object",
"properties": {
"vpc": {
"type": "object",
"allOf": [
{
"type": "object",
"properties": {
"description": {
"description": "A free-form text field for describing the VPC's purpose. It may be a maximum of 255 characters.",
"examples": [
"VPC for production environment"
],
"type": "string",
"maxLength": 255
},
"name": {
"description": "The name of the VPC. Must be unique and may only contain alphanumeric characters, dashes, and periods.",
"examples": [
"env.prod-vpc"
],
"type": "string",
"pattern": "^[a-zA-Z0-9\\-\\.]+$"
}
}
},
{
"type": "object",
"properties": {
"ip_range": {
"description": "The range of IP addresses in the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be smaller than `/28` nor larger than `/16`. If no IP range is specified, a `/20` network range is generated that won't conflict with other VPC networks in your account.",
"examples": [
"10.10.10.0/24"
],
"type": "string"
},
"region": {
"description": "The slug identifier for the region where the VPC will be created.",
"examples": [
"nyc1"
],
"type": "string"
}
}
},
{
"type": "object",
"properties": {
"default": {
"description": "A boolean value indicating whether or not the VPC is the default network for the region. All applicable resources are placed into the default VPC network unless otherwise specified during their creation. The `default` field cannot be unset from `true`. If you want to set a new default VPC network, update the `default` field of another VPC network in the same region. The previous network's `default` field will be set to `false` when a new default VPC has been defined.",
"examples": [
true
],
"type": "boolean"
}
}
},
{
"type": "object",
"properties": {
"created_at": {
"description": "A time value given in ISO8601 combined date and time format.",
"readOnly": true,
"examples": [
"2020-03-13T19:20:47.442049222Z"
],
"type": "string",
"format": "date-time"
},
"id": {
"description": "A unique ID that can be used to identify and reference the VPC.",
"readOnly": true,
"examples": [
"5a4981aa-9653-4bd1-bef5-d6bff52042e4"
],
"type": "string",
"format": "uuid"
},
"urn": {
"description": "Fallback schema for missing file reference",
"type": "object",
"additionalProperties": true
}
}
}
]
}
}
}Fields
vpc: Option<VpcsGetResponseVpc>Trait Implementations
Sourceimpl Clone for VpcsGetResponse
impl Clone for VpcsGetResponse
Sourcefn clone(&self) -> VpcsGetResponse
fn clone(&self) -> VpcsGetResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VpcsGetResponse
impl Debug for VpcsGetResponse
Sourceimpl Default for VpcsGetResponse
impl Default for VpcsGetResponse
Sourceimpl<'de> Deserialize<'de> for VpcsGetResponse
impl<'de> Deserialize<'de> for VpcsGetResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&VpcsGetResponse> for VpcsGetResponse
impl From<&VpcsGetResponse> for VpcsGetResponse
Sourcefn from(value: &VpcsGetResponse) -> Self
fn from(value: &VpcsGetResponse) -> Self
Converts to this type from the input type.