VpcsListResponse

Struct VpcsListResponse 

pub struct VpcsListResponse {
    pub links: Option<VpcsListResponseLinks>,
    pub meta: VpcsListResponseMeta,
    pub vpcs: Vec<VpcsListResponseVpcsItem>,
}
VpcsListResponse

JSON schema
{
 "examples": [
   {
     "links": {},
     "meta": {
       "total": 3
     },
     "vpcs": [
       {
         "created_at": "2020-03-13T19:20:47.442049222Z",
         "default": false,
         "description": "VPC for production environment",
         "id": "5a4981aa-9653-4bd1-bef5-d6bff52042e4",
         "ip_range": "10.10.10.0/24",
         "name": "env.prod-vpc",
         "region": "nyc1",
         "urn": "do:vpc:5a4981aa-9653-4bd1-bef5-d6bff52042e4"
       },
       {
         "created_at": "2020-03-13T19:29:20Z",
         "default": true,
         "description": "",
         "id": "e0fe0f4d-596a-465e-a902-571ce57b79fa",
         "ip_range": "10.102.0.0/20",
         "name": "default-nyc1",
         "region": "nyc1",
         "urn": "do:vpc:e0fe0f4d-596a-465e-a902-571ce57b79fa"
       },
       {
         "created_at": "2019-11-19T22:19:35Z",
         "default": true,
         "description": "",
         "id": "d455e75d-4858-4eec-8c95-da2f0a5f93a7",
         "ip_range": "10.100.0.0/20",
         "name": "default-nyc3",
         "region": "nyc3",
         "urn": "do:vpc:d455e75d-4858-4eec-8c95-da2f0a5f93a7"
       }
     ]
   }
 ],
 "allOf": [
   {
     "type": "object",
     "properties": {
       "vpcs": {
         "type": "array",
         "items": {
           "type": "object",
           "allOf": [
             {
               "type": "object",
               "properties": {
                 "description": {
                   "description": "A free-form text field for describing the VPC's purpose. It may be a maximum of 255 characters.",
                   "examples": [
                     "VPC for production environment"
                   ],
                   "type": "string",
                   "maxLength": 255
                 },
                 "name": {
                   "description": "The name of the VPC. Must be unique and may only contain alphanumeric characters, dashes, and periods.",
                   "examples": [
                     "env.prod-vpc"
                   ],
                   "type": "string",
                   "pattern": "^[a-zA-Z0-9\\-\\.]+$"
                 }
               }
             },
             {
               "type": "object",
               "properties": {
                 "ip_range": {
                   "description": "The range of IP addresses in the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be smaller than `/28` nor larger than `/16`. If no IP range is specified, a `/20` network range is generated that won't conflict with other VPC networks in your account.",
                   "examples": [
                     "10.10.10.0/24"
                   ],
                   "type": "string"
                 },
                 "region": {
                   "description": "The slug identifier for the region where the VPC will be created.",
                   "examples": [
                     "nyc1"
                   ],
                   "type": "string"
                 }
               }
             },
             {
               "type": "object",
               "properties": {
                 "default": {
                   "description": "A boolean value indicating whether or not the VPC is the default network for the region. All applicable resources are placed into the default VPC network unless otherwise specified during their creation. The `default` field cannot be unset from `true`. If you want to set a new default VPC network, update the `default` field of another VPC network in the same region. The previous network's `default` field will be set to `false` when a new default VPC has been defined.",
                   "examples": [
                     true
                   ],
                   "type": "boolean"
                 }
               }
             },
             {
               "type": "object",
               "properties": {
                 "created_at": {
                   "description": "A time value given in ISO8601 combined date and time format.",
                   "readOnly": true,
                   "examples": [
                     "2020-03-13T19:20:47.442049222Z"
                   ],
                   "type": "string",
                   "format": "date-time"
                 },
                 "id": {
                   "description": "A unique ID that can be used to identify and reference the VPC.",
                   "readOnly": true,
                   "examples": [
                     "5a4981aa-9653-4bd1-bef5-d6bff52042e4"
                   ],
                   "type": "string",
                   "format": "uuid"
                 },
                 "urn": {
                   "description": "Fallback schema for missing file reference",
                   "type": "object",
                   "additionalProperties": true
                 }
               }
             }
           ]
         }
       }
     }
   },
   {
     "type": "object",
     "properties": {
       "links": {
         "type": "object",
         "properties": {
           "pages": {
             "examples": [
               {
                 "pages": {
                   "first": "https://api.digitalocean.com/v2/account/keys?page=1",
                   "prev": "https://api.digitalocean.com/v2/account/keys?page=2"
                 }
               }
             ],
             "anyOf": [
               {
                 "type": "object",
                 "properties": {
                   "first": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=1"
                     ],
                     "type": "string",
                     "format": "uri"
                   },
                   "last": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=3"
                     ],
                     "type": "string",
                     "format": "uri"
                   },
                   "next": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=2"
                     ],
                     "type": "string",
                     "format": "uri"
                   }
                 }
               },
               {
                 "type": "object",
                 "properties": {
                   "first": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=1"
                     ],
                     "type": "string",
                     "format": "uri"
                   },
                   "last": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=3"
                     ],
                     "type": "string",
                     "format": "uri"
                   },
                   "prev": {
                     "examples": [
                       "https://api.digitalocean.com/v2/images?page=1"
                     ],
                     "type": "string",
                     "format": "uri"
                   }
                 }
               },
               {}
             ]
           }
         }
       }
     }
   },
   {
     "type": "object",
     "required": [
       "meta"
     ],
     "properties": {
       "meta": {
         "allOf": [
           {
             "description": "Information about the response itself.",
             "type": "object",
             "properties": {
               "total": {
                 "description": "Number of objects returned by the request.",
                 "examples": [
                   1
                 ],
                 "type": "integer"
               }
             }
           },
           {
             "required": [
               "total"
             ]
           }
         ]
       }
     }
   }
 ]
}

Fields

links: Option<VpcsListResponseLinks>meta: VpcsListResponseMetavpcs: Vec<VpcsListResponseVpcsItem>