pub struct AppSpecServicesItemImage {
pub deploy_on_push: Option<AppSpecServicesItemImageDeployOnPush>,
pub digest: Option<String>,
pub registry: Option<String>,
pub registry_credentials: Option<String>,
pub registry_type: Option<AppSpecServicesItemImageRegistryType>,
pub repository: Option<String>,
pub tag: String,
}Expand description
AppSpecServicesItemImage
JSON schema
{
"type": "object",
"properties": {
"deploy_on_push": {
"type": "object",
"properties": {
"enabled": {
"description": "Whether to automatically deploy new images. Can only be used for images hosted in DOCR and can only be used with an image tag, not a specific digest.",
"examples": [
true
],
"type": "boolean"
}
}
},
"digest": {
"description": "The image digest. Cannot be specified if tag is provided.",
"examples": [
"sha256:795e91610e9cccb7bb80893fbabf9c808df7d52ae1f39cd1158618b4a33041ac"
],
"type": "string"
},
"registry": {
"description": "The registry name. Must be left empty for the `DOCR` registry type.",
"examples": [
"registry.hub.docker.com"
],
"type": "string"
},
"registry_credentials": {
"description": "The credentials to be able to pull the image. The value will be encrypted on first submission. On following submissions, the encrypted value should be used.\n- \"$username:$access_token\" for registries of type `DOCKER_HUB`.\n- \"$username:$access_token\" for registries of type `GHCR`.",
"examples": [
"my-dockerhub-username:dckr_pat_the_access_token"
],
"type": "string"
},
"registry_type": {
"description": "- DOCKER_HUB: The DockerHub container registry type.\n- DOCR: The DigitalOcean container registry type.\n- GHCR: The Github container registry type.",
"examples": [
"DOCR"
],
"type": "string",
"enum": [
"DOCKER_HUB",
"DOCR",
"GHCR"
]
},
"repository": {
"description": "The repository name.",
"examples": [
"origin/master"
],
"type": "string"
},
"tag": {
"description": "The repository tag. Defaults to `latest` if not provided and no digest is provided. Cannot be specified if digest is provided.",
"default": "latest",
"examples": [
"latest"
],
"type": "string"
}
}
}Fields
deploy_on_push: Option<AppSpecServicesItemImageDeployOnPush>digest: Option<String>The image digest. Cannot be specified if tag is provided.
registry: Option<String>The registry name. Must be left empty for the DOCR registry type.
registry_credentials: Option<String>The credentials to be able to pull the image. The value will be encrypted on first submission. On following submissions, the encrypted value should be used.
- “$username:$access_token” for registries of type
DOCKER_HUB. - “$username:$access_token” for registries of type
GHCR.
registry_type: Option<AppSpecServicesItemImageRegistryType>- DOCKER_HUB: The DockerHub container registry type.
- DOCR: The DigitalOcean container registry type.
- GHCR: The Github container registry type.
repository: Option<String>The repository name.
tag: StringThe repository tag. Defaults to latest if not provided and no digest is provided. Cannot be specified if digest is provided.