pub struct AppsCreateRollbackBody {
pub deployment_id: Option<String>,
pub skip_pin: Option<bool>,
}Expand description
AppsCreateRollbackBody
JSON schema
{
"type": "object",
"properties": {
"deployment_id": {
"description": "The ID of the deployment to rollback to.",
"examples": [
"3aa4d20e-5527-4c00-b496-601fbd22520a"
],
"type": "string"
},
"skip_pin": {
"description": "Whether to skip pinning the rollback deployment. If false, the rollback deployment will be pinned and any new deployments including Auto Deploy on Push hooks will be disabled until the rollback is either manually committed or reverted via the CommitAppRollback or RevertAppRollback endpoints respectively. If true, the rollback will be immediately committed and the app will remain unpinned.",
"examples": [
false
],
"type": "boolean"
}
}
}Fields
deployment_id: Option<String>The ID of the deployment to rollback to.
skip_pin: Option<bool>Whether to skip pinning the rollback deployment. If false, the rollback deployment will be pinned and any new deployments including Auto Deploy on Push hooks will be disabled until the rollback is either manually committed or reverted via the CommitAppRollback or RevertAppRollback endpoints respectively. If true, the rollback will be immediately committed and the app will remain unpinned.