pub struct CdnUpdateEndpointsBody {
pub certificate_id: Option<Uuid>,
pub custom_domain: Option<String>,
pub ttl: CdnUpdateEndpointsBodyTtl,
}Expand description
CdnUpdateEndpointsBody
JSON schema
{
"type": "object",
"properties": {
"certificate_id": {
"description": "The ID of a DigitalOcean managed TLS certificate used for SSL when a custom subdomain is provided.",
"examples": [
"892071a0-bb95-49bc-8021-3afd67a210bf"
],
"type": "string",
"format": "uuid"
},
"custom_domain": {
"description": "The fully qualified domain name (FQDN) of the custom subdomain used with the CDN endpoint.",
"examples": [
"static.example.com"
],
"type": "string",
"format": "hostname"
},
"ttl": {
"description": "The amount of time the content is cached by the CDN's edge servers in seconds. TTL must be one of 60, 600, 3600, 86400, or 604800. Defaults to 3600 (one hour) when excluded.",
"default": 3600,
"examples": [
3600
],
"type": "integer",
"enum": [
60,
600,
3600,
86400,
604800
]
}
}
}Fields
certificate_id: Option<Uuid>The ID of a DigitalOcean managed TLS certificate used for SSL when a custom subdomain is provided.
custom_domain: Option<String>The fully qualified domain name (FQDN) of the custom subdomain used with the CDN endpoint.
ttl: CdnUpdateEndpointsBodyTtlThe amount of time the content is cached by the CDN’s edge servers in seconds. TTL must be one of 60, 600, 3600, 86400, or 604800. Defaults to 3600 (one hour) when excluded.