pub struct DropletsListBackupsResponseBackupsItem {
pub created_at: DateTime<Utc>,
pub id: i64,
pub min_disk_size: i64,
pub name: String,
pub regions: Vec<String>,
pub size_gigabytes: f32,
pub type_: DropletsListBackupsResponseBackupsItemType,
}Expand description
DropletsListBackupsResponseBackupsItem
JSON schema
{
"allOf": [
{
"type": "object",
"required": [
"id"
],
"properties": {
"id": {
"description": "The unique identifier for the snapshot or backup.",
"examples": [
6372321
],
"type": "integer"
}
}
},
{
"type": "object",
"required": [
"created_at",
"min_disk_size",
"name",
"regions",
"size_gigabytes"
],
"properties": {
"created_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the snapshot was created.",
"examples": [
"2020-07-28T16:47:44Z"
],
"type": "string",
"format": "date-time"
},
"min_disk_size": {
"description": "The minimum size in GB required for a volume or Droplet to use this snapshot.",
"examples": [
25
],
"type": "integer"
},
"name": {
"description": "A human-readable name for the snapshot.",
"examples": [
"web-01-1595954862243"
],
"type": "string"
},
"regions": {
"description": "An array of the regions that the snapshot is available in. The regions are represented by their identifying slug values.",
"examples": [
[
"nyc3",
"sfo3"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"size_gigabytes": {
"description": "The billable size of the snapshot in gigabytes.",
"examples": [
2.34
],
"type": "number",
"format": "float"
}
}
},
{
"type": "object",
"required": [
"type"
],
"properties": {
"type": {
"description": "Describes the kind of image. It may be one of `snapshot` or `backup`. This specifies whether an image is a user-generated Droplet snapshot or automatically created Droplet backup.",
"examples": [
"snapshot"
],
"type": "string",
"enum": [
"snapshot",
"backup"
]
}
}
}
]
}Fields
created_at: DateTime<Utc>A time value given in ISO8601 combined date and time format that represents when the snapshot was created.
id: i64The unique identifier for the snapshot or backup.
min_disk_size: i64The minimum size in GB required for a volume or Droplet to use this snapshot.
name: StringA human-readable name for the snapshot.
regions: Vec<String>An array of the regions that the snapshot is available in. The regions are represented by their identifying slug values.
size_gigabytes: f32type_: DropletsListBackupsResponseBackupsItemTypeDescribes the kind of image. It may be one of snapshot or backup. This specifies whether an image is a user-generated Droplet snapshot or automatically created Droplet backup.