pub struct GenaiListModelEvaluationMetricsResponseMetricsItem {Show 15 fields
pub associated_presets: Vec<Map<String, Value>>,
pub category: Map<String, Value>,
pub custom_eval_config: Map<String, Value>,
pub description: Option<String>,
pub evaluation_scope: Map<String, Value>,
pub inverted: Option<bool>,
pub is_metric_goal: Option<bool>,
pub metric_name: Option<String>,
pub metric_rank: Option<i64>,
pub metric_type: Map<String, Value>,
pub metric_uuid: Option<String>,
pub metric_value_type: Map<String, Value>,
pub range_max: Option<f32>,
pub range_min: Option<f32>,
pub source: Map<String, Value>,
}Expand description
GenaiListModelEvaluationMetricsResponseMetricsItem
JSON schema
{
"type": "object",
"properties": {
"associated_presets": {
"description": "Saved model evaluation presets that reference this metric. Populated for\ncustom metrics when listing metrics so the dashboard can warn that deleting\nthe metric will also delete these presets. Empty for built-in metrics.",
"type": "array",
"items": {
"description": "Auto-generated fallback definition for: apiAssociatedModelEvaluationPreset",
"type": "object",
"additionalProperties": true
}
},
"category": {
"description": "Auto-generated fallback definition for: apiEvaluationMetricCategory",
"type": "object",
"additionalProperties": true
},
"custom_eval_config": {
"description": "Auto-generated fallback definition for: apiCustomEvaluationMetricConfig",
"type": "object",
"additionalProperties": true
},
"description": {
"examples": [
"example string"
],
"type": "string"
},
"evaluation_scope": {
"description": "Auto-generated fallback definition for: apiEvaluationScope",
"type": "object",
"additionalProperties": true
},
"inverted": {
"description": "If true, the metric is inverted, meaning that a lower value is better.",
"examples": [
true
],
"type": "boolean"
},
"is_metric_goal": {
"examples": [
true
],
"type": "boolean"
},
"metric_name": {
"examples": [
"example name"
],
"type": "string"
},
"metric_rank": {
"examples": [
123
],
"type": "integer",
"format": "int64"
},
"metric_type": {
"description": "Auto-generated fallback definition for: apiEvaluationMetricType",
"type": "object",
"additionalProperties": true
},
"metric_uuid": {
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": "string"
},
"metric_value_type": {
"description": "Auto-generated fallback definition for: apiEvaluationMetricValueType",
"type": "object",
"additionalProperties": true
},
"range_max": {
"description": "The maximum value for the metric.",
"examples": [
123
],
"type": "number",
"format": "float"
},
"range_min": {
"description": "The minimum value for the metric.",
"examples": [
123
],
"type": "number",
"format": "float"
},
"source": {
"description": "Auto-generated fallback definition for: apiEvaluationMetricSource",
"type": "object",
"additionalProperties": true
}
}
}Fields
associated_presets: Vec<Map<String, Value>>Saved model evaluation presets that reference this metric. Populated for custom metrics when listing metrics so the dashboard can warn that deleting the metric will also delete these presets. Empty for built-in metrics.
category: Map<String, Value>Auto-generated fallback definition for: apiEvaluationMetricCategory
custom_eval_config: Map<String, Value>Auto-generated fallback definition for: apiCustomEvaluationMetricConfig
description: Option<String>evaluation_scope: Map<String, Value>Auto-generated fallback definition for: apiEvaluationScope
inverted: Option<bool>If true, the metric is inverted, meaning that a lower value is better.
is_metric_goal: Option<bool>metric_name: Option<String>metric_rank: Option<i64>metric_type: Map<String, Value>Auto-generated fallback definition for: apiEvaluationMetricType
metric_uuid: Option<String>metric_value_type: Map<String, Value>Auto-generated fallback definition for: apiEvaluationMetricValueType
range_max: Option<f32>range_min: Option<f32>source: Map<String, Value>Auto-generated fallback definition for: apiEvaluationMetricSource