pub struct ImageActionsPostResponse {
pub completed_at: Option<DateTime<Utc>>,
pub id: Option<i64>,
pub region: Option<ImageActionsPostResponseRegion>,
pub region_slug: Option<String>,
pub resource_id: Option<i64>,
pub resource_type: Option<String>,
pub started_at: Option<DateTime<Utc>>,
pub status: ImageActionsPostResponseStatus,
pub type_: Option<String>,
}Expand description
ImageActionsPostResponse
JSON schema
{
"type": "object",
"properties": {
"completed_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the action was completed.",
"examples": [
"2020-11-14T16:30:06Z"
],
"type": [
"string",
"null"
],
"format": "date-time"
},
"id": {
"description": "A unique numeric ID that can be used to identify and reference an action.",
"examples": [
36804636
],
"type": "integer"
},
"region": {
"type": "object",
"required": [
"available",
"features",
"name",
"sizes",
"slug"
],
"properties": {
"available": {
"description": "This is a boolean value that represents whether new Droplets can be created in this region.",
"examples": [
true
],
"type": "boolean"
},
"features": {
"description": "This attribute is set to an array which contains features available in this region",
"examples": [
[
"private_networking",
"backups",
"ipv6",
"metadata",
"install_agent",
"storage",
"image_transfer"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"name": {
"description": "The display name of the region. This will be a full name that is used in the control panel and other interfaces.",
"examples": [
"New York 3"
],
"type": "string"
},
"sizes": {
"description": "This attribute is set to an array which contains the identifying slugs for the sizes available in this region. sizes:read is required to view.",
"examples": [
[
"s-1vcpu-1gb",
"s-1vcpu-2gb",
"s-1vcpu-3gb",
"s-2vcpu-2gb",
"s-3vcpu-1gb",
"s-2vcpu-4gb",
"s-4vcpu-8gb",
"s-6vcpu-16gb",
"s-8vcpu-32gb",
"s-12vcpu-48gb",
"s-16vcpu-64gb",
"s-20vcpu-96gb",
"s-24vcpu-128gb",
"s-32vcpu-192g"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"slug": {
"description": "A human-readable string that is used as a unique identifier for each region.",
"examples": [
"nyc3"
],
"type": "string"
}
}
},
"region_slug": {
"description": "A human-readable string that is used as a unique identifier for each region.",
"examples": [
"nyc3"
],
"type": [
"string",
"null"
]
},
"resource_id": {
"description": "A unique identifier for the resource that the action is associated with.",
"examples": [
3164444
],
"type": [
"integer",
"null"
]
},
"resource_type": {
"description": "The type of resource that the action is associated with.",
"examples": [
"droplet"
],
"type": "string"
},
"started_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the action was initiated.",
"examples": [
"2020-11-14T16:29:21Z"
],
"type": "string",
"format": "date-time"
},
"status": {
"description": "The current status of the action. This can be \"in-progress\", \"completed\", or \"errored\".",
"default": "in-progress",
"examples": [
"completed"
],
"type": "string",
"enum": [
"in-progress",
"completed",
"errored"
]
},
"type": {
"description": "This is the type of action that the object represents. For example, this could be \"transfer\" to represent the state of an image transfer action.",
"examples": [
"create"
],
"type": "string"
}
}
}Fields
completed_at: Option<DateTime<Utc>>A time value given in ISO8601 combined date and time format that represents when the action was completed.
id: Option<i64>A unique numeric ID that can be used to identify and reference an action.
region: Option<ImageActionsPostResponseRegion>region_slug: Option<String>A human-readable string that is used as a unique identifier for each region.
resource_id: Option<i64>A unique identifier for the resource that the action is associated with.
resource_type: Option<String>The type of resource that the action is associated with.
started_at: Option<DateTime<Utc>>A time value given in ISO8601 combined date and time format that represents when the action was initiated.
status: ImageActionsPostResponseStatusThe current status of the action. This can be “in-progress”, “completed”, or “errored”.
type_: Option<String>This is the type of action that the object represents. For example, this could be “transfer” to represent the state of an image transfer action.