pub struct InvoicesGetByUuidResponse {
pub invoice_items: Vec<InvoicesGetByUuidResponseInvoiceItemsItem>,
pub links: Option<InvoicesGetByUuidResponseLinks>,
pub meta: InvoicesGetByUuidResponseMeta,
}Expand description
InvoicesGetByUuidResponse
JSON schema
{
"examples": [
{
"invoice_items": [
{
"amount": "12.34",
"description": "a56e086a317d8410c8b4cfd1f4dc9f82",
"duration": "744",
"duration_unit": "Hours",
"end_time": "2020-02-01T00:00:00Z",
"group_description": "my-doks-cluster",
"product": "Kubernetes Clusters",
"resource_uuid": "711157cb-37c8-4817-b371-44fa3504a39c",
"start_time": "2020-01-01T00:00:00Z"
},
{
"amount": "34.45",
"description": "Spaces ($5/mo 250GB storage & 1TB bandwidth)",
"duration": "744",
"duration_unit": "Hours",
"end_time": "2020-02-01T00:00:00Z",
"product": "Spaces Subscription",
"start_time": "2020-01-01T00:00:00Z"
}
],
"links": {
"pages": {
"last": "https://api.digitalocean.com/v2/customers/my/invoices/22737513-0ea7-4206-8ceb-98a575af7681?page=3&per_page=2",
"next": "https://api.digitalocean.com/v2/customers/my/invoices/22737513-0ea7-4206-8ceb-98a575af7681?page=2&per_page=2"
}
},
"meta": {
"total": 6
}
}
],
"allOf": [
{
"type": "object",
"properties": {
"invoice_items": {
"type": "array",
"items": {
"type": "object",
"properties": {
"amount": {
"description": "Billed amount of this invoice item. Billed in USD.",
"examples": [
"12.34"
],
"type": "string"
},
"description": {
"description": "Description of the invoice item.",
"examples": [
"a56e086a317d8410c8b4cfd1f4dc9f82"
],
"type": "string"
},
"duration": {
"description": "Duration of time this invoice item was used and subsequently billed.",
"examples": [
"744"
],
"type": "string"
},
"duration_unit": {
"description": "Unit of time for duration.",
"examples": [
"Hours"
],
"type": "string"
},
"end_time": {
"description": "Time the invoice item stopped being billed for usage.",
"examples": [
"2020-02-01T00:00:00Z"
],
"type": "string"
},
"group_description": {
"description": "Description of the invoice item when it is a grouped set of usage, such as DOKS or databases.",
"examples": [
"my-doks-cluster"
],
"type": "string"
},
"product": {
"description": "Name of the product being billed in the invoice item.",
"examples": [
"Kubernetes Clusters"
],
"type": "string"
},
"project_name": {
"description": "Name of the DigitalOcean Project this resource belongs to.",
"examples": [
"web"
],
"type": "string"
},
"resource_id": {
"description": "ID of the resource billing in the invoice item if available.",
"examples": [
"2353624"
],
"type": "string"
},
"resource_uuid": {
"description": "UUID of the resource billing in the invoice item if available.",
"examples": [
"711157cb-37c8-4817-b371-44fa3504a39c"
],
"type": "string"
},
"start_time": {
"description": "Time the invoice item began to be billed for usage.",
"examples": [
"2020-01-01T00:00:00Z"
],
"type": "string"
}
}
}
}
}
},
{
"type": "object",
"properties": {
"links": {
"type": "object",
"properties": {
"pages": {
"examples": [
{
"pages": {
"first": "https://api.digitalocean.com/v2/account/keys?page=1",
"prev": "https://api.digitalocean.com/v2/account/keys?page=2"
}
}
],
"anyOf": [
{
"type": "object",
"properties": {
"first": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
},
"last": {
"examples": [
"https://api.digitalocean.com/v2/images?page=3"
],
"type": "string",
"format": "uri"
},
"next": {
"examples": [
"https://api.digitalocean.com/v2/images?page=2"
],
"type": "string",
"format": "uri"
}
}
},
{
"type": "object",
"properties": {
"first": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
},
"last": {
"examples": [
"https://api.digitalocean.com/v2/images?page=3"
],
"type": "string",
"format": "uri"
},
"prev": {
"examples": [
"https://api.digitalocean.com/v2/images?page=1"
],
"type": "string",
"format": "uri"
}
}
},
{}
]
}
}
}
}
},
{
"type": "object",
"required": [
"meta"
],
"properties": {
"meta": {
"allOf": [
{
"description": "Information about the response itself.",
"type": "object",
"properties": {
"total": {
"description": "Number of objects returned by the request.",
"examples": [
1
],
"type": "integer"
}
}
},
{
"required": [
"total"
]
}
]
}
}
}
]
}Fields
invoice_items: Vec<InvoicesGetByUuidResponseInvoiceItemsItem>links: Option<InvoicesGetByUuidResponseLinks>meta: InvoicesGetByUuidResponseMetaTrait Implementations
Sourceimpl Clone for InvoicesGetByUuidResponse
impl Clone for InvoicesGetByUuidResponse
Sourcefn clone(&self) -> InvoicesGetByUuidResponse
fn clone(&self) -> InvoicesGetByUuidResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvoicesGetByUuidResponse
impl Debug for InvoicesGetByUuidResponse
Sourceimpl<'de> Deserialize<'de> for InvoicesGetByUuidResponse
impl<'de> Deserialize<'de> for InvoicesGetByUuidResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&InvoicesGetByUuidResponse> for InvoicesGetByUuidResponse
impl From<&InvoicesGetByUuidResponse> for InvoicesGetByUuidResponse
Sourcefn from(value: &InvoicesGetByUuidResponse) -> Self
fn from(value: &InvoicesGetByUuidResponse) -> Self
Converts to this type from the input type.