RegistriesGetOptionsResponse

Struct RegistriesGetOptionsResponse 

pub struct RegistriesGetOptionsResponse {
    pub options: Option<RegistriesGetOptionsResponseOptions>,
}
RegistriesGetOptionsResponse

JSON schema
{
 "type": "object",
 "properties": {
   "options": {
     "type": "object",
     "properties": {
       "available_regions": {
         "examples": [
           [
             "nyc3"
           ]
         ],
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "subscription_tiers": {
         "type": "array",
         "items": {
           "allOf": [
             {
               "type": "object",
               "properties": {
                 "allow_storage_overage": {
                   "description": "A boolean indicating whether the subscription tier supports additional storage above what is included in the base plan at an additional cost per GiB used.",
                   "examples": [
                     true
                   ],
                   "type": "boolean"
                 },
                 "included_bandwidth_bytes": {
                   "description": "The amount of outbound data transfer included in the subscription tier in bytes.",
                   "examples": [
                     5368709120
                   ],
                   "type": "integer"
                 },
                 "included_repositories": {
                   "description": "The number of repositories included in the subscription tier. `0` indicates that the subscription tier includes unlimited repositories.",
                   "examples": [
                     5
                   ],
                   "type": "integer"
                 },
                 "included_storage_bytes": {
                   "description": "The amount of storage included in the subscription tier in bytes.",
                   "examples": [
                     5368709120
                   ],
                   "type": "integer"
                 },
                 "monthly_price_in_cents": {
                   "description": "The monthly cost of the subscription tier in cents.",
                   "examples": [
                     500
                   ],
                   "type": "integer"
                 },
                 "name": {
                   "description": "The name of the subscription tier.",
                   "examples": [
                     "Basic"
                   ],
                   "type": "string"
                 },
                 "slug": {
                   "description": "The slug identifier of the subscription tier.",
                   "examples": [
                     "basic"
                   ],
                   "type": "string"
                 },
                 "storage_overage_price_in_cents": {
                   "description": "The price paid in cents per GiB for additional storage beyond what is included in the subscription plan.",
                   "examples": [
                     2
                   ],
                   "type": "integer"
                 }
               }
             },
             {
               "type": "object",
               "properties": {
                 "eligibility_reasons": {
                   "description": "If your account is not eligible to use a certain subscription tier, this will include a list of reasons that prevent you from using the tier.",
                   "examples": [
                     [
                       "OverRepositoryLimit"
                     ]
                   ],
                   "type": "array",
                   "items": {
                     "type": "string",
                     "enum": [
                       "OverRepositoryLimit",
                       "OverStorageLimit"
                     ]
                   }
                 },
                 "eligible": {
                   "description": "A boolean indicating whether your account it eligible to use a certain subscription tier.",
                   "examples": [
                     true
                   ],
                   "type": "boolean"
                 }
               }
             }
           ]
         }
       }
     }
   }
 }
}

Fields

options: Option<RegistriesGetOptionsResponseOptions>