pub struct SshKeysGetResponse {
pub ssh_key: Option<SshKeysGetResponseSshKey>,
}Expand description
SshKeysGetResponse
JSON schema
{
"properties": {
"ssh_key": {
"type": "object",
"required": [
"name",
"public_key"
],
"properties": {
"fingerprint": {
"description": "A unique identifier that differentiates this key from other keys using a format that SSH recognizes. The fingerprint is created when the key is added to your account.",
"readOnly": true,
"examples": [
"3b:16:bf:e4:8b:00:8b:b8:59:8c:a9:d3:f0:19:45:fa"
],
"type": "string"
},
"id": {
"description": "A unique identification number for this key. Can be used to embed a specific SSH key into a Droplet.",
"readOnly": true,
"examples": [
512189
],
"type": "integer"
},
"name": {
"description": "A human-readable display name for this key, used to easily identify the SSH keys when they are displayed.",
"examples": [
"My SSH Public Key"
],
"type": "string"
},
"public_key": {
"description": "The entire public key string that was uploaded. Embedded into the root user's `authorized_keys` file if you include this key during Droplet creation.",
"examples": [
"ssh-rsa AEXAMPLEaC1yc2EAAAADAQABAAAAQQDDHr/jh2Jy4yALcK4JyWbVkPRaWmhck3IgCoeOO3z1e2dBowLh64QAM+Qb72pxekALga2oi4GvT+TlWNhzPH4V example"
],
"type": "string"
}
}
}
}
}Fields
ssh_key: Option<SshKeysGetResponseSshKey>Trait Implementations
Sourceimpl Clone for SshKeysGetResponse
impl Clone for SshKeysGetResponse
Sourcefn clone(&self) -> SshKeysGetResponse
fn clone(&self) -> SshKeysGetResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SshKeysGetResponse
impl Debug for SshKeysGetResponse
Sourceimpl Default for SshKeysGetResponse
impl Default for SshKeysGetResponse
Sourceimpl<'de> Deserialize<'de> for SshKeysGetResponse
impl<'de> Deserialize<'de> for SshKeysGetResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&SshKeysGetResponse> for SshKeysGetResponse
impl From<&SshKeysGetResponse> for SshKeysGetResponse
Sourcefn from(value: &SshKeysGetResponse) -> Self
fn from(value: &SshKeysGetResponse) -> Self
Converts to this type from the input type.