pub struct VolumesCreateResponseVolume {
pub created_at: Option<String>,
pub description: Option<String>,
pub droplet_ids: Option<Vec<i64>>,
pub filesystem_label: Option<String>,
pub filesystem_type: Option<String>,
pub id: Option<String>,
pub name: Option<String>,
pub region: Option<VolumesCreateResponseVolumeRegion>,
pub size_gigabytes: Option<i64>,
pub tags: Option<Vec<String>>,
}Expand description
VolumesCreateResponseVolume
JSON schema
{
"type": "object",
"allOf": [
{
"type": "object",
"properties": {
"created_at": {
"description": "A time value given in ISO8601 combined date and time format that represents when the block storage volume was created.",
"readOnly": true,
"examples": [
"2020-03-02T17:00:49Z"
],
"type": "string"
},
"description": {
"description": "An optional free-form text field to describe a block storage volume.",
"examples": [
"Block store for examples"
],
"type": "string"
},
"droplet_ids": {
"description": "An array containing the IDs of the Droplets the volume is attached to. Note that at this time, a volume can only be attached to a single Droplet.",
"readOnly": true,
"examples": [
[]
],
"type": [
"array",
"null"
],
"items": {
"type": "integer"
}
},
"id": {
"description": "The unique identifier for the block storage volume.",
"readOnly": true,
"examples": [
"506f78a4-e098-11e5-ad9f-000f53306ae1"
],
"type": "string"
},
"name": {
"description": "A human-readable name for the block storage volume. Must be lowercase and be composed only of numbers, letters and \"-\", up to a limit of 64 characters. The name must begin with a letter.",
"examples": [
"example"
],
"type": "string"
},
"size_gigabytes": {
"description": "The size of the block storage volume in GiB (1024^3). This field does not apply when creating a volume from a snapshot.",
"examples": [
10
],
"type": "integer"
},
"tags": {
"description": "A flat array of tag names as strings applied to the resource. <br><br>Requires `tag:read` scope.",
"examples": [
[
"base-image",
"prod"
]
],
"type": [
"array",
"null"
],
"items": {
"type": "string"
}
}
}
},
{
"properties": {
"filesystem_label": {
"description": "The label currently applied to the filesystem.",
"examples": [
"example"
],
"type": "string"
},
"filesystem_type": {
"description": "The type of filesystem currently in-use on the volume.",
"examples": [
"ext4"
],
"type": "string"
},
"region": {
"readOnly": true,
"examples": [
{
"available": true,
"features": [
"private_networking",
"backups",
"ipv6",
"metadata"
],
"name": "New York 1",
"sizes": [
"s-1vcpu-1gb",
"s-1vcpu-2gb",
"s-1vcpu-3gb",
"s-2vcpu-2gb",
"s-3vcpu-1gb",
"s-2vcpu-4gb",
"s-4vcpu-8gb",
"s-6vcpu-16gb",
"s-8vcpu-32gb",
"s-12vcpu-48gb",
"s-16vcpu-64gb",
"s-20vcpu-96gb",
"s-24vcpu-128gb",
"s-32vcpu-192gb"
],
"slug": "nyc1"
}
],
"allOf": [
{
"description": "The region that the block storage volume is located in. When setting a region, the value should be the slug identifier for the region. When you query a block storage volume, the entire region object will be returned."
},
{
"type": "object",
"required": [
"available",
"features",
"name",
"sizes",
"slug"
],
"properties": {
"available": {
"description": "This is a boolean value that represents whether new Droplets can be created in this region.",
"examples": [
true
],
"type": "boolean"
},
"features": {
"description": "This attribute is set to an array which contains features available in this region",
"examples": [
[
"private_networking",
"backups",
"ipv6",
"metadata",
"install_agent",
"storage",
"image_transfer"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"name": {
"description": "The display name of the region. This will be a full name that is used in the control panel and other interfaces.",
"examples": [
"New York 3"
],
"type": "string"
},
"sizes": {
"description": "This attribute is set to an array which contains the identifying slugs for the sizes available in this region. sizes:read is required to view.",
"examples": [
[
"s-1vcpu-1gb",
"s-1vcpu-2gb",
"s-1vcpu-3gb",
"s-2vcpu-2gb",
"s-3vcpu-1gb",
"s-2vcpu-4gb",
"s-4vcpu-8gb",
"s-6vcpu-16gb",
"s-8vcpu-32gb",
"s-12vcpu-48gb",
"s-16vcpu-64gb",
"s-20vcpu-96gb",
"s-24vcpu-128gb",
"s-32vcpu-192g"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"slug": {
"description": "A human-readable string that is used as a unique identifier for each region.",
"examples": [
"nyc3"
],
"type": "string"
}
}
}
]
}
}
}
]
}Fields
created_at: Option<String>A time value given in ISO8601 combined date and time format that represents when the block storage volume was created.
description: Option<String>An optional free-form text field to describe a block storage volume.
droplet_ids: Option<Vec<i64>>An array containing the IDs of the Droplets the volume is attached to. Note that at this time, a volume can only be attached to a single Droplet.
filesystem_label: Option<String>The label currently applied to the filesystem.
filesystem_type: Option<String>The type of filesystem currently in-use on the volume.
id: Option<String>The unique identifier for the block storage volume.
name: Option<String>A human-readable name for the block storage volume. Must be lowercase and be composed only of numbers, letters and “-”, up to a limit of 64 characters. The name must begin with a letter.
region: Option<VolumesCreateResponseVolumeRegion>size_gigabytes: Option<i64>The size of the block storage volume in GiB (1024^3). This field does not apply when creating a volume from a snapshot.
A flat array of tag names as strings applied to the resource.
Requires tag:read scope.