pub struct VpcPeeringsCreateResponse {
pub vpc_peering: Option<VpcPeeringsCreateResponseVpcPeering>,
}Expand description
VpcPeeringsCreateResponse
JSON schema
{
"examples": [
{
"vpc_peering": {
"created_at": "2024-01-09T20:44:32Z",
"id": "5a4981aa-9653-4bd1-bef5-d6bff52042e4",
"name": "example-vpc-peering",
"status": "PROVISIONING",
"vpc_ids": [
"997615ce-132d-4bae-9270-9ee21b395e5d",
"e51aed59-3bb1-4a6a-8de0-9d1329e9c997"
]
}
}
],
"type": "object",
"properties": {
"vpc_peering": {
"type": "object",
"allOf": [
{
"type": "object",
"properties": {
"created_at": {
"description": "A time value given in ISO8601 combined date and time format.",
"readOnly": true,
"examples": [
"2020-03-13T19:20:47.442049222Z"
],
"type": "string",
"format": "date-time"
},
"id": {
"description": "A unique ID that can be used to identify and reference the VPC peering.",
"readOnly": true,
"examples": [
"5a4981aa-9653-4bd1-bef5-d6bff52042e4"
],
"type": "string",
"format": "uuid"
},
"status": {
"description": "The current status of the VPC peering.",
"readOnly": true,
"examples": [
"ACTIVE"
],
"type": "string",
"enum": [
"PROVISIONING",
"ACTIVE",
"DELETING"
]
}
}
},
{
"type": "object",
"properties": {
"vpc_ids": {
"description": "An array of the two peered VPCs IDs.",
"examples": [
[
"c140286f-e6ce-4131-8b7b-df4590ce8d6a",
"994a2735-dc84-11e8-80bc-3cfdfea9fba1"
]
],
"type": "array",
"items": {
"type": "string",
"format": "uuid"
},
"maxItems": 2,
"minItems": 2
}
}
},
{
"type": "object",
"properties": {
"name": {
"description": "The name of the VPC peering. Must be unique within the team and may only contain alphanumeric characters and dashes.",
"examples": [
"nyc1-blr1-peering"
],
"type": "string",
"pattern": "^[a-zA-Z0-9\\-]+$"
}
}
}
]
}
}
}Fields
vpc_peering: Option<VpcPeeringsCreateResponseVpcPeering>Trait Implementations
Sourceimpl Clone for VpcPeeringsCreateResponse
impl Clone for VpcPeeringsCreateResponse
Sourcefn clone(&self) -> VpcPeeringsCreateResponse
fn clone(&self) -> VpcPeeringsCreateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VpcPeeringsCreateResponse
impl Debug for VpcPeeringsCreateResponse
Sourceimpl Default for VpcPeeringsCreateResponse
impl Default for VpcPeeringsCreateResponse
Sourceimpl<'de> Deserialize<'de> for VpcPeeringsCreateResponse
impl<'de> Deserialize<'de> for VpcPeeringsCreateResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&VpcPeeringsCreateResponse> for VpcPeeringsCreateResponse
impl From<&VpcPeeringsCreateResponse> for VpcPeeringsCreateResponse
Sourcefn from(value: &VpcPeeringsCreateResponse) -> Self
fn from(value: &VpcPeeringsCreateResponse) -> Self
Converts to this type from the input type.