pub struct VpcsPatchBody {
pub default: Option<bool>,
pub description: Option<VpcsPatchBodyDescription>,
pub name: Option<VpcsPatchBodyName>,
}Expand description
VpcsPatchBody
JSON schema
{
"allOf": [
{
"type": "object",
"properties": {
"description": {
"description": "A free-form text field for describing the VPC's purpose. It may be a maximum of 255 characters.",
"examples": [
"VPC for production environment"
],
"type": "string",
"maxLength": 255
},
"name": {
"description": "The name of the VPC. Must be unique and may only contain alphanumeric characters, dashes, and periods.",
"examples": [
"env.prod-vpc"
],
"type": "string",
"pattern": "^[a-zA-Z0-9\\-\\.]+$"
}
}
},
{
"type": "object",
"properties": {
"default": {
"description": "A boolean value indicating whether or not the VPC is the default network for the region. All applicable resources are placed into the default VPC network unless otherwise specified during their creation. The `default` field cannot be unset from `true`. If you want to set a new default VPC network, update the `default` field of another VPC network in the same region. The previous network's `default` field will be set to `false` when a new default VPC has been defined.",
"examples": [
true
],
"type": "boolean"
}
}
}
]
}Fields
default: Option<bool>A boolean value indicating whether or not the VPC is the default network for the region. All applicable resources are placed into the default VPC network unless otherwise specified during their creation. The default field cannot be unset from true. If you want to set a new default VPC network, update the default field of another VPC network in the same region. The previous network’s default field will be set to false when a new default VPC has been defined.
description: Option<VpcsPatchBodyDescription>A free-form text field for describing the VPC’s purpose. It may be a maximum of 255 characters.
name: Option<VpcsPatchBodyName>The name of the VPC. Must be unique and may only contain alphanumeric characters, dashes, and periods.